@@ -1,14 +1,23 @@
 <?php
 
-$block_name = _("Random Fortune");
+/* Disable block if not configured. */
+if (isset($GLOBALS['conf']['fortune']['exec_path']) &&
+    is_executable($GLOBALS['conf']['fortune']['exec_path'])) {
+    $block_name = _("Random Fortune");
+}
 
 /**
- * $Horde: horde/lib/Block/fortune.php,v 1.14.10.3 2007/04/24 15:20:00 jan Exp $
+ * $Horde: horde/lib/Block/fortune.php,v 1.14.10.4 2007-12-20 15:01:35 jan Exp $
  *
  * @package Horde_Block
  */
 class Horde_Block_Horde_fortune extends Horde_Block {
 
+    /**
+     * Whether this block has changing content.
+     */
+    var $updateable = true;
+
     var $_app = 'horde';
 
     /**
@@ -117,11 +126,11 @@ class Horde_Block_Horde_fortune extends Horde_Block {
             $cmdLine = $conf['fortune']['exec_path']
                 . $this->_params['offend']
                 . ' ' . implode(' ', $this->_params['fortune']);
-            return '<span class="fixed">'
+            return '<span class="fixed"><small>'
                 . nl2br(Text_Filter::filter(shell_exec($cmdLine),
                                             array('space2html'),
                                             array(array('encode' => true))))
-                . '</span>';
+                . '</small></span>';
         } else {
             return '';
         }
