@@ -3,7 +3,7 @@
 $block_name = _("Sunrise/Sunset");
 
 /**
- * $Horde: horde/lib/Block/sunrise.php,v 1.14.10.3 2005/10/18 11:33:39 jan Exp $
+ * $Horde: horde/lib/Block/sunrise.php,v 1.14.10.4 2007-12-20 15:01:36 jan Exp $
  *
  * @package Horde_Block
  */
@@ -24,7 +24,7 @@ class Horde_Block_Horde_sunrise extends Horde_Block {
 
         global $coordinates;
         if (!is_array($coordinates)) {
-            @include 'Horde/NLS/coordinates.php';
+            include 'Horde/NLS/coordinates.php';
             if (!is_array($coordinates)) {
                 $coordinates = array();
             }
