@@ -11,12 +11,17 @@ if (!empty($GLOBALS['conf']['weatherdotcom']['partner_id']) &&
  * portal screen to display weather and forecast data from weather.com
  * for a specified location.
  *
- * $Horde: horde/lib/Block/weatherdotcom.php,v 1.37.4.8.2.3 2005/11/25 09:54:52 jan Exp $
+ * $Horde: horde/lib/Block/weatherdotcom.php,v 1.37.4.17 2009-06-17 21:19:16 mrubinsk Exp $
  *
  * @package Horde_Block
  */
 class Horde_Block_Horde_weatherdotcom extends Horde_Block {
 
+    /**
+     * Whether this block has changing content.
+     */
+    var $updateable = true;
+
     var $_app = 'horde';
 
     /**
@@ -38,8 +43,9 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
     {
         if (!(@include_once 'Services/Weather.php') ||
             !(@include_once 'Cache.php') ||
+            !(@include_once 'XML/Serializer.php') ||
             !ini_get('allow_url_fopen')) {
-            Horde::logMessage('The weather.com block will not work without the PEARServices_Weather and Cache packages, and allow_url_fopen enabled. Run pear install Services_Weather Cache, and ensure that allow_url_fopen_wrappers is enabled in php.ini.',
+            Horde::logMessage('The weather.com block will not work without PEAR\'s Services_Weather, Cache, and XML_ Serializer packages, and allow_url_fopen enabled. Run `pear install Services_Weather Cache XML_Serializer and ensure that allow_url_fopen is enabled in php.ini.',
                               __FILE__, __LINE__, PEAR_LOG_ERR);
             $params = array(
                 'error' => array(
@@ -69,18 +75,13 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
                 'days' => array(
                     'type' => 'enum',
                     'name' => _("Forecast Days (note that the returned forecast returns both day and night; a large number here could result in a wide block)"),
-                    'default' => '3',
+                    'default' => 3,
                     'values' => array(
-                        '1' => '1',
-                        '2' => '2',
-                        '3' => '3',
-                        '4' => '4',
-                        '5' => '5',
-                        '6' => '6',
-                        '7' => '7',
-                        '8' => '8',
-                        '9' => '9',
-                        '10' => '10'
+                        '1' => 1,
+                        '2' => 2,
+                        '3' => 3,
+                        '4' => 4,
+                        '5' => 5,
                     )
                 ),
                 'detailedForecast' => array(
@@ -111,11 +112,29 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
 
         global $conf;
 
+        $options = array();
+        if (!empty($conf['http']['proxy']['proxy_host'])) {
+            $proxy = 'http://';
+            if (!empty($conf['http']['proxy']['proxy_user'])) {
+                $proxy .= urlencode($conf['http']['proxy']['proxy_user']);
+                if (!empty($conf['http']['proxy']['proxy_pass'])) {
+                    $proxy .= ':' . urlencode($conf['http']['proxy']['proxy_pass']);
+                }
+                $proxy .= '@';
+            }
+            $proxy .= $conf['http']['proxy']['proxy_host'];
+            if (!empty($conf['http']['proxy']['proxy_port'])) {
+                $proxy .= ':' . $conf['http']['proxy']['proxy_port'];
+            }
+
+            $options['httpProxy'] = $proxy;
+        }
+
         if (empty($this->_params['location'])) {
             return _("No location is set.");
         }
 
-        $weatherDotCom = &Services_Weather::service('WeatherDotCom');
+        $weatherDotCom = &Services_Weather::service('WeatherDotCom', $options);
         $weatherDotCom->setAccountData(
             (isset($conf['weatherdotcom']['partner_id']) ? $conf['weatherdotcom']['partner_id'] : ''),
             (isset($conf['weatherdotcom']['license_key']) ? $conf['weatherdotcom']['license_key'] : ''));
@@ -163,7 +182,7 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
             case SERVICES_WEATHER_ERROR_INVALID_LICENSE_KEY:
                 return _("Invalid license key.");
             default:
-                return $search->getmessage();
+                return $search->getMessage();
             }
         }
 
@@ -174,7 +193,7 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
             $html = _("Several locations possible with the parameter: ") .
                 $this->_params['location'] .
                 '<br /><ul>';
-            foreach ($search as $id_weather=>$real_location) {
+            foreach ($search as $id_weather => $real_location) {
                 $html .= "<li>$real_location ($id_weather)</li>\n";
             }
             $html .= '</ul>';
@@ -183,15 +202,15 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
 
         $location = $weatherDotCom->getLocation($search);
         if (is_a($location, 'PEAR_Error')) {
-            return $location->getmessage();
+            return $location->getMessage();
         }
         $weather = $weatherDotCom->getWeather($search);
         if (is_a($weather, 'PEAR_Error')) {
-            return $weather->getmessage();
+            return $weather->getMessage();
         }
-        $forecast = $weatherDotCom->getForecast($search, $this->_params['days']);
+        $forecast = $weatherDotCom->getForecast($search, (integer)$this->_params['days']);
         if (is_a($forecast, 'PEAR_Error')) {
-            return $forecast->getmessage();
+            return $forecast->getMessage();
         }
 
         // Location and local time.
@@ -263,13 +282,12 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
         $html .= '<br /><strong>' . _("Current condition: ") . '</strong>' .
             Horde::img('block/weatherdotcom/32x32/' .
                        ($weather['conditionIcon'] == '-' ? 'na' : $weather['conditionIcon']) . '.png',
-                       $condition,
-                       'align="middle"');
+                       $condition);
         $html .= ' ' . $condition;
 
         // Do the forecast now (if requested).
         if ($this->_params['days'] > 0) {
-            $html .= '<div class="control" style="text-align:center"><strong>' .
+            $html .= '<div class="control"><strong>' .
                 sprintf(_("%d-day forecast"), $this->_params['days']) .
                 '</strong></div>';
 
@@ -293,8 +311,7 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
                 $html .= '<tr class="item0">';
 
                 // Day name.
-                $html .= '<td rowspan="2" style="border:1px solid #ddd; text-align:center">' .
-                        '<strong>';
+                $html .= '<td rowspan="2" style="border:1px solid #ddd; text-align:center"><strong>';
                 if ($which == 0) {
                     $html .= _("Today");
                 } elseif ($which == 1) {
@@ -313,7 +330,7 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
                 if ($which == 0 && (strtotime($location['time']) >= strtotime('14:00'))) {
                     // Balance the grid.
                     $html .= '<td colspan="' .
-                            (isset($this->_params['detailedForecast']) ? '5' : '3' . '"') .
+                            ((isset($this->_params['detailedForecast']) ? '5' : '3') . '"') .
                             ' style="border:1px solid #ddd; text-align:center">' .
                             '&nbsp;<br />' . _("Information no longer available.") . '<br />&nbsp;' .
                             '</td>';
@@ -370,7 +387,7 @@ class Horde_Block_Horde_weatherdotcom extends Horde_Block {
                 // Low temperature.
                 $html .= '<td style="border:1px solid #ddd; text-align:center">' .
                     '<span style="color:blue">' .
-                    round($day['temperatureLow']) . '</td>';
+                    round($day['temperatureLow']) . '</span></td>';
 
                 // Condition.
                 $html .= '<td style="border:1px solid #ddd; text-align:center">' .
