@@ -1,17 +1,18 @@
 <?php
+
+require_once dirname(__FILE__) . '/String.php';
+
 /**
  * The Horde_Array:: class provides various methods for array manipulation.
  *
- * $Horde: framework/Util/Array.php,v 1.26.2.9 2007/01/02 13:54:47 jan Exp $
+ * $Horde: framework/Util/Array.php,v 1.26.2.12 2009-01-06 15:23:45 jan Exp $
  *
- * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
- * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
- * Copyright 2003-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @author  Marko Djukic <marko@oblo.com>
  * @author  Jan Schneider <jan@horde.org>
  * @since   Horde 3.0
@@ -96,24 +97,21 @@ class Horde_Array {
             return;
         }
 
-        /* If no key to sort by is specified, use the first key. */
+        /* If no key to sort by is specified, use the first key of the
+         * first element. */
         if (is_null($key)) {
-            $keys = array_keys(each($array));
-            $key = $keys[0];
-        }
-
-        /* Create the function that will be used to sort the keys. */
-        if ($direction) {
-            $function = sprintf('return strcoll(String::lower($b[\'%1$s\'], true), String::lower($a[\'%1$s\'], true));', $key);
-        } else {
-            $function = sprintf('return strcoll(String::lower($a[\'%1$s\'], true), String::lower($b[\'%1$s\'], true));', $key);
+            reset($array);
+            $key = array_shift(array_keys(current($array)));
         }
 
         /* Call the appropriate sort function. */
+        $helper = new Horde_Array_Sort_Helper;
+        $helper->key = $key;
+        $function = $direction ? 'reverseCompare' : 'compare';
         if ($associate) {
-            uasort($array, create_function('$a, $b', $function));
+            uasort($array, array($helper, $function));
         } else {
-            usort($array, create_function('$a, $b', $function));
+            usort($array, array($helper, $function));
         }
     }
 
@@ -141,7 +139,7 @@ class Horde_Array {
     }
 
     /**
-     * Using an array of keys itarate through the array following the
+     * Using an array of keys iterate through the array following the
      * keys to find the final key value. If a value is passed then set
      * that value.
      *
@@ -172,7 +170,7 @@ class Horde_Array {
     /**
      * Returns a rectangle of a two-dimensional array.
      *
-     * @param array &$array    The array to extract the rectangle from.
+     * @param array   $array   The array to extract the rectangle from.
      * @param integer $row     The start row of the rectangle.
      * @param integer $col     The start column of the rectangle.
      * @param integer $height  The height of the rectangle.
@@ -180,7 +178,7 @@ class Horde_Array {
      *
      * @return array  The extracted rectangle.
      */
-    function &getRectangle(&$array, $row, $col, $height, $width)
+    function getRectangle($array, $row, $col, $height, $width)
     {
         $rec = array();
         for ($y = $row; $y < $row + $height; $y++) {
@@ -203,11 +201,12 @@ class Horde_Array {
      */
     function valuesToKeys($array)
     {
-        $mapped = array();
-        foreach ($array as $value) {
-            $mapped[$value] = $value;
+        if (!$array) {
+            return array();
         }
-        return $mapped;
+
+        $values = array_values($array);
+        return Horde_Array::combine($values, $values);
     }
 
     /**
@@ -237,4 +236,95 @@ class Horde_Array {
         return $array;
     }
 
+    /**
+     * Enhanced array_merge_recursive() function.  Main difference from PHP's
+     * stock function is later value always overwrites earlier value (stock
+     * function will instead create an array with all values of key).
+     *
+     * @since Horde 3.2
+     *
+     * @param array $a1  The old array.
+     * @param array $a2  The new array.
+     *
+     * @return array  The merged array.
+     */
+    function array_merge_recursive_overwrite($a1, $a2)
+    {
+        foreach ($a2 as $key => $val) {
+            if (!isset($a1[$key])) {
+                $a1[$key] = array();
+            }
+
+            $a1[$key] = (is_array($val))
+                ? Horde_Array::array_merge_recursive_overwrite($a1[$key], $val)
+                : $val;
+        }
+
+        return $a1;
+    }
+
+}
+
+/**
+ * @package Horde_Util
+ *
+ * Helper class for sorting arrays on arbitrary criteria for
+ * usort/uasort.
+ */
+class Horde_Array_Sort_Helper {
+
+    /**
+     * The array key to sort by.
+     *
+     * @var string
+     */
+    var $key;
+
+    /**
+     * Compare two associative arrays by the array key defined in
+     * self::$key.
+     *
+     * @param array $a
+     * @param array $b
+     */
+    function compare($a, $b)
+    {
+        return strcoll(String::lower($a[$this->key], true), String::lower($b[$this->key], true));
+    }
+
+    /**
+     * Compare, in reverse order, two associative arrays by the array
+     * key defined in self::$key.
+     *
+     * @param array $a
+     * @param array $b
+     */
+    function reverseCompare($a, $b)
+    {
+        return strcoll(String::lower($b[$this->key], true), String::lower($a[$this->key], true));
+    }
+
+    /**
+     * Compare array keys case insensitively for uksort.
+     *
+     * @param scalar $a
+     * @param scalar $b
+     */
+    function compareKeys($a, $b)
+    {
+        return strcoll(String::lower($a, true), String::lower($b, true));
+    }
+
+    /**
+     * Compare, in reverse order, array keys case insensitively for
+     * uksort.
+     *
+     * @param scalar $a
+     * @param scalar $b
+     */
+    function reverseCompareKeys($a, $b)
+    {
+        return strcoll(String::lower($b, true), String::lower($a, true));
+    }
+
 }
