@@ -1,6 +1,5 @@
 <?php
 
-require_once 'Horde/DataTree.php';
 require_once 'Horde/Form.php';
 require_once 'Horde/Form/Renderer.php';
 
@@ -9,12 +8,12 @@ require_once 'Horde/Form/Renderer.php';
  * new users sign themselves up into the horde installation, depending
  * on how the admin has configured Horde.
  *
- * $Horde: framework/Auth/Auth/Signup.php,v 1.38.2.13 2007/01/02 13:54:06 jan Exp $
+ * $Horde: framework/Auth/Auth/Signup.php,v 1.38.2.23 2009-08-13 15:43:57 jan Exp $
  *
- * Copyright 2002-2007 Marko Djukic <marko@oblo.com>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @since   Horde 3.0
@@ -23,23 +22,43 @@ require_once 'Horde/Form/Renderer.php';
 class Auth_Signup {
 
     /**
-     * Pointer to a DataTree instance to manage/store signups
+     * Attempts to return a concrete Auth_Signup instance based on $driver.
      *
-     * @var DataTree
+     * @param string $driver  The type of the concrete Auth_Signup subclass
+     *                        to return.  The class name is based on the
+     *                        storage driver ($driver).  The code is
+     *                        dynamically included.
+     * @param array $params   A hash containing any additional configuration or
+     *                        connection parameters a subclass might need.
+     *
+     * @return Auth_Signup  The newly created concrete Auth_Signup
+     *                          instance, or false on an error.
      */
-    var $_datatree;
-
-    function Auth_Signup()
+    function factory($driver = null, $params = null)
     {
-        global $conf;
+        if ($driver === null) {
+            if (!empty($GLOBALS['conf']['signup']['driver'])) {
+                $driver = $GLOBALS['conf']['signup']['driver'];
+            } else {
+                $driver = 'datatree';
+            }
+        } else {
+            $driver = basename($driver);
+        }
 
-        if (empty($conf['datatree']['driver'])) {
-            Horde::fatal(_("You must configure a DataTree backend to use Signups."), __FILE__, __LINE__);
+        if ($params === null) {
+            $params = Horde::getDriverConfig('signup', $driver);
+        }
+
+        $class = 'Auth_Signup_' . $driver;
+        if (!class_exists($class)) {
+            include dirname(__FILE__) . '/Signup/' . $driver . '.php';
+        }
+        if (class_exists($class)) {
+            return new $class($params);
+        } else {
+            return PEAR::raiseError(_("You must configure a backend to use Signups."));
         }
-        $driver = $conf['datatree']['driver'];
-        $this->_datatree = &DataTree::singleton($driver,
-                                                array_merge(Horde::getDriverConfig('datatree', $driver),
-                                                            array('group' => 'horde.signup')));
     }
 
     /**
@@ -63,24 +82,31 @@ class Auth_Signup {
             }
         }
 
-        // Attempt to add the user to the system.
-        $success = $auth->addUser($info['user_name'], array('password' => $info['password']));
-        if (is_a($success, 'PEAR_Error')) {
-            return $success;
+        // Check to see if the username already exists.
+        if ($auth->exists($info['user_name']) ||
+            $this->exists($info['user_name'])) {
+            return PEAR::raiseError(sprintf(_("Username \"%s\" already exists."), $info['user_name']));
         }
 
+        // Attempt to add the user to the system.
+        $result = $auth->addUser($info['user_name'], array('password' => $info['password']));
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+
+        $result = true;
         // Attempt to add/update any extra data handed in.
         if (!empty($info['extra'])) {
-            $added = false;
-            $added = Horde::callHook('_horde_hook_signup_addextra',
-                                     array($info['user_name'], $info['extra']));
-            if (!$added || is_a($added, 'PEAR_Error')) {
-                Horde::logMessage($added, __FILE__, __LINE__, PEAR_LOG_EMERG);
-                Horde::fatal(_("Unable to add extra user information when signing up."), __FILE__, __LINE__);
+            $result = false;
+            $result = Horde::callHook('_horde_hook_signup_addextra',
+                                      array($info['user_name'], $info['extra'], $info['password']));
+            if (is_a($result, 'PEAR_Error')) {
+                Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_EMERG);
+                return $result;
             }
         }
 
-        return true;
+        return $result;
     }
 
     /**
@@ -91,9 +117,9 @@ class Auth_Signup {
      *
      * @return mixed  PEAR_Error if any errors, otherwise true.
      */
-    function &queueSignup(&$info)
+    function queueSignup(&$info)
     {
-        global $auth,$conf;
+        global $auth, $conf;
 
         // Perform any preprocessing if requested.
         if ($conf['signup']['preprocess']) {
@@ -106,7 +132,7 @@ class Auth_Signup {
 
         // Check to see if the username already exists.
         if ($auth->exists($info['user_name']) ||
-            $this->_datatree->exists($info['user_name'])) {
+            $this->exists($info['user_name'])) {
             return PEAR::raiseError(sprintf(_("Username \"%s\" already exists."), $info['user_name']));
         }
 
@@ -121,15 +147,53 @@ class Auth_Signup {
                                   'dateReceived' => time());
         }
 
+        $result = $this->_queueSignup($signup);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+
         if ($conf['signup']['queue']) {
             $result = Horde::callHook('_horde_hook_signup_queued',
                                       array($info['user_name'], $info));
-            if (is_a($result, 'PEAR_Error')) {
-                return $result;
-            }
         }
 
-        return $this->_datatree->add($signup);
+        if (!empty($conf['signup']['email'])) {
+            require_once 'Horde/MIME/Mail.php';
+            $link = Util::addParameter(Horde::url($GLOBALS['registry']->get('webroot', 'horde') . '/admin/signup_confirm.php', true, -1),
+                                       array('u' => $signup->name,
+                                             'h' => Util::hmac($signup->name, $conf['secret_key'])),
+                                       null, false);
+            $message = sprintf(_("A new account for the user \"%s\" has been requested through the signup form."), $signup->name)
+                . "\n\n"
+                . _("Approve the account:")
+                . "\n" . Util::addParameter($link, 'a', 'approve') . "\n"
+                . _("Deny the account:")
+                . "\n" . Util::addParameter($link, 'a', 'deny');
+            $mail = new MIME_Mail(
+                sprintf(_("Account signup request for \"%s\""), $signup->name),
+                $message,
+                $conf['signup']['email'],
+                $conf['signup']['email'],
+                NLS::getCharset());
+            list($mail_driver, $mail_params) = Horde::getMailerConfig();
+            $result = $mail->send($mail_driver, $mail_params);
+            if (is_a($result, 'PEAR_Error')) {
+                Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            }
+        }
+    }
+
+    /**
+     * Queues the user's submitted registration info for later admin approval.
+     *
+     * @params mixed $info  Reference to array of parameteres to be passed
+     *                      to hook
+     *
+     * @return mixed  PEAR_Error if any errors, otherwise true.
+     */
+    function &_queueSignup(&$info)
+    {
+        return PEAR::raiseError('Not implemented');
     }
 
     /**
@@ -137,29 +201,21 @@ class Auth_Signup {
      *
      * @param string $username  The username to retrieve the queued info for.
      *
-     * @return DataTreeObject_Signup  The DataTreeObject for the requested
-     *                                signup.
+     * @return object  The bject for the requested signup.
      */
     function getQueuedSignup($username)
     {
-        return $this->_datatree->getObject($username, 'DataTreeObject_Signup');
+        return PEAR::raiseError('Not implemented');
     }
 
     /**
      * Get the queued information for all pending signups.
      *
-     * @return array  An array of DataTreeObject_Signup objects, one for
-     *                each signup in the queue.
+     * @return array  An array of objects, one for each signup in the queue.
      */
     function getQueuedSignups()
     {
-        $signups = array();
-        foreach ($this->_datatree->get(DATATREE_FORMAT_FLAT, DATATREE_ROOT, true) as $username) {
-            if ($username != DATATREE_ROOT) {
-                $signups[] = $this->_datatree->getObject($username);
-            }
-        }
-        return $signups;
+        return PEAR::raiseError('Not implemented');
     }
 
     /**
@@ -169,7 +225,7 @@ class Auth_Signup {
      */
     function removeQueuedSignup($username)
     {
-        $this->_datatree->remove($username);
+        return PEAR::raiseError('Not implemented');
     }
 
     /**
@@ -177,63 +233,22 @@ class Auth_Signup {
      *
      * @param string $name  The signups's name.
      *
-     * @return DataTreeObject_Signup  A new signup object.
+     * @return object  A new signup object.
      */
-    function &newSignup($name)
+    function newSignup($name)
     {
-        if (empty($name)) {
-            return PEAR::raiseError('Signup names must be non-empty');
-        }
-        $signup = &new DataTreeObject_Signup($name);
-        return $signup;
+        return PEAR::raiseError('Not implemented');
     }
 
 }
 
 /**
- * Extension of the DataTreeObject class for storing Signup
- * information in the DataTree driver. If you want to store
- * specialized Signup information, you should extend this class
- * instead of extending DataTreeObject directly.
+ * Horde Signup Form.
  *
- * @author  Marko Djukic <marko@oblo.com>
- * @since   Horde 3.0
- * @package Horde_Auth
- */
-class DataTreeObject_Signup extends DataTreeObject {
-
-    /**
-     * We want to see queued signups in descending order of receipt.
-     * Insert new signups at position 0 and push the rest down.
-     *
-     * @var integer
-     */
-    var $order = 0;
-
-    /**
-     * The DataTreeObject_Signup constructor. Just makes sure to call
-     * the parent constructor so that the signup's is is set
-     * properly.
-     *
-     * @param string $id  The id of the signup.
-     */
-    function DataTreeObject_Signup($id)
-    {
-        parent::DataTreeObject($id);
-        if (is_null($this->data)) {
-            $this->data = array();
-        }
-    }
-
-}
-
-/**
- * Horde Signup Form, extending of Horde_Form::
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
- * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
- *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @since   Horde 3.0
@@ -278,4 +293,24 @@ class HordeSignupForm extends Horde_Form {
         }
     }
 
+    /**
+     * Fetch the field values of the submitted form.
+     *
+     * @param Variables $vars  A Variables instance, optional since Horde 3.2.
+     * @param array $info      Array to be filled with the submitted field
+     *                         values.
+     */
+    function getInfo($vars, &$info)
+    {
+        parent::getInfo($vars, $info);
+
+        if (!isset($info['user_name']) && isset($info['extra']['user_name'])) {
+            $info['user_name'] = $info['extra']['user_name'];
+        }
+
+        if (!isset($info['password']) && isset($info['extra']['password'])) {
+            $info['password'] = $info['extra']['password'];
+        }
+    }
+
 }
