@@ -36,6 +36,7 @@ require_once 'Horde/IMAP/Admin.php';
  *                     Set this to true if the value is true in imapd.conf.
  *   'username_field'  The name of the username field in the auth table.
  *                     DEFAULT: 'username'</pre>
+ *   'hidden_accounts' An array of system accounts to hide from the user interface.
  *
  * Required by some database implementations:<pre>
  *   'database'  The name of the database.
@@ -121,15 +122,14 @@ require_once 'Horde/IMAP/Admin.php';
  * );
  * </pre>
  *
- * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33.10.11 2005/08/02 17:20:57 jan Exp $
+ * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33.10.19 2009-01-06 15:22:49 jan Exp $
  *
- * Copyright 2002-2005 Ilya <mail@krel.org>
- * Copyright 2005 Jan Schneider <jan@horde.org>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
  *
- * @author  Ilya <mail@krel.org>
+ * @author  Ilya Krel <mail@krel.org>
  * @author  Jan Schneider <jan@horde.org>
  * @since   Horde 3.0
  * @package Horde_Auth
@@ -164,9 +164,6 @@ class Auth_cyrsql extends Auth_sql {
      */
     function Auth_cyrsql($params = array())
     {
-        if (!Util::extensionExists('imap')) {
-            Horde::fatal(_("Auth_cyrsql: Required imap extension not found."), __FILE__, __LINE__);
-        }
         parent::Auth_sql($params);
 
         $admin_params = array('admin_user' => $params['cyradmin'],
@@ -174,8 +171,82 @@ class Auth_cyrsql extends Auth_sql {
                               'dsn' => $params['imap_dsn']);
         if (!empty($this->_params['unixhier'])) {
             $admin_params['userhierarchy'] = 'user/';
-        } 
-        $this->_admin = &new IMAP_Admin($admin_params);
+        }
+        $this->_admin = new IMAP_Admin($admin_params);
+    }
+
+    /**
+     * Find out if a set of login credentials are valid.
+     *
+     * @access private
+     *
+     * @param string $userId      The userId to check.
+     * @param array $credentials  The credentials to use.
+     *
+     * @return boolean  Whether or not the credentials are valid.
+     */
+    function _authenticate($userId, $credentials)
+    {
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            $this->_setAuthError(AUTH_REASON_FAILED);
+            return false;
+        }
+
+        if (!empty($this->_params['domain_field']) &&
+            ($this->_params['domain_field'] != 'none')) {
+            /* Build the SQL query with domain. */
+            $query = sprintf('SELECT * FROM %s WHERE %s = ? AND %s = ?',
+                             $this->_params['table'],
+                             $this->_params['username_field'],
+                             $this->_params['domain_field']);
+            $values = explode('@', $userId);
+        } else {
+            /* Build the SQL query without domain. */
+            $query = sprintf('SELECT * FROM %s WHERE %s = ?',
+                             $this->_params['table'],
+                             $this->_params['username_field']);
+            $values = array($userId);
+        }
+
+        Horde::logMessage('SQL Query by Auth_cyrsql::_authenticate(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+        $result = $this->_db->query($query, $values);
+        if (is_a($result, 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            $this->_setAuthError(AUTH_REASON_FAILED);
+            return false;
+        }
+
+        $row = $result->fetchRow(DB_GETMODE_ASSOC);
+        if (is_array($row)) {
+            $result->free();
+        } else {
+            $this->_setAuthError(AUTH_REASON_BADLOGIN);
+            return false;
+        }
+
+        if (!$this->_comparePasswords($row[$this->_params['password_field']],
+                                      $credentials['password'])) {
+            $this->_setAuthError(AUTH_REASON_BADLOGIN);
+            return false;
+        }
+
+        $now = time();
+        if (!empty($this->_params['hard_expiration_field']) &&
+            !empty($row[$this->_params['hard_expiration_field']]) &&
+            ($now > $row[$this->_params['hard_expiration_field']])) {
+            $this->_setAuthError(AUTH_REASON_EXPIRED);
+            return false;
+        }
+
+        if (!empty($this->_params['soft_expiration_field']) &&
+            !empty($row[$this->_params['soft_expiration_field']]) &&
+            ($now > $row[$this->_params['soft_expiration_field']])) {
+            $this->_authCredentials['changeRequested'] = true;
+        }
+
+        return true;
     }
 
     /**
@@ -188,7 +259,9 @@ class Auth_cyrsql extends Auth_sql {
      */
     function addUser($userId, $credentials)
     {
-        $this->_connect();
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            return $result;
+        }
 
         if (!empty($this->_params['domain_field']) &&
             ($this->_params['domain_field'] != 'none')) {
@@ -210,7 +283,7 @@ class Auth_cyrsql extends Auth_sql {
 
             $dbresult = $this->_db->query($query, $values);
             $query = 'INSERT INTO virtual (alias, dest, username, status) VALUES (?, ?, ?, 1)';
-            $values = array($userId, $name, $name);
+            $values = array($userId, $userId, $name);
 
             Horde::logMessage('SQL Query by Auth_cyrsql::addUser(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
@@ -220,24 +293,23 @@ class Auth_cyrsql extends Auth_sql {
             }
         } else {
             $dbresult = parent::addUser($userId, $credentials);
-            $name = $userId;
         }
         if (is_a($dbresult, 'PEAR_Error')) {
             return $dbresult;
         }
 
-        if (!is_a($result = $this->_admin->addMailbox($name), 'PEAR_Error')) {
+        if (!is_a($result = $this->_admin->addMailbox($userId), 'PEAR_Error')) {
             @array_walk($this->_params['folders'],
-                        array($this, '_createSubFolders'), $name);
+                        array($this, '_createSubFolders'), $userId);
         } else {
-            Horde::logMessage('IMAP mailbox creation for ' . $name . ' failed: ' . $result->getMessage(),
+            Horde::logMessage('IMAP mailbox creation for ' . $userId . ' failed: ' . $result->getMessage(),
                               __FILE__, __LINE__, PEAR_LOG_ERR);
             return PEAR::raiseError(sprintf(_("IMAP mailbox creation failed: %s"), $result->getMessage()));
         }
 
         if (isset($this->_params['quota']) && $this->_params['quota'] >= 0) {
             if (!@imap_set_quota($this->_imapStream,
-                                 'user' . $this->_separator . $name,
+                                 'user' . $this->_separator . $userId,
                                  $this->_params['quota'])) {
                 return PEAR::raiseError(sprintf(_("IMAP mailbox quota creation failed: %s"), imap_last_error()));
             }
@@ -255,7 +327,9 @@ class Auth_cyrsql extends Auth_sql {
      */
     function removeUser($userId)
     {
-        $this->_connect();
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            return $result;
+        }
 
         if (!empty($this->_params['domain_field']) &&
             ($this->_params['domain_field'] != 'none')) {
@@ -271,7 +345,7 @@ class Auth_cyrsql extends Auth_sql {
 
             $dbresult = $this->_db->query($query, $values);
             $query = 'DELETE FROM virtual WHERE dest = ?';
-            $values = array($name);
+            $values = array($userId);
 
             Horde::logMessage('SQL Query by Auth_cyrsql::removeUser(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
@@ -281,7 +355,6 @@ class Auth_cyrsql extends Auth_sql {
             }
         } else {
             $dbresult = parent::removeUser($userId);
-            $name = $userId;
         }
 
         if (is_a($dbresult, 'PEAR_Error')) {
@@ -289,7 +362,7 @@ class Auth_cyrsql extends Auth_sql {
         }
 
         /* Delete IMAP mailbox. */
-        $imapresult = $this->_admin->removeMailbox($name);
+        $imapresult = $this->_admin->removeMailbox($userId);
 
         if (is_a($imapresult, 'PEAR_Error')) {
             return PEAR::raiseError(sprintf(_("IMAP mailbox deletion failed: %s"), $imapresult->getMessage()));
@@ -298,67 +371,6 @@ class Auth_cyrsql extends Auth_sql {
         return $this->removeUserData($userId);
     }
 
-    /**
-     * Attempts to open connections to the SQL and IMAP servers.
-     *
-     * @access private
-     *
-     * @return mixed  True on success or a PEAR_Error object on failure.
-     */
-    function _connect()
-    {
-        if (!$this->_connected) {
-            parent::_connect();
-
-            // Reset the $_connected flag; we haven't yet successfully opened
-            // everything.
-            $this->_connected = false;
-
-            $this->_imapStream = @imap_open($this->_params['imap_dsn'], $this->_params['cyradmin'], $this->_params['cyrpass'], OP_HALFOPEN);
-            if (!$this->_imapStream) {
-                Horde::fatal(sprintf(_("Can't connect to IMAP server: %s"), imap_last_error()), __FILE__, __LINE__);
-            }
-
-            if (!empty($this->_params['unixhier'])) {
-                $this->_separator = '/';
-            }
-            $this->_connected = true;
-        }
-
-        return true;
-    }
-
-    /**
-     * Disconnect from the SQL and IMAP servers and clean up the connections.
-     *
-     * @access private
-     *
-     * @return boolean  True on success, false on failure.
-     */
-    function _disconnect()
-    {
-        if ($this->_connected) {
-            parent::_disconnect();
-            @imap_close($this->_imapStream);
-        }
-
-        return true;
-    }
-
-    /**
-     * Creates all mailboxes supplied in configuration
-     *
-     * @access private
-     */
-    function _createSubFolders($value, $key, $userName)
-    {
-        if (!empty($this->_params['domain_field']) &&
-            ($this->_params['domain_field'] != 'none')) {
-            list($userName) = explode('@', $userName);
-        }
-        $this->_admin->addMailbox($userName . $this->_separator . $value);
-    }
-
     /**
      * List all users in the system.
      *
@@ -366,8 +378,9 @@ class Auth_cyrsql extends Auth_sql {
      */
     function listUsers()
     {
-        /* _connect() will die with Horde::fatal() upon failure. */
-        $this->_connect();
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            return $result;
+        }
 
         if (!empty($this->_params['domain_field']) &&
             ($this->_params['domain_field'] != 'none')) {
@@ -394,14 +407,18 @@ class Auth_cyrsql extends Auth_sql {
 
         /* Loop through and build return array. */
         $users = array();
-        if (!empty($this->_params['domain_field']) &&
-            ($this->_params['domain_field'] != 'none')) {
+        if (!empty($this->_params['domain_field'])
+            && ($this->_params['domain_field'] != 'none')) {
             foreach ($result as $ar) {
-                $users[] = $ar[0] . '@' . $ar[1];
+                if (!in_array($ar[0], $this->_params['hidden_accounts'])) {
+                    $users[] = $ar[0] . '@' . $ar[1];
+                }
             }
         } else {
             foreach ($result as $ar) {
-                $users[] = $ar[0];
+                if (!in_array($ar[0], $this->_params['hidden_accounts'])) {
+                    $users[] = $ar[0];
+                }
             }
         }
 
@@ -419,8 +436,9 @@ class Auth_cyrsql extends Auth_sql {
      */
     function updateUser($oldID, $newID, $credentials)
     {
-        /* _connect() will die with Horde::fatal() upon failure. */
-        $this->_connect();
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            return $result;
+        }
 
         if (!empty($this->_params['domain_field']) &&
             ($this->_params['domain_field'] != 'none')) {
@@ -454,4 +472,67 @@ class Auth_cyrsql extends Auth_sql {
         return $this->_db->query($query, $values);
     }
 
+    /**
+     * Attempts to open connections to the SQL and IMAP servers.
+     *
+     * @access private
+     *
+     * @return mixed  True on success or a PEAR_Error object on failure.
+     */
+    function _connect()
+    {
+        if ($this->_connected) {
+            return true;
+        }
+
+        if (!Util::extensionExists('imap')) {
+            return PEAR::raiseError(_("Auth_cyrsql: Required imap extension not found."));
+        }
+
+        $result = parent::_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+
+        if (!isset($this->_params['hidden_accounts'])) {
+            $this->_params['hidden_accounts'] = array('cyrus');
+        }
+
+        // Reset the $_connected flag; we haven't yet successfully
+        // opened everything.
+        $this->_connected = false;
+
+        $this->_imapStream = @imap_open($this->_params['imap_dsn'], $this->_params['cyradmin'], $this->_params['cyrpass'], OP_HALFOPEN);
+        if (!$this->_imapStream) {
+            return PEAR::raiseError(sprintf(_("Can't connect to IMAP server: %s"), imap_last_error()));
+        }
+
+        if (!empty($this->_params['unixhier'])) {
+            $this->_separator = '/';
+        }
+
+        $this->_connected = true;
+        return true;
+    }
+
+    /**
+     * Creates all mailboxes supplied in configuration
+     *
+     * @access private
+     *
+     * @param string $value
+     * @param string $key      Unused by this driver
+     * @param string userName
+     */
+    function _createSubFolders($value, $key, $userName)
+    {
+        if (!empty($this->_params['domain_field']) &&
+            ($this->_params['domain_field'] != 'none')) {
+            list($userName, $domain) = explode('@', $userName);
+            $this->_admin->addMailbox($userName . $this->_separator . $value . '@' . $domain);
+        } else {
+            $this->_admin->addMailbox($userName . $this->_separator . $value);
+        }
+    }
+
 }
