@@ -7,7 +7,7 @@
  * RADIUS PECL extension: http://pecl.php.net/package/radius
  *
  * On *nix-y machines, this extension can be installed as follows:<pre>
- *   "pear install radius"</pre>
+ *   "pecl install radius"</pre>
  *
  * Then, edit your php.ini file and make sure the following line is present:<pre>
  *   For Windows machines:  extension=php_radius.dll
@@ -40,14 +40,14 @@
  *              DEFAULT: 3 seconds</pre>
  *
  *
- * $Horde: framework/Auth/Auth/radius.php,v 1.24.8.9 2007/01/02 13:54:07 jan Exp $
+ * $Horde: framework/Auth/Auth/radius.php,v 1.24.8.13 2009-01-06 15:22:50 jan Exp $
  *
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -73,11 +73,7 @@ class Auth_radius extends Auth {
      */
     function Auth_radius($params = array())
     {
-        if (!Util::extensionExists('radius')) {
-            Horde::fatal('Auth_radius requires the radius PECL extension to be loaded.', __FILE__, __LINE__);
-        }
-
-        $this->_setParams($params);
+        $this->_params = $params;
     }
 
     /**
@@ -87,50 +83,53 @@ class Auth_radius extends Auth {
      *
      * @param array $params  The parameter hash.
      */
-    function _setParams($params)
+    function _setParams()
     {
+        if (!Util::extensionExists('radius')) {
+            return PEAR::raiseError('Auth_radius requires the radius PECL extension to be loaded.');
+        }
+
         /* A RADIUS host is required. */
-        if (empty($params['host'])) {
-            Horde::fatal('Auth_radius requires a RADIUS host to connect to.', __FILE__, __LINE__);
+        if (empty($this->_params['host'])) {
+            return PEAR::raiseError('Auth_radius requires a RADIUS host to connect to.');
         }
 
         /* A RADIUS secret string is required. */
-        if (empty($params['secret'])) {
-            Horde::fatal('Auth_radius requires a RADIUS secret string.', __FILE__, __LINE__);
+        if (empty($this->_params['secret'])) {
+            return PEAR::raiseError('Auth_radius requires a RADIUS secret string.');
         }
 
         /* A RADIUS authentication method is required. */
-        if (empty($params['method'])) {
-            Horde::fatal('Auth_radius requires a RADIUS authentication method.', __FILE__, __LINE__);
+        if (empty($this->_params['method'])) {
+            return PEAR::raiseError('Auth_radius requires a RADIUS authentication method.');
         }
 
         /* RADIUS NAS Identifier. */
-        if (empty($params['nas'])) {
-            $params['nas'] = isset($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'
-] : 'localhost';
+        if (empty($this->_params['nas'])) {
+            $this->_params['nas'] = isset($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : 'localhost';
         }
 
         /* Suffix to add to unqualified user names. */
-        if (empty($params['suffix'])) {
-            $params['suffix'] = '';
+        if (empty($this->_params['suffix'])) {
+            $this->_params['suffix'] = '';
         }
 
         /* The RADIUS port to use. */
-        if (empty($params['port'])) {
-            $params['port'] = 0;
+        if (empty($this->_params['port'])) {
+            $this->_params['port'] = 0;
         }
 
         /* Maximum number of retries. */
-        if (empty($params['retries'])) {
-            $params['retries'] = 3;
+        if (empty($this->_params['retries'])) {
+            $this->_params['retries'] = 3;
         }
 
         /* RADIUS timeout. */
-        if (empty($params['timeout'])) {
-            $params['timeout'] = 3;
+        if (empty($this->_params['timeout'])) {
+            $this->_params['timeout'] = 3;
         }
 
-        $this->_params = $params;
+        return true;
     }
 
     /**
@@ -147,9 +146,16 @@ class Auth_radius extends Auth {
      */
     function _authenticate($username, $credentials)
     {
+        $result = $this->_setParams();
+        if (is_a($result, 'PEAR_Error')) {
+            $this->_setAuthError(AUTH_REASON_MESSAGE, $result->getMessage());
+            return false;
+        }
+
         /* Password is required. */
         if (!isset($credentials['password'])) {
-            Horde::fatal(_("Password required for RADIUS authentication."), __FILE__, __LINE__);
+            $this->_setAuthError(AUTH_REASON_MESSAGE, _("Password required for RADIUS authentication."));
+            return false;
         }
 
         $res = radius_auth_open();
