@@ -6,9 +6,9 @@ require_once 'Horde/Block.php';
  * The Horde_Block_Collection:: class provides an API to the blocks
  * (applets) framework.
  *
- * $Horde: framework/Block/Block/Collection.php,v 1.36.4.21 2008/09/03 15:21:48 jan Exp $
+ * $Horde: framework/Block/Block/Collection.php,v 1.36.4.23 2010-07-15 16:53:50 mrubinsk Exp $
  *
- * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -203,10 +203,12 @@ class Horde_Block_Collection {
      *
      * @param string $cur_app    The block from this application gets selected.
      * @param string $cur_block  The block with this name gets selected.
+     * @param boolean $onchange  Indicates if the onchnage handler is included.
+     * @param boolean $readonly  Indicates if this block's type is changeable.
      *
      * @return string  The select tag with all available blocks.
      */
-    function getBlocksWidget($cur_app = null, $cur_block = null, $onchange = false)
+    function getBlocksWidget($cur_app = null, $cur_block = null, $onchange = false, $readonly = false)
     {
         global $registry;
 
@@ -214,6 +216,9 @@ class Horde_Block_Collection {
         if ($onchange) {
             $widget .= ' onchange="document.blockform.action.value=\'save-resume\';document.blockform.submit()"';
         }
+        if ($readonly) {
+            $widget .= ' disabled="disabled"';
+        }
         $widget .= ">\n";
         $blocks_list = $this->getBlocksList();
         foreach ($blocks_list as $id => $name) {
