@@ -2,12 +2,12 @@
 /**
  * Class for setting up Horde Blocks using the Horde_Form:: classes.
  *
- * Copyright 2004-2007 Marko Djukic <marko@oblo.com>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL). If you did
- * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Block/Block/UI.php,v 1.8.10.6 2007/01/02 13:54:08 jan Exp $
+ * $Horde: framework/Block/Block/UI.php,v 1.8.10.9 2009-01-06 15:22:53 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @since   Horde 3.0
@@ -47,7 +47,7 @@ class Horde_Block_UI {
         if (!is_a($this->_form, 'Horde_Form')) {
             /* No existing valid form object set so set up a new one. */
             require_once 'Horde/Form.php';
-            $this->_form = &Horde_Form::singleton('', $this->_vars, _("Edit Block"));
+            $this->_form = new Horde_Form($this->_vars, _("Edit Block"));
         }
 
         /* Get the current value of the block selection. */
