@@ -3,12 +3,12 @@
  * The Horde_Cipher:: class provides a common abstracted interface to
  * various Ciphers for encryption of arbitrary length pieces of data.
  *
- * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Cipher/Cipher.php,v 1.16.12.11 2008/01/02 11:30:24 jan Exp $
+ * $Horde: framework/Cipher/Cipher.php,v 1.16.12.13 2009-03-04 20:34:27 slusarz Exp $
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
  * @since   Horde 2.2
@@ -21,7 +21,7 @@ class Horde_Cipher {
      *
      * @var string
      */
-    var $_blockMode = 'CBC';
+    var $_blockMode = 'cbc';
 
     /**
      * The initialization vector
