@@ -3,9 +3,9 @@
  * The Horde_Cipher_BlockMode:: class provides a common abstracted
  * interface to various block mode handlers for ciphers.
  *
- * $Horde: framework/Cipher/Cipher/BlockMode.php,v 1.14.12.6 2005/07/03 05:11:47 selsky Exp $
+ * $Horde: framework/Cipher/Cipher/BlockMode.php,v 1.14.12.13 2009-01-06 15:22:57 jan Exp $
  *
- * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -29,7 +29,7 @@ class Horde_Cipher_BlockMode {
      *
      * @param string $mode   The type of concrete Horde_Cipher_BlockMode
      *                       subclass to return.
-     * @param array $params  A hash containing any additional parameters a 
+     * @param array $params  A hash containing any additional parameters a
      *                       subclass might need.
      *
      * @return Horde_Cipher_BlockMode  The newly created concrete
@@ -39,16 +39,18 @@ class Horde_Cipher_BlockMode {
     function &factory($mode, $params = null)
     {
         $mode = basename($mode);
-        if (@file_exists(dirname(__FILE__) . '/BlockMode/' . $mode . '.php')) {
-            require_once dirname(__FILE__) . '/BlockMode/' . $mode . '.php';
+        $class = 'Horde_Cipher_BlockMode_' . $mode;
+        if (!class_exists($class)) {
+            include_once 'Horde/Cipher/BlockMode/' . $mode . '.php';
         }
 
-        $class = 'Horde_Cipher_BlockMode_' . $mode;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $blockmode = new $class($params);
         } else {
-            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            $blockmode = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
+
+        return $blockmode;
     }
 
     /**
