@@ -3,9 +3,9 @@
  * The Cipher_blowfish:: class implements the Cipher interface encryption data
  * using the Blowfish algorithm.
  *
- * $Horde: framework/Cipher/Cipher/blowfish.php,v 1.14.12.12 2008/01/02 11:30:25 jan Exp $
+ * $Horde: framework/Cipher/Cipher/blowfish.php,v 1.14.12.14 2009-01-06 15:22:57 jan Exp $
  *
- * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -327,11 +327,14 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
     function setKey($key)
     {
         $key = $this->_formatKey($key);
+        $keyLen = count($key);
+        if ($keyLen == 0) {
+            return false;
+        }
+
         $keyPos = 0;
         $keyXor = 0;
-
         $iMax = count($this->p);
-        $keyLen = count($key);
         for ($i = 0; $i < $iMax; $i++) {
             for ($t = 0; $t < 4; $t++) {
                 $keyXor = ($keyXor << 8) | (($key[$keyPos]) & 0x0ff);
