@@ -2,16 +2,15 @@
 /**
  * The Horde_Compress_gzip class allows gzip files to be read.
  *
- * $Horde: framework/Compress/Compress/gzip.php,v 1.7.12.4 2005/07/03 04:52:41 selsky Exp $
+ * $Horde: framework/Compress/Compress/gzip.php,v 1.7.12.13 2009-01-06 15:22:59 jan Exp $
  *
- * Copyright 2002-2005 Michael Cochrane <mike@graftonhall.co.nz>
- * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Cochrane <mike@graftonhall.co.nz>
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @since   Horde 3.0
  * @package Horde_Compress
  */
@@ -38,7 +37,7 @@ class Horde_Compress_gzip extends Horde_Compress {
      *
      * @return string  The uncompressed data.
      */
-    function &decompress(&$data, $params = array())
+    function decompress(&$data, $params = array())
     {
         /* If gzip is not compiled into PHP, return now. */
         if (!Util::extensionExists('zlib')) {
@@ -47,7 +46,10 @@ class Horde_Compress_gzip extends Horde_Compress {
 
         /* Gzipped File - decompress it first. */
         $position = 0;
-        $info = unpack('CCM/CFLG/VTime/CXFL/COS', substr($data, $position + 2));
+        $info = @unpack('CCM/CFLG/VTime/CXFL/COS', substr($data, $position + 2));
+        if (!$info) {
+            return PEAR::raiseError(_("Unable to decompress data."));
+        }
         $position += 10;
 
         if ($info['FLG'] & $this->_flags['FEXTRA']) {
@@ -74,7 +76,7 @@ class Horde_Compress_gzip extends Horde_Compress {
             $position += 2;
         }
 
-        $result = gzinflate(substr($data, $position, strlen($data) - $position));
+        $result = @gzinflate(substr($data, $position, strlen($data) - $position));
         if (empty($result)) {
             return PEAR::raiseError(_("Unable to decompress data."));
         }
