@@ -23,9 +23,9 @@ include_once 'Horde/Form/Renderer.php';
  * configuration of Horde applications, writing conf.php files from
  * conf.xml source files, generating user interfaces, etc.
  *
- * $Horde: framework/Horde/Horde/Config.php,v 1.80.2.37 2008/09/22 13:49:06 jan Exp $
+ * $Horde: framework/Horde/Horde/Config.php,v 1.80.2.40 2009-02-25 05:35:42 chuck Exp $
  *
- * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -648,7 +648,16 @@ class Horde_Config {
             'required' => true,
             'desc' => 'Internally used charset',
             'default' => $this->_default($ctx . '|charset', 'utf-8'));
-
+        $ssl = array(
+            '_type' => 'boolean',
+            'required' => false,
+            'desc' => 'Use SSL to connect to the server?',
+            'default' => $this->_default($ctx . '|ssl', false));
+        $ca = array(
+            '_type' => 'text',
+            'required' => false,
+            'desc' => 'Certification Authority to use for SSL connections',
+            'default' => $this->_default($ctx . '|ca', ''));
         $oci8_fields = array(
             'persistent' => $persistent,
             'username' => $username,
@@ -801,6 +810,8 @@ class Horde_Config {
                         'protocol' => $mysql_protocol,
                         'database' => $database,
                         'charset' => $charset,
+                        'ssl' => $ssl,
+                        'ca' => $ca,
                         'splitread' => $splitread)),
                 'mysqli' => array(
                     'desc' => 'MySQL (mysqli)',
@@ -810,7 +821,10 @@ class Horde_Config {
                         'protocol' => $mysql_protocol,
                         'database' => $database,
                         'charset' => $charset,
-                        'splitread' => $splitread)),
+                        'splitread' => $splitread,
+                        'ssl' => $ssl,
+                        'ca' => $ca
+            )),
                 'oci8' => array(
                     'desc' => 'Oracle',
                     'fields' => $oci8_fields),
