@@ -3,14 +3,14 @@
  * The DataTree_null:: class provides a dummy implementation of the
  * DataTree:: API; no data will last beyond a single page request.
  *
- * $Horde: framework/DataTree/DataTree/null.php,v 1.15.2.3 2005/05/26 20:31:41 selsky Exp $
+ * $Horde: framework/DataTree/DataTree/null.php,v 1.15.2.8 2009-01-06 15:23:02 jan Exp $
  *
- * Copyright 1999, 2000, 2001, 2002 Stephane Huther <shuther@bigfoot.com>
- * Copyright 2001, 2002 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
+ * @author  Stephane Huther <shuther1@free.fr>
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Horde 3.0
  * @package Horde_DataTree
@@ -61,6 +61,65 @@ class DataTree_null extends DataTree {
     {
     }
 
+    /**
+     * Check for existance of an object in a backend-specific manner.
+     *
+     * @param string $object_name Object name to check for.
+     *
+     * @return boolean True if the object exists, false otherwise.
+     */
+    function _exists($object_name)
+    {
+        return false;
+    }
+
+    /**
+     * Look up a datatree id by name.
+     *
+     * @param string $name
+     *
+     * @return integer DataTree id
+     */
+    function _getId($name)
+    {
+        return null;
+    }
+
+    /**
+     * Look up a datatree name by id.
+     *
+     * @param integer $id
+     *
+     * @return string DataTree name
+     */
+    function _getName($id)
+    {
+        return null;
+    }
+
+    /**
+     * Get a tree sorted by the specified attribute name and/or key.
+     *
+     * @since Horde 3.1
+     *
+     * @param string  $root       Which portion of the tree to sort.
+     *                            Defaults to all of it.
+     * @param boolean $loadTree   Sort the tree starting at $root, or just the
+     *                            requested level and direct parents?
+     *                            Defaults to single level.
+     * @param array $sortby_name  Attribute name to use for sorting.
+     * @param array $sortby_key   Attribute key to use for sorting.
+     * @param array $direction    Sort direction:
+     *                              0 - ascending
+     *                              1 - descending
+     *
+     * @return array TODO
+     */
+    function getSortedTree($root, $loadTree = false, $sortby_name = null, $sortby_key = null, $direction = 0)
+    {
+        return array();
+    }
+
     /**
      * Add an object. Part of the DataTree API that must be
      * overridden by subclasses.
@@ -249,18 +308,72 @@ class DataTree_null extends DataTree {
     }
 
     /**
-     * Return a set of object ids based on a set of attribute
-     * criteria.
+     * Returns a set of object ids based on a set of attribute criteria.
      *
-     * @param array $criteria  The array of criteria.
+     * @see buildAttributeQuery()
+     *
+     * @param array   $criteria     The array of criteria.
+     * @param string  $parent       The parent node to start searching from.
+     * @param boolean $allLevels    Return all levels, or just the direct
+     *                              children of $parent? Defaults to all levels.
+     * @param string  $restrict     Only return attributes with the same
+     *                              attribute_name or attribute_id.
+     * @param integer $from         The object to start to fetching
+     * @param integer $count        The number of objects to fetch
+     * @param string  $sortby_name  Attribute name to use for sorting.
+     * @param string  $sortby_key   Attribute key to use for sorting.
+     * @param integer $direction    Sort direction:
+     *                                0 - ascending
+     *                                1 - descending
      */
-    function getByAttributes($criteria)
+    function getByAttributes($criteria, $parent = DATATREE_ROOT, $allLevels = true, $restrict = 'name', $from = 0, $count = 0,
+                             $sortby_name = null, $sortby_key = null, $direction = 0)
     {
         if (!count($criteria)) {
-            return array();
+            return PEAR::raiseError('no criteria');
         }
 
-        return array_keys($this->_attributeCache);
+        $cids = array();
+        foreach (array_keys($this->_attributeCache) as $cid) {
+            $cids[$cid] = null;
+        }
+        return $cids;
+    }
+
+    /**
+     * Sorts IDs by attribute values. IDs without attributes will be
+     * added to the end of the sorted list.
+     *
+     * @param array $unordered_ids  Array of ids to sort.
+     * @param array $sortby_name    Attribute name to use for sorting.
+     * @param array $sortby_key     Attribute key to use for sorting.
+     * @param array $direction      Sort direction:
+     *                                0 - ascending
+     *                                1 - descending
+     *
+     * @return array  Sorted ids.
+     */
+    function sortByAttributes($unordered_ids, $sortby_name = null, $sortby_key = null, $direction = 0)
+    {
+        return $unordered_ids;
+    }
+
+    /**
+     * Returns a list of all of the available values of the given
+     * attribute name/key combination. Either attribute_name or
+     * attribute_key MUST be supplied, and both MAY be supplied.
+     *
+     * @param string $attribute_name  The name of the attribute.
+     * @param string $attribute_key   The key value of the attribute.
+     * @param string $parent          The parent node to start searching from.
+     * @param boolean $allLevels      Return all levels, or just the direct
+     *                                children of $parent?
+     *
+     * @return array  An array of all of the available values.
+     */
+    function getAttributeValues($attribute_name = null, $attribute_key = null, $parent = DATATREE_ROOT, $allLevels = true)
+    {
+        return array();
     }
 
     /**
@@ -291,4 +404,14 @@ class DataTree_null extends DataTree {
         return true;
     }
 
+    /**
+     * Init the object.
+     *
+     * @return boolean  True.
+     */
+    function _init()
+    {
+       return true;
+    }
+
 }
