@@ -31,7 +31,7 @@ define('HORDE_DATE_MASK_ALLPARTS', 63);
  * Horde Date wrapper/logic class, including some calculation
  * functions.
  *
- * $Horde: framework/Date/Date.php,v 1.8.10.9 2007/03/23 14:41:46 jan Exp $
+ * $Horde: framework/Date/Date.php,v 1.8.10.21 2010-10-19 20:20:13 jan Exp $
  *
  * @package Horde_Date
  */
@@ -80,17 +80,48 @@ class Horde_Date {
     var $sec = 0;
 
     /**
-     * Build a new date object. If $date contains date parts, use them
-     * to initialize the object.
+     * Internally supported strftime() specifiers.
+     *
+     * @var string
+     */
+    var $_supportedSpecs = '%CdDeHImMnRStTyY';
+
+    /**
+     * Build a new date object. If $date contains date parts, use them to
+     * initialize the object.
+     *
+     * Recognized formats:
+     * - arrays with keys 'year', 'month', 'mday', 'day' (since Horde 3.2),
+     *   'hour', 'min', 'minute' (since Horde 3.2), 'sec'
+     * - objects with properties 'year', 'month', 'mday', 'hour', 'min', 'sec'
+     * - yyyy-mm-dd hh:mm:ss (since Horde 3.1)
+     * - yyyymmddhhmmss (since Horde 3.1)
+     * - yyyymmddThhmmssZ (since Horde 3.1.4)
+     * - unix timestamps
      */
     function Horde_Date($date = null)
     {
+        if (function_exists('nl_langinfo')) {
+            $this->_supportedSpecs .= 'bBpxX';
+        }
+
         if (is_array($date) || is_object($date)) {
             foreach ($date as $key => $val) {
                 if (in_array($key, array('year', 'month', 'mday', 'hour', 'min', 'sec'))) {
                     $this->$key = (int)$val;
                 }
             }
+
+            // If $date['day'] is present and numeric we may have been passed
+            // a Horde_Form_datetime array.
+            if (is_array($date) && isset($date['day']) &&
+                is_numeric($date['day'])) {
+                $this->mday = (int)$date['day'];
+            }
+            // 'minute' key also from Horde_Form_datetime
+            if (is_array($date) && isset($date['minute'])) {
+                $this->min = $date['minute'];
+            }
         } elseif (!is_null($date)) {
             // Match YYYY-MM-DD HH:MM:SS, YYYYMMDDHHMMSS and YYYYMMDD'T'HHMMSS'Z'.
             if (preg_match('/(\d{4})-?(\d{2})-?(\d{2})T? ?(\d{2}):?(\d{2}):?(\d{2})Z?/', $date, $parts)) {
@@ -115,26 +146,6 @@ class Horde_Date {
         }
     }
 
-    /**
-     * Return the unix timestamp representation of this date.
-     *
-     * @return integer  A unix timestamp.
-     */
-    function timestamp()
-    {
-        return @mktime($this->hour, $this->min, $this->sec, $this->month, $this->mday, $this->year);
-    }
-
-    /**
-     * Return the unix timestamp representation of this date, 12:00am.
-     *
-     * @return integer  A unix timestamp.
-     */
-    function datestamp()
-    {
-        return @mktime(0, 0, 0, $this->month, $this->mday, $this->year);
-    }
-
     /**
      * @static
      */
@@ -228,32 +239,44 @@ class Horde_Date {
     }
 
     /**
-     * Returns week of the year, first Monday is first day of first
-     * week.
+     * Returns the week of the month.
+     *
+     * @since Horde 3.2
+     *
+     * @return integer  The week number.
+     */
+    function weekOfMonth()
+    {
+        return ceil($this->mday / 7);
+    }
+
+    /**
+     * Returns the week of the year, first Monday is first day of first week.
      *
      * @return integer  The week number.
      */
     function weekOfYear()
     {
-        return date('W', $this->timestamp());
+        return $this->format('W');
     }
 
     /**
      * Return the number of weeks in the given year (52 or 53).
      *
+     * @static
+     *
      * @param integer $year  The year to count the number of weeks in.
      *
-     * @return integer $numWeeks      The number of weeks in $year.
+     * @return integer $numWeeks   The number of weeks in $year.
      */
     function weeksInYear($year)
     {
         // Find the last Thursday of the year.
         $day = 31;
-        while (date('w', mktime(0, 0, 0, 12, $day, $year)) != HORDE_DATE_THURSDAY) {
-            --$day;
+        $date = new Horde_Date(array('year' => $year, 'month' => 12, 'mday' => $day, 'hour' => 0, 'min' => 0, 'sec' => 0));
+        while ($date->dayOfWeek() != HORDE_DATE_THURSDAY) {
+            --$date->mday;
         }
-
-        $date = new Horde_Date(array('year' => $year, 'month' => 12, 'mday' => $day));
         return $date->weekOfYear();
     }
 
@@ -385,11 +408,12 @@ class Horde_Date {
 
         if ($this->year != $date->year) {
             return $this->year - $date->year;
-        } elseif ($this->month != $date->month) {
-            return $this->month - $date->month;
-        } else {
-            return $this->mday - $date->mday;
         }
+        if ($this->month != $date->month) {
+            return $this->month - $date->month;
+        }
+
+        return $this->mday - $date->mday;
     }
 
     /**
@@ -411,11 +435,12 @@ class Horde_Date {
 
         if ($this->hour != $date->hour) {
             return $this->hour - $date->hour;
-        } elseif ($this->min != $date->min) {
-            return $this->min - $date->min;
-        } else {
-            return $this->sec - $date->sec;
         }
+        if ($this->min != $date->min) {
+            return $this->min - $date->min;
+        }
+
+        return $this->sec - $date->sec;
     }
 
     /**
@@ -437,9 +462,9 @@ class Horde_Date {
 
         if ($diff = $this->compareDate($date)) {
             return $diff;
-        } else {
-            return $this->compareTime($date);
         }
+
+        return $this->compareTime($date);
     }
 
     /**
@@ -451,7 +476,7 @@ class Horde_Date {
      */
     function tzOffset($colon = true)
     {
-        $secs = date('Z', $this->timestamp());
+        $secs = $this->format('Z');
 
         if ($secs < 0) {
             $sign = '-';
@@ -466,17 +491,68 @@ class Horde_Date {
     }
 
     /**
-     * Format time in ISO-8601 format.
+     * Return the unix timestamp representation of this date.
+     *
+     * @return integer  A unix timestamp.
+     */
+    function timestamp()
+    {
+        if (class_exists('DateTime')) {
+            return $this->format('U');
+        } else {
+            return Horde_Date::_mktime($this->hour, $this->min, $this->sec, $this->month, $this->mday, $this->year);
+        }
+    }
+
+    /**
+     * Return the unix timestamp representation of this date, 12:00am.
+     *
+     * @return integer  A unix timestamp.
+     */
+    function datestamp()
+    {
+        if (class_exists('DateTime')) {
+            $this->_setTimeZone();
+            $dt = new DateTime();
+            $dt->setDate($this->year, $this->month, $this->mday);
+            $dt->setTime(0, 0, 0);
+            return $dt->format('U');
+        } else {
+            return Horde_Date::_mktime(0, 0, 0, $this->month, $this->mday, $this->year);
+        }
+    }
+
+    /**
+     * Format time using the specifiers available in date() or in the DateTime
+     * class' format() method.
+     *
+     * @since Horde 3.3
+     *
+     * @param string $format
+     *
+     * @return string  Formatted time.
+     */
+    function format($format)
+    {
+        if (class_exists('DateTime')) {
+            $this->_setTimeZone();
+            $dt = new DateTime();
+            $dt->setDate($this->year, $this->month, $this->mday);
+            $dt->setTime($this->hour, $this->min, $this->sec);
+            return $dt->format($format);
+        } else {
+            return date($format, $this->timestamp());
+        }
+    }
+
+    /**
+     * Format time in ISO-8601 format. Works correctly since Horde 3.2.
      *
      * @return string  Date and time in ISO-8601 format.
      */
     function iso8601DateTime()
     {
-        $tzoff = $this->tzOffset();
-        $date = $this->year . '-' . $this->month . '-' . $this->mday;
-        $time = $this->hour . ':' . $this->min . ':' . $this->sec;
-
-        return $date . 'T' . $time . $tzoff;
+        return $this->rfc3339DateTime() . $this->tzOffset();
     }
 
     /**
@@ -486,17 +562,32 @@ class Horde_Date {
      */
     function rfc2822DateTime()
     {
-        return date('D, j M Y H:i:s ', $this->timestamp()) . $this->tzOffset(false);
+        return $this->format('D, j M Y H:i:s') . ' ' . $this->tzOffset(false);
     }
 
     /**
      * Format time in RFC 3339 format.
      *
-     * @return string  Date and time in RFC 3339 format.
+     * @since Horde 3.1
+     *
+     * @return string  Date and time in RFC 3339 format. The seconds part has
+     *                 been added with Horde 3.2.
      */
     function rfc3339DateTime()
     {
-        return date('Y-m-d\TH:i', $this->timestamp());
+        return $this->format('Y-m-d\TH:i:s');
+    }
+
+    /**
+     * Format time in the format we use for SQL queries.
+     *
+     * @since Horde 3.3.6
+     *
+     * @return string  Date and time in SQL format.
+     */
+    function sqlDateTime()
+    {
+        return $this->format('Y-m-d H:i:s');
     }
 
     /**
@@ -504,19 +595,200 @@ class Horde_Date {
      *
      * @return string  Date and time.
      */
-    function cTime($time = false)
+    function cTime()
     {
-        return date('D M j H:i:s Y', $this->timestamp());
+        return $this->format('D M j H:i:s Y');
     }
 
     /**
      * Format date and time using strftime() format.
      *
+     * @since Horde 3.1
+     *
      * @return string  strftime() formatted date and time.
      */
     function strftime($format)
     {
-        return strftime($format, $this->timestamp());
+        if (preg_match('/%[^' . $this->_supportedSpecs . ']/', $format)) {
+            return strftime($format, $this->timestamp());
+        } else {
+            return $this->_strftime($format);
+        }
+    }
+
+    /**
+     * Format date and time using a limited set of the strftime() format.
+     *
+     * @return string  strftime() formatted date and time.
+     */
+    function _strftime($format)
+    {
+        if (preg_match('/%[bBpxX]/', $format)) {
+            require_once 'Horde/NLS.php';
+        }
+
+        return preg_replace(
+            array('/%b/e',
+                  '/%B/e',
+                  '/%C/e',
+                  '/%d/e',
+                  '/%D/e',
+                  '/%e/e',
+                  '/%H/e',
+                  '/%I/e',
+                  '/%m/e',
+                  '/%M/e',
+                  '/%n/',
+                  '/%p/e',
+                  '/%R/e',
+                  '/%S/e',
+                  '/%t/',
+                  '/%T/e',
+                  '/%x/e',
+                  '/%X/e',
+                  '/%y/e',
+                  '/%Y/',
+                  '/%%/'),
+            array('$this->_strftime(NLS::getLangInfo(constant(\'ABMON_\' . (int)$this->month)))',
+                  '$this->_strftime(NLS::getLangInfo(constant(\'MON_\' . (int)$this->month)))',
+                  '(int)($this->year / 100)',
+                  'sprintf(\'%02d\', $this->mday)',
+                  '$this->_strftime(\'%m/%d/%y\')',
+                  'sprintf(\'%2d\', $this->mday)',
+                  'sprintf(\'%02d\', $this->hour)',
+                  'sprintf(\'%02d\', $this->hour == 0 ? 12 : ($this->hour > 12 ? $this->hour - 12 : $this->hour))',
+                  'sprintf(\'%02d\', $this->month)',
+                  'sprintf(\'%02d\', $this->min)',
+                  "\n",
+                  '$this->_strftime(NLS::getLangInfo($this->hour < 12 ? AM_STR : PM_STR))',
+                  '$this->_strftime(\'%H:%M\')',
+                  'sprintf(\'%02d\', $this->sec)',
+                  "\t",
+                  '$this->_strftime(\'%H:%M:%S\')',
+                  '$this->_strftime(NLS::getLangInfo(D_FMT))',
+                  '$this->_strftime(NLS::getLangInfo(T_FMT))',
+                  'substr(sprintf(\'%04d\', $this->year), -2)',
+                  (int)$this->year,
+                  '%'),
+            $format);
+    }
+
+    /**
+     * mktime() implementation that supports dates outside of 1970-2038,
+     * from http://phplens.com/phpeverywhere/adodb_date_library.
+     *
+     * @TODO remove in Horde 4
+     *
+     * This does NOT work with pre-1970 daylight saving times.
+     *
+     * @static
+     */
+    function _mktime($hr, $min, $sec, $mon = false, $day = false,
+                     $year = false, $is_dst = false, $is_gmt = false)
+    {
+        if ($mon === false) {
+            return $is_gmt
+                ? @gmmktime($hr, $min, $sec)
+                : @mktime($hr, $min, $sec);
+        }
+
+        if ($year > 1901 && $year < 2038 &&
+            ($year >= 1970 || version_compare(PHP_VERSION, '5.0.0', '>='))) {
+            return $is_gmt
+                ? @gmmktime($hr, $min, $sec, $mon, $day, $year)
+                : @mktime($hr, $min, $sec, $mon, $day, $year);
+        }
+
+        $gmt_different = $is_gmt
+            ? 0
+            : (mktime(0, 0, 0, 1, 2, 1970, 0) - gmmktime(0, 0, 0, 1, 2, 1970, 0));
+
+        $mon = intval($mon);
+        $day = intval($day);
+        $year = intval($year);
+
+        if ($mon > 12) {
+            $y = floor($mon / 12);
+            $year += $y;
+            $mon -= $y * 12;
+        } elseif ($mon < 1) {
+            $y = ceil((1 - $mon) / 12);
+            $year -= $y;
+            $mon += $y * 12;
+        }
+
+        $_day_power = 86400;
+        $_hour_power = 3600;
+        $_min_power = 60;
+
+        $_month_table_normal = array('', 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
+        $_month_table_leaf = array('', 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
+
+        $_total_date = 0;
+        if ($year >= 1970) {
+            for ($a = 1970; $a <= $year; $a++) {
+                $leaf = Horde_Date::isLeapYear($a);
+                if ($leaf == true) {
+                    $loop_table = $_month_table_leaf;
+                    $_add_date = 366;
+                } else {
+                    $loop_table = $_month_table_normal;
+                    $_add_date = 365;
+                }
+                if ($a < $year) {
+                    $_total_date += $_add_date;
+                } else {
+                    for ($b = 1; $b < $mon; $b++) {
+                        $_total_date += $loop_table[$b];
+                    }
+                }
+            }
+
+            return ($_total_date + $day - 1) * $_day_power + $hr * $_hour_power + $min * $_min_power + $sec + $gmt_different;
+        }
+
+        for ($a = 1969 ; $a >= $year; $a--) {
+            $leaf = Horde_Date::isLeapYear($a);
+            if ($leaf == true) {
+                $loop_table = $_month_table_leaf;
+                $_add_date = 366;
+            } else {
+                $loop_table = $_month_table_normal;
+                $_add_date = 365;
+            }
+            if ($a > $year) {
+                $_total_date += $_add_date;
+            } else {
+                for ($b = 12; $b > $mon; $b--) {
+                    $_total_date += $loop_table[$b];
+                }
+            }
+        }
+
+        $_total_date += $loop_table[$mon] - $day;
+        $_day_time = $hr * $_hour_power + $min * $_min_power + $sec;
+        $_day_time = $_day_power - $_day_time;
+        $ret = -($_total_date * $_day_power + $_day_time - $gmt_different);
+        if ($ret < -12220185600) {
+            // If earlier than 5 Oct 1582 - gregorian correction.
+            return $ret + 10 * 86400;
+        } elseif ($ret < -12219321600) {
+            // If in limbo, reset to 15 Oct 1582.
+            return -12219321600;
+        } else {
+            return $ret;
+        }
+    }
+
+    /**
+     * Sets the current timezone, if available.
+     */
+    function _setTimeZone()
+    {
+        $tz = getenv('TZ');
+        if (!empty($tz)) {
+            date_default_timezone_set($tz);
+        }
     }
 
 }
