@@ -1,26 +1,37 @@
 <?php
 
+require_once 'Horde/Auth.php';
 require_once 'Horde/DataTree.php';
 require_once 'Horde/History.php';
+require_once 'Horde/SessionObjects.php';
+
+/** The parent Group node */
+define('GROUP_ROOT', -1);
 
 /**
  * The Group:: class provides the Horde groups system.
  *
- * $Horde: framework/Group/Group.php,v 1.67.2.16 2007/01/02 13:54:20 jan Exp $
+ * $Horde: framework/Group/Group.php,v 1.67.2.22 2009-01-06 15:23:08 jan Exp $
  *
- * Copyright 1999-2007 Stephane Huther <shuther@bigfoot.com>
- * Copyright 2001-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Stephane Huther <shuther@bigfoot.com>
+ * @author  Stephane Huther <shuther1@free.fr>
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Horde 2.1
  * @package Horde_Group
  */
 class Group {
 
+    /**
+     * Group driver parameters
+     *
+     * @var array
+     */
+    var $_params;
+
     /**
      * Pointer to a DataTree instance to manage the different groups.
      *
@@ -29,9 +40,85 @@ class Group {
     var $_datatree;
 
     /**
-     * Constructor
+     * Cache of previously retrieved group objects.
+     *
+     * @var array
      */
-    function Group()
+    var $_groupCache = array();
+
+    /**
+     * Id-name-map of already cached group objects.
+     *
+     * @var array
+     */
+    var $_groupMap = array();
+
+    /**
+     * Id-name-hash of all existing groups.
+     *
+     * @var array
+     */
+    var $_groupList;
+
+    /**
+     * List of sub groups.
+     *
+     * @see listAllUsers()
+     * @var array
+     */
+    var $_subGroups = array();
+
+    /**
+     * Cache of parent groups.
+     *
+     * This is an array with group IDs as keys and the integer group id of the
+     * direct parent as values.
+     *
+     * @see getGroupParent
+     * @var array
+     */
+    var $_groupParents = array();
+
+    /**
+     * Cache of parent group trees.
+     *
+     * This is an array with group IDs as keys and id-name-hashes of all
+     * parents as values.
+     *
+     * @see getGroupParentList
+     * @var array
+     */
+    var $_groupParentList = array();
+
+    /**
+     * Cache of parents tree.
+     *
+     * @see getGroupParents()
+     * @var array
+     */
+    var $_parentTree = array();
+
+    /**
+     * Hash of groups of certain users.
+     *
+     * @see getGroupMemberShips()
+     * @var array
+     */
+    var $_userGroups;
+
+    /**
+     * Constructor.
+     */
+    function Group($params)
+    {
+        $this->_params = $params;
+        $this->__wakeup();
+    }
+
+    /**
+     * Initializes the object.
+     */
+    function __wakeup()
     {
         global $conf;
 
@@ -43,23 +130,28 @@ class Group {
         $this->_datatree = &DataTree::singleton($driver,
                                                 array_merge(Horde::getDriverConfig('datatree', $driver),
                                                             array('group' => 'horde.groups')));
+
+        foreach (array_keys($this->_groupCache) as $name) {
+            $this->_groupCache[$name]->setGroupOb($this);
+            $this->_groupCache[$name]->setDataTree($this->_datatree);
+        }
     }
 
     /**
-     * Return a new group object.
+     * Returns a new group object.
      *
      * @param string $name    The group's name.
      * @param string $parent  The group's parent's name.
      *
      * @return DataTreeObject_Group  A new group object.
      */
-    function &newGroup($name, $parent = DATATREE_ROOT)
+    function &newGroup($name, $parent = GROUP_ROOT)
     {
         if (empty($name)) {
             return PEAR::raiseError(_("Group names must be non-empty"));
         }
 
-        if ($parent != DATATREE_ROOT) {
+        if ($parent != GROUP_ROOT) {
             $name = $this->getGroupName($parent) . ':' . DataTree::encodeName($name);
         }
 
@@ -69,48 +161,49 @@ class Group {
     }
 
     /**
-     * Return a DataTreeObject_Group object corresponding to the named
-     * group, with the users and other data retrieved appropriately.
+     * Returns a DataTreeObject_Group object corresponding to the named group,
+     * with the users and other data retrieved appropriately.
      *
      * @param string $name The name of the group to retrieve.
      */
     function &getGroup($name)
     {
-        /* cache of previous retrieved groups */
-        static $groupCache;
-
-        if (!is_array($groupCache)) {
-            $groupCache = array();
-        }
-
-        if (!isset($groupCache[$name])) {
-            $groupCache[$name] = $this->_datatree->getObject($name, 'DataTreeObject_Group');
-            if (!is_a($groupCache[$name], 'PEAR_Error')) {
-                $groupCache[$name]->setGroupOb($this);
+        if (!isset($this->_groupCache[$name])) {
+            $this->_groupCache[$name] = &$this->_datatree->getObject($name, 'DataTreeObject_Group');
+            if (!is_a($this->_groupCache[$name], 'PEAR_Error')) {
+                $this->_groupCache[$name]->setGroupOb($this);
+                $this->_groupMap[$this->_groupCache[$name]->getId()] = $name;
             }
         }
 
-        return $groupCache[$name];
+        return $this->_groupCache[$name];
     }
 
     /**
-     * Return a DataTreeObject_Group object corresponding to the given
-     * unique ID, with the users and other data retrieved
-     * appropriately.
+     * Returns a DataTreeObject_Group object corresponding to the given unique
+     * ID, with the users and other data retrieved appropriately.
      *
      * @param integer $cid  The unique ID of the group to retrieve.
      */
     function &getGroupById($cid)
     {
-        $group = $this->_datatree->getObjectById($cid, 'DataTreeObject_Group');
-        if (!is_a($group, 'PEAR_Error')) {
-            $group->setGroupOb($this);
+        if (isset($this->_groupMap[$cid])) {
+            $group = $this->_groupCache[$this->_groupMap[$cid]];
+        } else {
+            $group = $this->_datatree->getObjectById($cid, 'DataTreeObject_Group');
+            if (!is_a($group, 'PEAR_Error')) {
+                $group->setGroupOb($this);
+                $name = $group->getName();
+                $this->_groupCache[$name] = &$group;
+                $this->_groupMap[$cid] = $name;
+            }
         }
+
         return $group;
     }
 
     /**
-     * Get a globally unique ID for a group.
+     * Returns a globally unique ID for a group.
      *
      * @param DataTreeObject_Group $group  The group.
      *
@@ -122,9 +215,9 @@ class Group {
     }
 
     /**
-     * Add a group to the groups system. The group must first be
-     * created with Group::newGroup(), and have any initial users
-     * added to it, before this function is called.
+     * Adds a group to the groups system. The group must first be created with
+     * Group::newGroup(), and have any initial users added to it, before this
+     * function is called.
      *
      * @param DataTreeObject_Group $group  The new group object.
      */
@@ -138,6 +231,14 @@ class Group {
             return $result;
         }
 
+        $id = $group->getId();
+        $name = $group->getName();
+        $this->_groupCache[$name] = &$group;
+        $this->_groupMap[$id] = $name;
+        if (isset($this->_groupList)) {
+            $this->_groupList[$id] = $name;
+        }
+
         /* Log the addition of the group in the history log. */
         $history = &Horde_History::singleton();
         $log = $history->log($this->getGUID($group), array('action' => 'add'), true);
@@ -149,7 +250,7 @@ class Group {
     }
 
     /**
-     * Store updated data - users, etc. - of a group to the backend system.
+     * Stores updated data - users, etc. - of a group to the backend system.
      *
      * @param DataTreeObject_Group $group  The group to update.
      */
@@ -163,6 +264,8 @@ class Group {
             return $result;
         }
 
+        $this->_groupCache[$group->getName()] = &$group;
+
         /* Log the update of the group users on the history log. */
         $history = &Horde_History::singleton();
         $guid = $this->getGUID($group);
@@ -177,30 +280,7 @@ class Group {
     }
 
     /**
-     * Change the name of a group without changing its contents or
-     * where it is in the groups hierarchy.
-     *
-     * @param DataTreeObject_Group $group  The group to rename.
-     * @param string $newName              The group's new name.
-     */
-    function renameGroup($group, $newName)
-    {
-        if (!is_a($group, 'DataTreeObject_Group')) {
-            return PEAR::raiseError('Groups must be DataTreeObject_Group objects or extend that class.');
-        }
-        $result = $this->_datatree->rename($group, $newName);
-        if (is_a($result, 'PEAR_Error')) {
-            return $result;
-        }
-
-        /* History Log the name change of the group. */
-        $history = &Horde_History::singleton();
-        $history->log($this->getGUID($group), array('action' => 'rename'), true);
-        return $result;
-    }
-
-    /**
-     * Remove a group from the groups system permanently.
+     * Removes a group from the groups system permanently.
      *
      * @param DataTreeObject_Group $group  The group to remove.
      * @param boolean $force               Force to remove every child.
@@ -211,6 +291,13 @@ class Group {
             return PEAR::raiseError('Groups must be DataTreeObject_Group objects or extend that class.');
         }
 
+        $id = $group->getId();
+        unset($this->_groupMap[$id]);
+        if (isset($this->_groupList)) {
+            unset($this->_groupList[$id]);
+        }
+        unset($this->_groupCache[$group->getName()]);
+
         $history = &Horde_History::singleton();
         $history->log($this->getGUID($group), array('action' => 'delete'), true);
 
@@ -218,19 +305,28 @@ class Group {
     }
 
     /**
-     * Retrieve the name of a group.
+     * Retrieves the name of a group.
      *
-     * @param integer $gid  The id of the group to retrieve the name for.
+     * @param integer|DataTreeObject_Group $gid  The id of the group or the
+     *                                           group object to retrieve the
+     *                                           name for.
      *
      * @return string  The group's name.
      */
     function getGroupName($gid)
     {
         if (is_a($gid, 'DataTreeObject_Group')) {
-            return $this->_datatree->getName($gid->getId());
-        } else {
-            return $this->_datatree->getName($gid);
+            $gid = $gid->getId();
         }
+
+        if (isset($this->_groupMap[$gid])) {
+            return $this->_groupMap[$gid];
+        }
+        if (isset($this->_groupList[$gid])) {
+            return $this->_groupList[$gid];
+        }
+
+        return $this->_datatree->getName($gid);
     }
 
     /**
@@ -246,19 +342,31 @@ class Group {
     }
 
     /**
-     * Retrieve the ID of a group.
+     * Retrieves the ID of a group.
      *
-     * @param string $group  The group to retrieve the ID for.
+     * @param string|DataTreeObject_Group $group  The group name or object to
+     *                                            retrieve the ID for.
      *
      * @return integer  The group's ID.
      */
     function getGroupId($group)
     {
         if (is_a($group, 'DataTreeObject_Group')) {
-            return $this->_datatree->getId($group->getName());
-        } else {
-            return $this->_datatree->getId($group);
+            $group = $group->getName();
         }
+
+        $id = array_search($group, $this->_groupMap);
+        if ($id !== false) {
+            return $id;
+        }
+        if (isset($this->_groupList)) {
+            $id = array_search($group, $this->_groupList);
+            if ($id !== false) {
+                return $id;
+            }
+        }
+
+        return $this->_datatree->getId($group);
     }
 
     /**
@@ -270,65 +378,93 @@ class Group {
      */
     function exists($group)
     {
+        if (isset($this->_groupCache[$group]) ||
+            (isset($this->_groupList) &&
+             array_search($group, $this->_groupList) !== false)) {
+            return true;
+        }
+
         return $this->_datatree->exists($group);
     }
 
     /**
-     * Get a list of the parents of a child group.
+     * Returns a tree of the parents of a child group.
      *
-     * @param integer $gid The id of the child group.
+     * @param integer $gid  The id of the child group.
      *
-     * @return array
+     * @return array  The group parents tree, with groupnames as the keys.
      */
     function getGroupParents($gid)
     {
-        $name = $this->getGroupName($gid);
-        return $this->_datatree->getParents($name);
+        if (!isset($this->_parentTree[$gid])) {
+            $name = $this->getGroupName($gid);
+            $parents = $this->_datatree->getParents($name);
+            if (is_a($parents, 'PEAR_Error')) {
+                return $parents;
+            }
+            $this->_parentTree[$gid] = $parents;
+        }
+
+        return $this->_parentTree[$gid];
     }
 
     /**
-     * Return the single parent of the given group.
+     * Returns the single parent ID of the given group.
      *
      * @param integer $gid  The DataTree ID of the child group.
      *
-     * @return the parent of the given group.
+     * @return integer  The parent of the given group.
      */
     function getGroupParent($gid)
     {
-        return $this->_datatree->getParentById($gid);
+        if (!isset($this->_groupParents[$gid])) {
+            $parent = $this->_datatree->getParentById($gid);
+            if (is_a($parent, 'PEAR_Error')) {
+                return $parent;
+            }
+            $this->_groupParents[$gid] = $parent;
+        }
+
+        return $this->_groupParents[$gid];
     }
 
     /**
-     * Get a list of parents all the way up to the root object for $group.
+     * Returns a flat list of the parents of a child group
      *
      * @param integer $gid  The id of the group.
      *
-     * @return array  A flat list of all of the parents of $group,
-     *                hashed in $id => $name format.
+     * @return array  A flat list of all of the parents of $group, hashed in
+     *                $id => $name format.
      */
     function getGroupParentList($gid)
     {
-        return $this->_datatree->getParentList($gid);
+        if (!isset($this->_groupParentList[$gid])) {
+            $parents = $this->_datatree->getParentList($gid);
+            if (is_a($parents, 'PEAR_Error')) {
+                return $parents;
+            }
+            $this->_groupParentList[$gid] = $parents;
+        }
+
+        return $this->_groupParentList[$gid];
     }
 
     /**
-     * Get a list of every group, in the format cid => groupname.
+     * Returns a list of all groups, in the format id => groupname.
      *
-     * @param boolean $refresh  If true, the cached value is ignored and the group
-     *                          list is refreshed from the group backend.
+     * @param boolean $refresh  If true, the cached value is ignored and the
+     *                          group list is refreshed from the group backend.
      *
-     * @return array  CID => groupname hash.
+     * @return array  ID => groupname hash.
      */
     function listGroups($refresh = false)
     {
-        static $groups;
-
-        if ($refresh || is_null($groups)) {
-            $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, DATATREE_ROOT, true);
-            unset($groups[DATATREE_ROOT]);
+        if ($refresh || !isset($this->_groupList)) {
+            $this->_groupList = $this->_datatree->get(DATATREE_FORMAT_FLAT, GROUP_ROOT, true);
+            unset($this->_groupList[GROUP_ROOT]);
         }
 
-        return $groups;
+        return $this->_groupList;
     }
 
     /**
@@ -363,15 +499,17 @@ class Group {
      */
     function listAllUsers($gid)
     {
-        // Get a list of every group that is a sub-group of $group.
-        $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, $this->getGroupName($gid), true);
-        if (is_a($groups, 'PEAR_Error')) {
-            return $groups;
+        if (!isset($this->_subGroups[$gid])) {
+            // Get a list of every group that is a sub-group of $group.
+            $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, $this->getGroupName($gid), true);
+            if (is_a($groups, 'PEAR_Error')) {
+                return $groups;
+            }
+            $this->_subGroups[$gid] = array_keys($groups);
         }
 
-        $groups = array_keys($groups);
         $users = array();
-        foreach ($groups as $groupId) {
+        foreach ($this->_subGroups[$gid] as $groupId) {
             $users = array_merge($users, $this->listUsers($groupId));
         }
         return array_values(array_flip(array_flip($users)));
@@ -387,9 +525,7 @@ class Group {
      */
     function getGroupMemberships($user, $parentGroups = false)
     {
-        static $cache;
-
-        if (empty($cache[$user])) {
+        if (!isset($this->_userGroups[$user])) {
             $criteria = array(
                 'AND' => array(
                     array('field' => 'name', 'op' => '=', 'test' => 'user'),
@@ -397,8 +533,7 @@ class Group {
             $groups = $this->_datatree->getByAttributes($criteria);
 
             if (is_a($groups, 'PEAR_Error')) {
-                Horde::logMessage($groups, __FILE__, __LINE__, PEAR_LOG_ERROR);
-                return false;
+                return $groups;
             }
 
             if ($parentGroups) {
@@ -411,10 +546,10 @@ class Group {
                 }
             }
 
-            $cache[$user] = $groups;
+            $this->_userGroups[$user] = $groups;
         }
 
-        return $cache[$user];
+        return $this->_userGroups[$user];
     }
 
     /**
@@ -450,8 +585,8 @@ class Group {
     }
 
     /**
-     * Returns the DataTree level of the given group. 0 is returned for
-     * and object directly below DATATREE_ROOT.
+     * Returns the nesting level of the given group. 0 is returned for any
+     * object directly below GROUP_ROOT.
      *
      * @param integer $gid  The DataTree ID of the group.
      *
@@ -459,10 +594,32 @@ class Group {
      */
     function getLevel($gid)
     {
-        $name = $this->_datatree->getName($gid);
+        $name = $this->getGroupName($gid);
         return substr_count($name, ':');
     }
 
+    /**
+     * Stores the object in the session cache.
+     */
+    function shutdown()
+    {
+        $session = new Horde_SessionObjects();
+        $session->overwrite('horde_group', $this, false);
+    }
+
+    /**
+     * Returns the properties that need to be serialized.
+     *
+     * @return array  List of serializable properties.
+     */
+    function __sleep()
+    {
+        $properties = get_object_vars($this);
+        unset($properties['_datatree']);
+        $properties = array_keys($properties);
+        return $properties;
+    }
+
     /**
      * Attempts to return a concrete Group instance based on $driver.
      *
@@ -475,14 +632,11 @@ class Group {
      */
     function &factory($driver = '', $params = null)
     {
-        $driver = basename($driver);
-
-        if (@file_exists(dirname(__FILE__) . '/Group/' . $driver . '.php')) {
-            require_once dirname(__FILE__) . '/Group/' . $driver . '.php';
-        } else {
-            @include_once 'Horde/Group/' . $driver . '.php';
+        if (is_null($params)) {
+            $params = Horde::getDriverConfig('group', $driver);
         }
-        $class = 'Group_' . $driver;
+
+        $class = Group::_loadDriver($driver);
         if (class_exists($class)) {
             $group = &new $class($params);
         } else {
@@ -505,23 +659,56 @@ class Group {
     {
         static $group;
 
-        if (!isset($group)) {
-            global $conf;
+        if (isset($group)) {
+            return $group;
+        }
 
-            require_once 'Horde/Auth.php';
-            $auth = &Auth::singleton($conf['auth']['driver']);
-            if ($auth->hasCapability('groups')) {
-                $group = &Group::factory($auth->getDriver(), $auth);
-            } elseif (!empty($conf['group']['driver']) && $conf['group']['driver'] != 'datatree') {
-                $group = &Group::factory($conf['group']['driver']);
-            } else {
-                $group = new Group();
-            }
+        $group_driver = null;
+        $group_params = null;
+        $auth = &Auth::singleton($GLOBALS['conf']['auth']['driver']);
+        if ($auth->hasCapability('groups')) {
+            $group_driver = $auth->getDriver();
+            $group_params = $auth;
+        } elseif (!empty($GLOBALS['conf']['group']['driver']) &&
+                  $GLOBALS['conf']['group']['driver'] != 'datatree') {
+            $group_driver = $GLOBALS['conf']['group']['driver'];
+            $group_params = Horde::getDriverConfig('group', $group_driver);
+        }
+
+        Group::_loadDriver($group_driver);
+
+        $group = null;
+        if (!empty($GLOBALS['conf']['group']['cache'])) {
+            $session = new Horde_SessionObjects();
+            $group = $session->query('horde_group');
+        }
+
+        if (!$group) {
+            $group = Group::factory($group_driver, $group_params);
+        }
+
+        if (!empty($GLOBALS['conf']['group']['cache'])) {
+            register_shutdown_function(array(&$group, 'shutdown'));
         }
 
         return $group;
     }
 
+    function _loadDriver($driver)
+    {
+        if (!$driver) {
+            $class = 'Group';
+        } else {
+            $driver = basename($driver);
+            $class = 'Group_' . $driver;
+            if (!class_exists($class)) {
+                include 'Horde/Group/' . $driver . '.php';
+            }
+        }
+
+        return $class;
+    }
+
 }
 
 /**
@@ -564,6 +751,19 @@ class DataTreeObject_Group extends DataTreeObject {
         parent::DataTreeObject($name);
     }
 
+    /**
+     * Returns the properties that need to be serialized.
+     *
+     * @return array  List of serializable properties.
+     */
+    function __sleep()
+    {
+        $properties = get_object_vars($this);
+        unset($properties['datatree'], $properties['_groupOb']);
+        $properties = array_keys($properties);
+        return $properties;
+    }
+
     /**
      * Associates a Group object with this group.
      *
