@@ -4,9 +4,9 @@
  * addition of adding support for hook functions to define if a user
  * is in a group.
  *
- * $Horde: framework/Group/Group/hooks.php,v 1.7.2.11 2007/01/02 13:54:20 jan Exp $
+ * $Horde: framework/Group/Group/hooks.php,v 1.7.2.16 2009-01-06 15:23:08 jan Exp $
  *
- * Copyright 2003-2007 Jason Rust <jrust@rustyparts.com>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -17,13 +17,16 @@
  */
 class Group_hooks extends Group {
 
+    var $_hookFunction = false;
+
     /**
      * Constructor.
      */
-    function Group_hooks()
+    function Group_hooks($params)
     {
-        parent::Group();
-        require $GLOBALS['registry']->get('fileroot', 'horde') . '/config/hooks.php';
+        parent::Group($params);
+        Horde::loadConfiguration('hooks.php', null, 'horde');
+        $this->_hookFunction = function_exists('_group_hook');
     }
 
     /**
@@ -37,20 +40,23 @@ class Group_hooks extends Group {
     function getGroupMemberships($user, $parentGroups = false)
     {
         $memberships = parent::getGroupMemberships($user, $parentGroups);
+        if (!$this->_hookFunction) {
+            return $memberships;
+        }
+
         $groups = $this->listGroups();
-        foreach ($groups as $gid => $group) {
-            if ($this->hasHook($group) &&
-                call_user_func($this->_getGroupHookName($group), $user)) {
-                $memberships += array($gid => $group);
+        foreach ($groups as $gid => $groupName) {
+            if (empty($memberships[$gid]) && _group_hook($groupName, $user)) {
+                $memberships += array($gid => $groupName);
             }
+
             if ($parentGroups) {
                 $parents = $this->getGroupParentList($gid);
-                foreach ($parents as $pid => $parent) {
-                    if ($this->hasHook($parent) &&
-                        call_user_func($this->_getGroupHookName($group), $user)) {
-                        $memberships += array($pid => $parent);
-                    }
+                if (is_a($parents, 'PEAR_Error')) {
+                    return $parents;
                 }
+
+                $memberships += $parents;
             }
         }
 
@@ -69,46 +75,8 @@ class Group_hooks extends Group {
      */
     function userIsInGroup($user, $gid, $subgroups = true)
     {
-        $group = $this->getGroupName($gid);
-        if ($this->hasHook($group)) {
-            if (call_user_func($this->_getGroupHookName($group), $user)) {
-                $inGroup = true;
-            } else {
-                $inGroup = false;
-            }
-        } else {
-            $inGroup = false;
-        }
-
-        if ($inGroup || parent::userIsInGroup($user, $gid, $subgroups)) {
-            return true;
-        } else {
-            return false;
-        }
-    }
-
-    /**
-     * Determines if a group has a hook associated with it.
-     *
-     * @param string $name  The group name.
-     *
-     * @return boolean  True if the group has a hook, false otherwise
-     */
-    function hasHook($name)
-    {
-        return function_exists($this->_getGroupHookName($name));
-    }
-
-    /**
-     * Returns the name of the hook function.
-     *
-     * @param string $name  The group name.
-     *
-     * @return string  The function name for the hook for this group
-     */
-    function _getGroupHookName($name)
-    {
-        return '_group_hook_' . str_replace(':', '__', $name);
+        $inGroup = ($this->_hookFunction && _group_hook($this->getGroupName($gid), $user));
+        return ($inGroup || parent::userIsInGroup($user, $gid, $subgroups));
     }
 
 }
