@@ -7,14 +7,14 @@
  * This library allows more complex searches to be created (e.g. OR searches,
  * searching specific headers).
  *
- * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.15 2005/08/02 04:52:36 slusarz Exp $
+ * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.32 2009-01-06 15:23:11 jan Exp $
  *
- * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL). If you did not
- * receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (GPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -35,11 +35,11 @@ class IMAP_Search {
     var $_result = array();
 
     /**
-     * Are we dealing with a POP3 connection?
+     * The paramater list.
      *
-     * @var boolean
+     * @var array
      */
-    var $_pop3 = false;
+    var $_params = array();
 
     /**
      * The charset of the search values.
@@ -83,16 +83,14 @@ class IMAP_Search {
      * @param array $params  A hash containing the following entries:<pre>
      *                       'pop3' => boolean (using POP3 connection?)
      *                       'charset' => string (charset of search values)
+     *                       'no_imap_search' => true if the IMAP server does
+     *                                           not support the charset in
+     *                                           the search command
      *                       </pre>
      */
     function IMAP_Search($params = array())
     {
-        if (isset($params['pop3'])) {
-            $this->_pop3 = $params['pop3'];
-        }
-        if (isset($params['charset'])) {
-            $this->_charset = $params['charset'];
-        }
+        $this->_params = $params;
     }
 
     /**
@@ -100,7 +98,7 @@ class IMAP_Search {
      * by imap_search()).
      *
      * @param IMAP_Search_Query $query  The search query.
-     * @param resource &$imap           An IMAP resource stream.
+     * @param resource $imap            An IMAP resource stream.
      * @param string $mbox              The name of the mailbox to search. For
      *                                  POP3, this should be empty.
      *
@@ -108,7 +106,7 @@ class IMAP_Search {
      *                current mailbox.
      *                Returns PEAR_Error on error.
      */
-    function searchMailbox($query, &$imap, $mbox)
+    function searchMailbox($query, $imap, $mbox)
     {
         /* Check for IMAP extension. */
         if (!Util::extensionExists('imap')) {
@@ -116,8 +114,14 @@ class IMAP_Search {
         }
 
         /* Open to the correct mailbox. */
-        if (!$this->_pop3) {
-            @imap_reopen($imap, $mbox);
+        // TODO: Remove for Horde 4.0
+        if (!$this->_params['pop3']) {
+            $old_error = error_reporting(0);
+            $res = imap_reopen($imap, $mbox, OP_READONLY);
+            error_reporting($old_error);
+            if (!$res) {
+                return array();
+            }
         }
 
         /* Clear the search flag. */
@@ -130,23 +134,25 @@ class IMAP_Search {
      * Searches the mailbox and sorts the results.
      *
      * @param IMAP_Search_Query $query  The search query.
-     * @param resource &$imap           An IMAP resource stream.
+     * @param resource $imap            An IMAP resource stream.
      * @param string $mbox              The name of the mailbox to search.
-     * @param integer $criteria         The criteria to sort by (see
+     * @param integer $sortby           The criteria to sort by (see
      *                                  imap_sort()).
-     * @param integer $dir              1 for reverse sorting.
+     * @param integer $sortdir          1 for reverse sorting.
      *
      * @return array  The list of indices that match the search rules in the
      *                current mailbox and sorted.
      *                Returns PEAR_Error on error.
      */
-    function searchSortMailbox($query, &$imap, $mbox, $criteria, $dir = 0)
+    function searchSortMailbox($query, $imap, $mbox, $sortby, $sortdir = 0)
     {
         $indices = $this->searchMailbox($query, $imap, $mbox);
         if (is_a($indices, 'PEAR_Error')) {
             return $indices;
         } else {
-            $indices_sort = @imap_sort($imap, $criteria, $dir, SE_UID);
+            $old_error = error_reporting(0);
+            $indices_sort = imap_sort($imap, $sortby, $sortdir, SE_UID);
+            error_reporting($old_error);
             return array_values(array_intersect($indices_sort, $indices));
         }
     }
@@ -157,14 +163,24 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _imapSearch(&$imap, $criteria)
+    function _imapSearch($imap, $criteria)
     {
-        if (!empty($this->_charset) &&
-            version_compare(phpversion(), '4.3.3', '>=')) {
-            return @imap_search($imap, $criteria, SE_UID, $this->_charset);
-        } else {
-            return @imap_search($imap, $criteria, SE_UID);
+        $old_error = error_reporting(0);
+
+        if (!empty($this->_params['charset'])) {
+            if (empty($this->_params['no_imap_charset']) &&
+                version_compare(PHP_VERSION, '4.3.3', '>=')) {
+                $res = imap_search($imap, $criteria, SE_UID, $this->_params['charset']);
+                error_reporting($old_error);
+                return $res;
+            } else {
+                $criteria = String::convertCharset($criteria, $this->_params['charset'], 'US-ASCII');
+            }
         }
+
+        $res = imap_search($imap, $criteria, SE_UID);
+        error_reporting($old_error);
+        return $res;
     }
 
     /**
@@ -172,7 +188,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _searchMailbox($query, &$imap, $mbox)
+    function _searchMailbox($query, $imap, $mbox)
     {
         $indices = array();
 
@@ -214,12 +230,24 @@ class IMAP_Search {
 
         /* Process size searches. */
         if (($sizeOb = $query->sizeSearch())) {
-            $overview = @imap_fetch_overview($imap, implode(',', $indices), FT_UID);
-            $func = create_function('$a', 'return ($a ' . $sizeOb->sizeop . ' ' . $sizeOb->size . ');');
+            $old_error = error_reporting(0);
+            $overview = imap_fetch_overview($imap, implode(',', $indices), FT_UID);
+            error_reporting($old_error);
+
             $result = array();
             foreach ($overview as $val) {
-                if ($func($val->size)) {
-                    $result[] = $val->uid;
+                switch ($sizeOb->sizeop) {
+                case '<':
+                    if ($val->size < $sizeOb->size) {
+                        $result[] = $val->uid;
+                    }
+                    break;
+
+                case '>':
+                    if ($val->size > $sizeOb->size) {
+                        $result[] = $val->uid;
+                    }
+                    break;
                 }
             }
             if ($this->_searchflag == 0) {
@@ -244,7 +272,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _doAndOrSearch($query, &$imap, $mbox, $mode, $indices,
+    function _doAndOrSearch($query, $imap, $mbox, $mode, $indices,
                             $base = false)
     {
         if (empty($query)) {
@@ -289,14 +317,14 @@ class IMAP_Search {
      *
      * @access private
      *
-     * @param stdClass $imap_query  rch query.
+     * @param stdClass $imap_query  Search query.
      * @param string $flags         Any additional flags.
-     * @param resource &$imap       An IMAP resource stream.
+     * @param resource $imap        An IMAP resource stream.
      * @param string $mbox          The name of the search mailbox.
      *
      * @return array  The list of indices that match.
      */
-    function _searchPHP($imap_query, $flags, &$imap, $mbox)
+    function _searchPHP($imap_query, $flags, $imap, $mbox)
     {
         $indices = array();
 
@@ -304,7 +332,7 @@ class IMAP_Search {
             $flags = 'ALL';
         }
 
-        if ($this->_pop3) {
+        if (!empty($this->_params['pop3'])) {
             $mbox = 'POP3';
         }
 
@@ -314,7 +342,9 @@ class IMAP_Search {
          * field matches. Use imap_search() to get the list of message indices
          * or return empty list if no search results. */
         if (!isset($this->_result[$cache_key])) {
-            $this->_result[$cache_key] = @imap_search($imap, $flags, SE_UID);
+            $old_error = error_reporting(0);
+            $this->_result[$cache_key] = imap_search($imap, $flags, SE_UID);
+            error_reporting($old_error);
         }
 
         /* If empty message list, return now. */
@@ -334,7 +364,9 @@ class IMAP_Search {
 
         foreach ($this->_result[$cache_key] as $index) {
             if (!isset($this->_headers[$mbox][$index])) {
-                $this->_headers[$mbox][$index] = MIME_Structure::parseMIMEHeaders(@imap_fetchheader($imap, $index, FT_UID), null, true);
+                $old_error = error_reporting(0);
+                $this->_headers[$mbox][$index] = MIME_Structure::parseMIMEHeaders(imap_fetchheader($imap, $index, FT_UID), null, true);
+                error_reporting($old_error);
             }
             $h = &$this->_headers[$mbox][$index];
 
@@ -367,7 +399,7 @@ class IMAP_Search {
  * The IMAP_Search_Object:: class is used to formulate queries to be used with
  * the IMAP_Search:: class.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -382,17 +414,13 @@ class IMAP_Search_Query {
     var $_size = null;
     var $_sizeop = null;
 
-    function IMAP_Search_Query()
-    {
-    }
-
     /**
      * Returns any extended searches.
      */
     function extendedSearch()
     {
         if (!empty($this->_extendedSearch)) {
-            $search = &new stdClass;
+            $search = new stdClass;
             $search->not = $this->_not;
             $search->query = $this->_extendedSearch;
             return $search;
@@ -409,7 +437,7 @@ class IMAP_Search_Query {
         if (is_null($this->_size)) {
             return null;
         }
-        $ob = &new stdClass;
+        $ob = new stdClass;
         $ob->size = (float)$this->_size;
         $ob->sizeop = $this->_sizeop;
 
@@ -445,13 +473,13 @@ class IMAP_Search_Query {
      */
     function build()
     {
-        $search = &new stdClass;
+        $search = new stdClass;
 
         $search->not = $this->_not;
         $search->flags = $this->flags();
 
         if (empty($this->_query)) {
-            if (empty($search->flags)) {
+            if (!empty($this->_or)) {
                 return '';
             }
             $search->query = 'ALL';
@@ -462,12 +490,14 @@ class IMAP_Search_Query {
             }
             $search->query = $this->_query;
         }
-        $search->fullquery = $search->flags . ' ' . $search->query;
+        $search->fullquery = (!empty($search->flags) ? $search->flags . ' ' : '') . $search->query;
 
         return $search;
     }
 
-    /* IMAP search modifiers. */
+    /**
+     * IMAP search modifiers.
+     */
     function _modifiers($ob, $cmd)
     {
         if (is_a($ob, 'IMAP_Search_Query')) {
@@ -486,9 +516,12 @@ class IMAP_Search_Query {
         $this->_modifiers($ob, '_or');
     }
 
-    /* IMAP Search Flags. */
-    /* There is no need to support the KEYWORD/UNKEYWORD query since the
-       individual keywords have identical functionality. */
+    /**
+     * IMAP Search Flags.
+     *
+     * There is no need to support the KEYWORD/UNKEYWORD query since
+     * the individual keywords have identical functionality.
+     */
     function _imapFlags($flag, $cmd)
     {
         $cmd = ($flag) ? $cmd : 'UN' . $cmd;
@@ -525,14 +558,16 @@ class IMAP_Search_Query {
         $this->_imapFlags(true, 'NEW');
     }
 
-    /* IMAP Header Search. */
+    /**
+     * IMAP Header Search.
+     */
     function header($header, $query, $not = false)
     {
         $header = ucfirst(rtrim($header, ':'));
         $stdHdrs = array('To', 'Cc', 'From', 'Subject');
         if ($query != '') {
             if (in_array($header, $stdHdrs)) {
-                $this->_query = String::upper($header) . ' "' . addslashes($query) . '"';
+                $this->_query = String::upper($header) . ' "' . str_replace('"', '\"', $query) . '"';
             } else {
                 $this->_extendedSearch[$header] = $query;
             }
@@ -540,7 +575,9 @@ class IMAP_Search_Query {
         }
     }
 
-    /* IMAP Date Search. */
+    /**
+     * IMAP Date Search.
+     */
     function _imapDate($day, $month, $year, $cmd)
     {
         $this->_query = $cmd . ' ' . date("d-M-y", mktime(0, 0, 0, $month, $day, $year));
@@ -561,7 +598,9 @@ class IMAP_Search_Query {
         $this->_imapDate($day, $month, $year, 'ON');
     }
 
-    /* IMAP Text searches. */
+    /**
+     * IMAP Text searches.
+     */
     function body($query, $not = false)
     {
         $this->_query = 'BODY "' . $query . '"';
@@ -574,11 +613,90 @@ class IMAP_Search_Query {
         $this->_not = $not;
     }
 
-    /* IMAP Size searches. */
+    /**
+     * IMAP Size searches.
+     */
     function size($size, $operator)
     {
         $this->_size = $size;
         $this->_sizeop = $operator;
     }
 
+    /**
+     * Determines whether this query matches a pre-parsed message
+     *
+     * Note: This is not completely implemented.
+     *
+     * @param object $parsedMessage  The return value from
+     *                               Mail_mimeDecode::decode()
+     * @return bool  whether the message matches
+     */
+    function matches(&$parsedMessage)
+    {
+        $result = $this->_matchesQuery($parsedMessage);
+        if (!empty($this->_or)) {
+            $result = $this->_recursiveMatch($this->_or, '||', $parsedMessage);
+        }
+        if (!empty($this->_and)) {
+            $result = $this->_recursiveMatch($this->_and, '&&', $parsedMessage);
+        }
+        if ($this->_not) {
+            $result = !$result;
+        }
+        return $result;
+    }
+
+    function _recursiveMatch(&$list, $operator, &$parsedMessage)
+    {
+        switch ($operator) {
+        case '||':
+            $result = false;
+            break;
+
+        case '&&':
+            $result = true;
+            break;
+        }
+        foreach (array_keys($list) as $i) {
+            if (is_object($list[$i])) {
+                $result1 = $list[$i]->matches($parsedMessage);
+            } else {
+                $result1 = $this->_recursiveMatch($list[$i], $operator,
+                                                  $parsedMessage);
+            }
+            switch ($operator) {
+            case '||':
+                $result = $result || $result1;
+                break;
+
+            case '&&':
+                $result = $result && $result1;
+                break;
+            }
+        }
+        return $result;
+    }
+
+    function _matchesQuery(&$parsedMessage)
+    {
+        if (empty($this->_query)) {
+            return false;
+        }
+
+        if (preg_match('/^FROM "(.*)"$/', $this->_query, $m)) {
+            if (empty($parsedMessage->headers)) {
+                return false;
+            }
+            if (empty($parsedMessage->headers['from'])) {
+                return false;
+            }
+            if (strpos(strtolower($parsedMessage->headers['from']),
+                       strtolower($m[1])) !== false) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
 }
