@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: framework/Kolab_Filter/lib/Horde/Kolab/Filter/Transport/smtp.php,v 1.3.2.1 2009/02/20 22:37:15 wrobel Exp $
+ * $Horde: framework/Kolab_Filter/lib/Horde/Kolab/Filter/Transport/smtp.php,v 1.3.2.2 2010-07-15 21:35:39 wrobel Exp $
  *
  * @package Kolab_Filter
  */
@@ -8,7 +8,7 @@
 /**
  * Provides SMTP for delivering mail.
  *
- * $Horde: framework/Kolab_Filter/lib/Horde/Kolab/Filter/Transport/smtp.php,v 1.3.2.1 2009/02/20 22:37:15 wrobel Exp $
+ * $Horde: framework/Kolab_Filter/lib/Horde/Kolab/Filter/Transport/smtp.php,v 1.3.2.2 2010-07-15 21:35:39 wrobel Exp $
  *
  * Copyright 2004-2008 Klarälvdalens Datakonsult AB
  *
@@ -38,8 +38,8 @@ class Horde_Kolab_Filter_Transport_smtp extends Horde_Kolab_Filter_Transport
             $this->_params['port'] = 25;
         }
 
-        $transport = &new Net_SMTP($this->_params['host'],
-                                   $this->_params['port']);
+        $transport = new Net_SMTP($this->_params['host'],
+                                  $this->_params['port']);
         return $transport;
     }
 }
