@@ -2,7 +2,7 @@
 /**
  * @package Kolab_Storage
  *
- * $Horde: framework/Kolab_Server/lib/Horde/Kolab/IMAP/test.php,v 1.1.2.1 2008/10/27 09:50:35 wrobel Exp $
+ * $Horde: framework/Kolab_Server/lib/Horde/Kolab/IMAP/test.php,v 1.1.2.4 2009-03-08 05:30:12 wrobel Exp $
  */
 
 /**
@@ -14,9 +14,9 @@ define('KOLAB_IMAP_FLAG_DELETED', 1);
  * The Horde_Kolab_IMAP_Connection_test class simulates an IMAP server for
  * testing purposes.
  *
- * $Horde: framework/Kolab_Server/lib/Horde/Kolab/IMAP/test.php,v 1.1.2.1 2008/10/27 09:50:35 wrobel Exp $
+ * $Horde: framework/Kolab_Server/lib/Horde/Kolab/IMAP/test.php,v 1.1.2.4 2009-03-08 05:30:12 wrobel Exp $
  *
- * Copyright 2007-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2007-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -75,7 +75,7 @@ class Horde_Kolab_IMAP_test extends Horde_Kolab_IMAP {
         $tls = ($tls) ? 'tls' : 'notls';
         $this->_connected = $login . ':' . $password . ':' . $tls;
         $this->_user = $login;
-        $this->_mbox = null;
+        unset($this->_mbox);
         $this->_mboxname = null;
     }
 
@@ -550,7 +550,7 @@ class Horde_Kolab_IMAP_test extends Horde_Kolab_IMAP {
      */
     function appendMessage($msg)
     {
-        $split = strpos('\r\n\r\n', $msg);
+        $split = strpos($msg, "\r\n\r\n");
         $mail = array('header' => substr($msg, 0, $split + 2),
                       'body' => substr($msg, $split + 3));
         return $this->_appendMessage($mail);
