@@ -2,7 +2,7 @@
 /**
  * The server configuration.
  *
- * $Horde: framework/Kolab_Server/lib/Horde/Kolab/Server/Object/server.php,v 1.2.2.3 2008/10/24 12:29:40 wrobel Exp $
+ * $Horde: framework/Kolab_Server/lib/Horde/Kolab/Server/Object/server.php,v 1.2.2.5 2009-04-25 08:56:33 wrobel Exp $
  *
  * PHP version 4
  *
@@ -16,9 +16,9 @@
 /**
  * This class provides methods to deal with Kolab server configuration.
  *
- * $Horde: framework/Kolab_Server/lib/Horde/Kolab/Server/Object/server.php,v 1.2.2.3 2008/10/24 12:29:40 wrobel Exp $
+ * $Horde: framework/Kolab_Server/lib/Horde/Kolab/Server/Object/server.php,v 1.2.2.5 2009-04-25 08:56:33 wrobel Exp $
  *
- * Copyright 2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2008-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -32,11 +32,26 @@
 class Horde_Kolab_Server_Object_server extends Horde_Kolab_Server_Object {
 
     /**
-     * The LDAP filter to retrieve this object type
+     * Return the filter string to retrieve this object type.
      *
-     * @var string
+     * @static
+     *
+     * @return string The filter to retrieve this object type from the server
+     *                database.
      */
-    var $filter = '(&((k=kolab))(objectclass=kolab))';
+    public static function getFilter()
+    {
+        $criteria = array('AND' => array(
+                              array('field' => 'k',
+                                    'op'    => '=',
+                                    'test'  => 'kolab'),
+                              array('field' => KOLAB_ATTR_OC,
+                                    'op'    => '=',
+                                    'test'  => KOLAB_OC_KOLAB),
+                          ),
+        );
+        return $criteria;
+    }
 
     /**
      * The attributes supported by this class
