@@ -2,15 +2,14 @@
 /**
  * The MIME_Viewer_images class allows images to be displayed.
  *
- * $Horde: framework/MIME/MIME/Viewer/images.php,v 1.18.8.10 2007/01/02 13:54:25 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/images.php,v 1.18.8.14 2009-01-06 15:23:21 jan Exp $
  *
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   Horde 2.2
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_MIME_Viewer
  */
 class MIME_Viewer_images extends MIME_Viewer {
@@ -64,27 +63,21 @@ EOD;
             /* Translate '&amp' entities to '&' for JS URL links. */
             $url = str_replace('&amp;', '&', $url);
 
-            /* Mozilla and IE determine window dimensions in different ways. */
-            if ($browser->isBrowser('msie')) {
-                $iWidth_code = 'document.body.clientWidth;';
-                $iHeight_code = 'document.body.clientHeight;';
-            } else {
-                $iWidth_code = 'window.innerWidth;';
-                $iHeight_code = 'window.innerHeight;';
-            }
-
             /* Javascript display. */
             $loading = _("Loading...");
             $str .= <<<EOD
 <script type="text/javascript">
-function resizeWindow() {
-    window.moveTo(0, 0);
+function resizeWindow()
+{
+
+    var h, img = document.getElementById('disp_image'), w;
     document.getElementById('splash').style.display = 'none';
-    document.getElementById('disp_image').style.display = 'block';
-    var iWidth = document.images[0].width - $iWidth_code
-    var iHeight = document.images[0].height - $iHeight_code
-    window.resizeBy(iWidth, iHeight);
-    self.focus(); 
+    img.style.display = 'block';
+    window.moveTo(0, 0);
+    h = img.height - (window.innerHeight ? window.innerHeight : (document.documentElement.clientHeight ? document.documentElement.clientHeight : document.body.clientHeight));
+    w = img.width - (window.innerWidth ? window.innerWidth : (document.documentElement.clientWidth ? document.documentElement.clientWidth : document.body.clientWidth));
+    window.resizeBy(w, h);
+    self.focus();
 }
 </script></head>
 <body onload="resizeWindow();"><span id="splash" style="color:gray;font-family:sans-serif;padding:2px;">$loading</span><img id="disp_image" style="display:none;" src="$url" /></body></html>
