@@ -1,4 +1,9 @@
 <?php
+/**
+ * @package Horde_Maintenance
+ *
+ * $Horde: framework/Maintenance/Maintenance.php,v 1.52.10.21 2009-01-06 15:23:23 jan Exp $
+ */
 
 /**
  * Do task yearly (First login after/on January 1).
@@ -64,15 +69,12 @@ $GLOBALS['intervals'] = &$intervals;
  * The Maintenance:: class provides a set of methods for dealing with
  * maintenance operations run upon login to Horde applications.
  *
- * $Horde: framework/Maintenance/Maintenance.php,v 1.52.10.17 2007/03/29 12:34:32 jan Exp $
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
- * Copyright 2001-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
- *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   Horde 1.3.5
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_Maintenance
  */
 class Maintenance {
@@ -147,7 +149,8 @@ class Maintenance {
      * Constructor.
      *
      * @param array $params  A hash containing the following entries:
-     *                       'last_maintenance' => The last time maintenance was run (unix timestamp).
+     *                       'last_maintenance' => The last time maintenance
+     *                                             was run (UNIX timestamp).
      */
     function Maintenance($params = array())
     {
@@ -451,7 +454,7 @@ class Maintenance {
      */
     function _cacheTasklist()
     {
-        $_SESSION['horde_maintenance_tasklist'] = serialize($this->_tasklist);
+        $_SESSION['horde_maintenance_tasklist'][get_class($this)] = serialize($this->_tasklist);
     }
 
     /**
@@ -462,10 +465,10 @@ class Maintenance {
      */
     function _retrieveTasklist()
     {
-        if (isset($_SESSION['horde_maintenance_tasklist'])) {
-            $this->_tasklist = unserialize($_SESSION['horde_maintenance_tasklist']);
+        if (isset($_SESSION['horde_maintenance_tasklist'][get_class($this)])) {
+            $this->_tasklist = unserialize($_SESSION['horde_maintenance_tasklist'][get_class($this)]);
         } else {
-            $this->_createTasklist();
+            $this->_createTaskList();
         }
     }
 
@@ -537,13 +540,12 @@ class Maintenance {
  * The Maintenance_Tasklist:: class is used to store the list of maintenance
  * tasks that need to be run during this login.
  *
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   Horde 3.0
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_Maintenance
  */
 class Maintenance_Tasklist {
@@ -787,13 +789,12 @@ class Maintenance_Tasklist {
  *     text. doMaintenance() will ALWAYS be run.
  *     * This style will be displayed on its own, separate maintenance page. *
  *
- * Copyright 2001-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   Horde 1.3.5
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_Maintenance
  */
 class Maintenance_Task {
