@@ -6,9 +6,9 @@ require_once 'Horde/Notification/Listener.php';
  * The Notification_Listener_javascript:: class provides functionality for
  * inserting javascript code from the message stack into the page.
  *
- * $Horde: framework/Notification/Notification/Listener/javascript.php,v 1.7.10.6 2006/01/01 21:28:30 jan Exp $
+ * $Horde: framework/Notification/Notification/Listener/javascript.php,v 1.7.10.10 2009-01-06 15:23:29 jan Exp $
  *
- * Copyright 2004-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -24,7 +24,8 @@ class Notification_Listener_javascript extends Notification_Listener {
      */
     function Notification_Listener_javascript()
     {
-        $this->_handles = array('javascript' => '');
+        $this->_handles = array('javascript' => '',
+                                'javascript-file' => '');
     }
 
     /**
@@ -46,16 +47,30 @@ class Notification_Listener_javascript extends Notification_Listener {
      */
     function notify(&$messageStack, $options = array())
     {
-        if (count($messageStack)) {
-            if (empty($options['noscript'])) {
-                echo '<script type="text/javascript">';
-                echo "\n<!--\n";
+        if (!count($messageStack)) {
+            return;
+        }
+
+        if (empty($options['noscript'])) {
+            echo '<script type="text/javascript">//<![CDATA[' . "\n";
+        }
+
+        $files = array();
+        while ($message = array_shift($messageStack)) {
+            $event = $this->getEvent($message);
+            if ($message['type'] == 'javascript') {
+                echo $event->getMessage() . "\n";
+            } elseif ($message['type'] == 'javascript-file') {
+                $files[] = $event->getMessage();
             }
-            while ($message = array_shift($messageStack)) {
-                $this->getMessage($message);
-            }
-            if (empty($options['noscript'])) {
-                echo "//-->\n</script>\n";
+        }
+
+        if (empty($options['noscript'])) {
+            echo "//]]></script>\n";
+            if (count($files)) {
+                foreach ($files as $file) {
+                    echo '<script type="text/javascript" src="' . $file . '"></script>' . "\n";
+                }
             }
         }
     }
@@ -67,8 +82,6 @@ class Notification_Listener_javascript extends Notification_Listener {
      */
     function getMessage($message)
     {
-        $event = $this->getEvent($message);
-        echo $event->getMessage() . "\n";
     }
 
 }
