@@ -6,9 +6,9 @@ require_once 'Horde/Notification/Listener.php';
  * The Notification_Listener_status:: class provides functionality for
  * displaying messages from the message stack as a status line.
  *
- * $Horde: framework/Notification/Notification/Listener/status.php,v 1.29.2.5 2006/01/01 21:28:30 jan Exp $
+ * $Horde: framework/Notification/Notification/Listener/status.php,v 1.29.2.9 2009-01-06 15:23:29 jan Exp $
  *
- * Copyright 2001-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -27,7 +27,8 @@ class Notification_Listener_status extends Notification_Listener {
         $this->_handles = array('horde.error'   => array('alerts/error.png', _("Error")),
                                 'horde.success' => array('alerts/success.png', _("Success")),
                                 'horde.warning' => array('alerts/warning.png', _("Warning")),
-                                'horde.message' => array('alerts/message.png', _("Message")));
+                                'horde.message' => array('alerts/message.png', _("Message")),
+                                'horde.alarm' => array('alerts/alarm.png', _("Alarm")));
     }
 
     /**
@@ -50,10 +51,13 @@ class Notification_Listener_status extends Notification_Listener {
     function notify(&$messageStack, $options = array())
     {
         if (count($messageStack)) {
+            echo '<ul class="notices">';
             while ($message = array_shift($messageStack)) {
-                echo $this->getMessage($message);
+                $message = $this->getMessage($message);
+                $message = preg_replace('/^<p class="notice">(.*)<\/p>$/', '<li>$1</li>', $message);
+                echo $message;
             }
-            echo '<br class="spacer" />';
+            echo '</ul>';
         }
     }
 
@@ -73,7 +77,7 @@ class Notification_Listener_status extends Notification_Listener {
             $text = htmlspecialchars($text);
         }
 
-        return '<p class="notice">' . Horde::img($this->_handles[$message['type']][0], $this->_handles[$message['type']][1], '', $registry->getImageDir('horde')) . '&nbsp;&nbsp;' . $text . '</p>';
+        return '<li>' . Horde::img($this->_handles[$message['type']][0], $this->_handles[$message['type']][1], '', $registry->getImageDir('horde')) . $text . '</li>';
     }
 
 }
