@@ -26,9 +26,9 @@ define('PERMS_ROOT', -1);
 /**
  * The Perms:: class provides the Horde permissions system.
  *
- * $Horde: framework/Perms/Perms.php,v 1.80.10.20 2008/09/15 11:18:59 jan Exp $
+ * $Horde: framework/Perms/Perms.php,v 1.80.10.22 2009-01-06 15:23:29 jan Exp $
  *
- * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -548,13 +548,21 @@ class Horde_Permission {
     }
 
     /**
-     * Set permission id
-     *
-     * @param string $id  Permission ID
+     * Get permission name
      */
-    function setData($data)
+    function getName()
     {
-        $this->data = $data;
+        return $this->name;
+    }
+
+    /**
+     * Set permission name
+     *
+     * @param string $name  Permission name
+     */
+    function setName($name)
+    {
+        $this->name = $name;
     }
 
     /**
@@ -565,6 +573,16 @@ class Horde_Permission {
         return $this->data;
     }
 
+    /**
+     * Set permission id
+     *
+     * @param string $id  Permission ID
+     */
+    function setData($data)
+    {
+        $this->data = $data;
+    }
+
     /**
      * Updates the permissions based on data passed in the array.
      *
