@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: framework/Prefs/Prefs.php,v 1.137.10.37 2008/10/09 15:55:51 chuck Exp $
+ * $Horde: framework/Prefs/Prefs.php,v 1.137.10.42 2009-06-04 19:00:36 mrubinsk Exp $
  */
 
 /** Preference is administratively locked. */
@@ -43,7 +43,7 @@ define('_PREF_DEFAULT', 8);
  *     'help'   => *Name of the entry in the XML help file*
  * );
  *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -758,10 +758,10 @@ class Prefs {
                 }
 
                 if (!empty($pref['hook'])) {
-                    if (!isset($this->_hooks[$pref_scope])) {
-                        $this->_hooks[$pref_scope] = array();
+                    if (!isset($this->_hooks[$scope])) {
+                        $this->_hooks[$scope] = array();
                     }
-                    $this->_hooks[$pref_scope][] = $name;
+                    $this->_hooks[$scope][$name] = $pref_scope;
                 }
             }
         }
@@ -781,10 +781,10 @@ class Prefs {
             return;
         }
 
-        foreach ($this->_hooks[$scope] as $name) {
-            if ($this->_scopes[$scope][$name]['m'] & _PREF_LOCKED ||
-                empty($this->_scopes[$scope][$name]['v']) ||
-                $this->_scopes[$scope][$name]['m'] & _PREF_DEFAULT) {
+        foreach ($this->_hooks[$scope] as $name => $pref_scope) {
+            if ($this->_scopes[$pref_scope][$name]['m'] & _PREF_LOCKED ||
+                empty($this->_scopes[$pref_scope][$name]['v']) ||
+                $this->_scopes[$pref_scope][$name]['m'] & _PREF_DEFAULT) {
 
                 $val = Horde::callHook('_prefs_hook_' . $name, array($this->_user), $scope, $name);
                 if (is_a($val, 'PEAR_Error')) {
@@ -792,9 +792,13 @@ class Prefs {
                     continue;
                 }
 
-                $this->_scopes[$scope][$name]['v'] = $this->convertToDriver($val, NLS::getCharset());
-                if ($this->_scopes[$scope][$name]['m'] & _PREF_LOCKED) {
-                    $this->_scopes[$scope][$name]['m'] |= _PREF_DIRTY;
+                if ($this->_scopes[$pref_scope][$name]['m'] & _PREF_DEFAULT) {
+                    $this->_scopes[$pref_scope][$name]['v'] = $val;
+                } else {
+                    $this->_scopes[$pref_scope][$name]['v'] = $this->convertToDriver($val, NLS::getCharset());
+                }
+                if (!($this->_scopes[$pref_scope][$name]['m'] & _PREF_LOCKED)) {
+                    $this->_scopes[$pref_scope][$name]['m'] |= _PREF_DIRTY;
                 }
             }
         }
