@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: framework/RPC/RPC/jsonrpc.php,v 1.4.2.4 2009/01/06 15:23:32 jan Exp $
+ * $Horde: framework/RPC/RPC/jsonrpc.php,v 1.4.2.6 2009-11-09 13:20:20 jan Exp $
  *
  * Copyright 2007-2009 The Horde Project (http://www.horde.org/)
  *
@@ -30,6 +30,18 @@ require_once 'Horde/Serialize.php';
  */
 class Horde_RPC_jsonrpc extends Horde_RPC {
 
+    /**
+     * Constructor.
+     *
+     * @param array $config  A hash containing any additional configuration or
+     *                       connection parameters this class might need.
+     */
+    function Horde_RPC_jsonrpc($params = array())
+    {
+        parent::Horde_RPC($params);
+        NLS::setCharsetEnvironment('UTF-8');
+    }
+
     /**
      * Returns the Content-Type of the response.
      *
