@@ -1,4 +1,14 @@
 <?php
+/**
+ * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.41 2010-10-21 10:13:24 jan Exp $
+ *
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @package Horde_Framework
+ */
 
 /** Do not start a session. */
 define('HORDE_SESSION_NONE', 1);
@@ -11,15 +21,6 @@ define('HORDE_SESSION_READONLY', 2);
  * between Horde applications and keeping track of application
  * configuration information.
  *
- * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.25 2007/03/13 00:04:45 jan Exp $
- *
- * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Jon Parise <jon@horde.org>
- * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
- *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
  * @author  Anil Madhavapeddy <anil@recoil.org>
@@ -71,13 +72,6 @@ class Registry {
      */
     var $_currentApp = null;
 
-    /**
-     * Cache of $prefs objects
-     *
-     * @var array
-     */
-    var $_prefsCache = array();
-
     /**
      * Cache of application configurations.
      *
@@ -99,13 +93,6 @@ class Registry {
      */
     var $_updatecache = array();
 
-    /**
-     * Update these mtime entries on shutdown.
-     *
-     * @param array
-     */
-    var $_updatemtime = array();
-
     /**
      * Don't update cache at end of request?
      *
@@ -113,6 +100,27 @@ class Registry {
      */
     var $_nocache = false;
 
+    /**
+     * The list of APIs.
+     *
+     * @param array
+     */
+    var $_apis = array();
+
+    /**
+     * Cached values of the image directories.
+     *
+     * @param array
+     */
+    var $_imgDir = array();
+
+    /**
+     * Cached values of theme information.
+     *
+     * @param array
+     */
+    var $_themeCache = array();
+
     /**
      * Returns a reference to the global Registry object, only
      * creating it if it doesn't already exist.
@@ -154,14 +162,16 @@ class Registry {
             $_SESSION = array();
         } else {
             Horde::setupSessionHandler();
-            @session_start();
+            $old_error = error_reporting(0);
+            session_start();
             if ($session_flags & HORDE_SESSION_READONLY) {
                 /* Close the session immediately so no changes can be
                    made but values are still available. */
-                @session_write_close();
+                session_write_close();
             } else {
                 $this->_usecache = true;
             }
+            error_reporting($old_error);
         }
 
         /* Initialize the localization routines and variables. */
@@ -171,15 +181,47 @@ class Registry {
 
         $reg_mtime = filemtime(HORDE_BASE . '/config/registry.php');
 
+        if (!empty($_SESSION['_registry']) &&
+            isset($_SESSION['_registry']['registry_d'])) {
+            $registry_d = $_SESSION['_registry']['registry_d'];
+        } else {
+            $registry_d = file_exists(HORDE_BASE . '/config/registry.d') &&
+                          is_dir(HORDE_BASE . '/config/registry.d');
+        }
+
+        if ($registry_d) {
+            $reg_mtime = max($reg_mtime, filemtime(HORDE_BASE . '/config/registry.d'));
+        }
+
+        if (!empty($GLOBALS['conf']['vhosts'])) {
+            $registry_vhost = HORDE_BASE . '/config/registry-' . $GLOBALS['conf']['server']['name'] . '.php';
+            if (file_exists($registry_vhost)) {
+                $reg_mtime = max($reg_mtime, filemtime($registry_vhost));
+            }
+        }
+
         /* Load registry information from the session, if available. */
-        if (!empty($_SESSION['_registrycache']) &&
-            ($_SESSION['_registrymtime']['registry.php'] == $reg_mtime)) {
-            foreach ($_SESSION['_registrycache'] as $key => $val) {
+        if (!empty($_SESSION['_registry']) &&
+            !empty($_SESSION['_registry']['cache']) &&
+            ($_SESSION['_registry']['mtime'] == $reg_mtime)) {
+            foreach ($_SESSION['_registry']['cache'] as $key => $val) {
                 $this->$key = $val;
             }
         } else {
-            /* Read the registry configuration file. */
-            require_once HORDE_BASE . '/config/registry.php';
+            /* Read the registry configuration files. */
+            require HORDE_BASE . '/config/registry.php';
+            if ($registry_d) {
+                $files = glob(HORDE_BASE . '/config/registry.d/*.php');
+                if ($files) {
+                    foreach ($files as $r) {
+                        include $r;
+                    }
+                }
+            }
+            if (!empty($GLOBALS['conf']['vhosts']) &&
+                file_exists($registry_vhost)) {
+                include $registry_vhost;
+            }
 
             /* Stop system if Horde is inactive. */
             if ($this->applications['horde']['status'] == 'inactive') {
@@ -194,6 +236,10 @@ class Registry {
                 if ($app['status'] == 'heading') {
                     continue;
                 }
+                if (isset($app['fileroot']) && !file_exists($app['fileroot'])) {
+                    $app['status'] = 'inactive';
+                    Horde::logMessage('Setting ' . $appName . ' inactive because the fileroot does not exist.', __FILE__, __LINE__, PEAR_LOG_DEBUG);
+                }
                 if ($app['status'] != 'inactive' &&
                     ($app['status'] != 'admin' || Auth::isAdmin()) &&
                     isset($app['provides'])) {
@@ -225,7 +271,8 @@ class Registry {
             /* Clear out the API & Type caches, if they exists. */
             $this->_apiCache = $this->_typeCache = array();
 
-            $this->_cacheVars(array('applications', '_interfaces', '_apiCache', '_typeCache'), array('registry.php' => $reg_mtime));
+            $_SESSION['_registry'] = array('cache' => array(), 'registry_d' => $registry_d, 'mtime' => $reg_mtime);
+            $this->_cacheVars(array('applications', '_interfaces', '_apiCache', '_typeCache'));
         }
 
         /* Create the global Perms object. */
@@ -236,30 +283,32 @@ class Registry {
         $notification->attach('javascript');
 
         /* Register access key logger for translators. */
-        if (@$GLOBALS['conf']['log_accesskeys']) {
+        if (!empty($GLOBALS['conf']['log_accesskeys'])) {
             register_shutdown_function(create_function('', 'Horde::getAccessKey(null, null, true);'));
         }
+
+        /* Register memory tracker if logging in debug mode. */
+        if ($GLOBALS['conf']['log']['enabled'] &&
+            ($GLOBALS['conf']['log']['priority'] == PEAR_LOG_DEBUG) &&
+            function_exists('memory_get_peak_usage')) {
+            register_shutdown_function(array(&$this, '_memoryusageShutdown'));
+        }
     }
 
     /**
-     * Add a list of variable names and modification times to be cached.
+     * Add a list of variable names to be cached.
      *
      * @access private
      *
-     * @param array $vars    A list of variable names to be cached.
-     * @param array $mtimes  A list of file modificaion times to be cached.
+     * @param array $vars A list of variable names to be cached.
      */
-    function _cacheVars($vars = array(), $mtimes = array())
+    function _cacheVars($vars = array())
     {
-        static $regcacheshutdown = false;
-
-        if ($this->_usecache) {
-            $this->_updatecache = array_merge($this->_updatecache, $vars);
-            $this->_updatemtime = array_merge($this->_updatemtime, $mtimes);
-            if (!$regcacheshutdown) {
+        if ($this->_usecache && !empty($vars)) {
+            if (empty($this->_updatecache)) {
                 register_shutdown_function(array(&$this, '_shutdowncache'));
-                $regcacheshutdown = true;
             }
+            $this->_updatecache = array_merge($this->_updatecache, $vars);
         }
     }
 
@@ -270,25 +319,27 @@ class Registry {
      */
     function _shutdowncache()
     {
-        if (isset($_SESSION) && Auth::getAuth() && !$this->_nocache) {
-            if (!isset($_SESSION['_registrycache'])) {
-                $_SESSION['_registrycache'] = array();
+        if (isset($_SESSION) && !$this->_nocache && Auth::getAuth()) {
+            if (!isset($_SESSION['_registry'])) {
+                $_SESSION['_registry'] = array('cache' => array(), 'mtime' => false);
             }
 
-            foreach (array_unique($this->_updatecache) as $val) {
-                $_SESSION['_registrycache'][$val] = $this->$val;
-            }
-
-            if (!isset($_SESSION['_registrymtime'])) {
-                $_SESSION['_registrymtime'] = array();
-            }
-
-            foreach (array_unique($this->_updatemtime) as $key => $val) {
-                $_SESSION['_registrymtime'][$key] = $val;
+            foreach (array_keys(array_flip($this->_updatecache)) as $val) {
+                $_SESSION['_registry']['cache'][$val] = $this->$val;
             }
         }
     }
 
+    /**
+     * Print memory information on shutdown.
+     *
+     * @access private
+     */
+    function _memoryusageShutdown()
+    {
+        Horde::logMessage('Max memory usage: ' . memory_get_peak_usage(true) . ' bytes', __FILE__, __LINE__, PEAR_LOG_DEBUG);
+    }
+
     /**
      * Clear the registry cache.
      *
@@ -296,7 +347,7 @@ class Registry {
      */
     function clearCache()
     {
-        unset($_SESSION['_registrycache']);
+        unset($_SESSION['_registry']);
         $this->_nocache = true;
     }
 
@@ -305,7 +356,7 @@ class Registry {
      *
      * @access private
      */
-    function _fillAPICache()
+    function _fillApiCache()
     {
         if (!empty($this->_apiCache)) {
             return;
@@ -322,16 +373,11 @@ class Registry {
             if (is_readable($api)) {
                 include_once $api;
             }
-            if (!isset($_services)) {
-                $this->_apiCache[$app] = array();
-            } else {
-                $this->_apiCache[$app] = $_services;
-            }
-            if (isset($_types)) {
+            $this->_apiCache[$app] = $_services;
+            if (!is_null($_types)) {
                 foreach ($_types as $type => $params) {
-                    /* Prefix non-Horde types with the application
-                     * name. */
-                    $prefix = $app == 'horde' ? '' : "${app}_";
+                    /* Prefix non-Horde types with the application name. */
+                    $prefix = ($app == 'horde') ? '' : "${app}_";
                     $this->_typeCache[$prefix . $type] = $params;
                 }
             }
@@ -362,7 +408,11 @@ class Registry {
         foreach ($this->applications as $app => $params) {
             if (in_array($params['status'], $filter) &&
                 (defined('AUTH_HANDLER') || $this->hasPermission($app, $permission))) {
-                $assoc ? $apps[$app] = $app : $apps[] = $app;
+                if ($assoc) {
+                    $apps[$app] = $app;
+                } else {
+                    $apps[] = $app;
+                }
             }
         }
 
@@ -376,17 +426,13 @@ class Registry {
      */
     function listAPIs()
     {
-        static $apis = array();
-        if ($apis) {
-            return $apis;
+        if (empty($this->_apis)) {
+            foreach (array_keys($this->_interfaces) as $interface) {
+                list($api,) = explode('/', $interface, 2);
+                $this->_apis[$api] = true;
+            }
         }
-
-        foreach (array_keys($this->_interfaces) as $interface) {
-            @list($api, ) = explode('/', $interface);
-            $apis[] = $api;
-        }
-
-        return array_unique($apis);
+        return array_keys($this->_apis);
     }
 
     /**
@@ -402,7 +448,7 @@ class Registry {
     {
         $methods = array();
 
-        $this->_fillAPICache();
+        $this->_fillApiCache();
 
         foreach (array_keys($this->applications) as $app) {
             if (isset($this->applications[$app]['provides'])) {
@@ -418,19 +464,19 @@ class Registry {
                 if (strpos($method, '/') !== false) {
                     if (is_null($api) ||
                         (substr($method, 0, strlen($api)) == $api)) {
-                        $methods[] = $method;
+                        $methods[$method] = true;
                     }
                 } elseif (is_null($api) || ($method == $api)) {
                     if (isset($this->_apiCache[$app])) {
                         foreach (array_keys($this->_apiCache[$app]) as $service) {
-                            $methods[] = $method . '/' . $service;
+                            $methods[$method . '/' . $service] = true;
                         }
                     }
                 }
             }
         }
 
-        return array_unique($methods);
+        return array_keys($methods);
     }
 
     /**
@@ -440,7 +486,7 @@ class Registry {
      */
     function listTypes()
     {
-        $this->_fillAPICache();
+        $this->_fillApiCache();
         return $this->_typeCache;
     }
 
@@ -459,10 +505,11 @@ class Registry {
             return;
         }
 
-        $this->_fillAPICache();
+        $this->_fillApiCache();
 
-        @list(, $function) = explode('/', $method);
-        if (isset($this->_apiCache[$app][$function]['type']) &&
+        list(,$function) = explode('/', $method, 2);
+        if (!empty($function) &&
+            isset($this->_apiCache[$app][$function]['type']) &&
             isset($this->_apiCache[$app][$function]['args'])) {
             return array($this->_apiCache[$app][$function]['args'], $this->_apiCache[$app][$function]['type']);
         }
@@ -495,7 +542,7 @@ class Registry {
     function hasMethod($method, $app = null)
     {
         if (is_null($app)) {
-            @list($interface, $call) = explode('/', $method);
+            list($interface, $call) = explode('/', $method, 2);
             if (!empty($this->_interfaces[$method])) {
                 $app = $this->_interfaces[$method];
             } elseif (!empty($this->_interfaces[$interface])) {
@@ -507,7 +554,7 @@ class Registry {
             $call = $method;
         }
 
-        $this->_fillAPICache();
+        $this->_fillApiCache();
 
         return !empty($this->_apiCache[$app][$call]) ? $app : false;
     }
@@ -526,7 +573,7 @@ class Registry {
      */
     function call($method, $args = array())
     {
-        @list($interface, $call) = explode('/', $method);
+        list($interface, $call) = explode('/', $method, 2);
 
         if (!empty($this->_interfaces[$method])) {
             $app = $this->_interfaces[$method];
@@ -559,15 +606,13 @@ class Registry {
         }
 
         /* Load the API now. */
-        if (!empty($_SESSION['_registrycache']['_apiCache'])) {
-            $api = $this->get('fileroot', $app) . '/lib/api.php';
-            if (is_readable($api)) {
-                include_once $api;
-            }
+        $api = $this->get('fileroot', $app) . '/lib/api.php';
+        if (is_readable($api)) {
+            include_once $api;
         }
 
         /* Make sure that the function actually exists. */
-        $function = '_' . $app . '_' . $call;
+        $function = '_' . $app . '_' . str_replace('/', '_', $call);
         if (!function_exists($function)) {
             return PEAR::raiseError('The function implementing ' . $call . ' (' . $function . ') is not defined in ' . $app . '\'s API.');
         }
@@ -609,7 +654,7 @@ class Registry {
      */
     function link($method, $args = array(), $extra = '')
     {
-        @list($interface, $call) = explode('/', $method);
+        list($interface, $call) = explode('/', $method, 2);
 
         if (!empty($this->_interfaces[$method])) {
             $app = $this->_interfaces[$method];
@@ -672,7 +717,7 @@ class Registry {
         if (is_array($extra)) {
             $extra_args = '';
             foreach ($extra as $key => $val) {
-                $extra_args .- '&' . urlencode($key) . '=' . urlencode($val);
+                $extra_args .= '&' . urlencode($key) . '=' . urlencode($val);
             }
         } else {
             $extra_args = $extra;
@@ -759,9 +804,9 @@ class Registry {
             Horde::fatal($app . ' is not activated', __FILE__, __LINE__);
         }
 
-        /* If permissions checking is requested, return an error if
-         * the current user does not have read perms to the
-         * application being loaded. We allow access:
+        /* If permissions checking is requested, return an error if the
+         * current user does not have read perms to the application being
+         * loaded. We allow access:
          *
          *  - To all admins.
          *  - To all authenticated users if no permission is set on $app.
@@ -771,31 +816,40 @@ class Registry {
             return PEAR::raiseError(sprintf(_('%s is not authorised for %s.'), Auth::getAuth() ? 'User ' . Auth::getAuth() : 'Guest user', $this->applications[$app]['name']), 'permission_denied');
         }
 
+        /* Chicken and egg problem: the language environment has to be loaded
+         * before loading the configuration file, because it might contain
+         * gettext strings. Though the preferences can specify a different
+         * language for this app, the have to be loaded after the
+         * configuration, because they rely on configuration settings. So try
+         * with the current language, and reset the language later. */
+        NLS::setLanguageEnvironment($GLOBALS['language'], $app);
+
         /* Import this application's configuration values. */
         $success = $this->importConfig($app);
         if (is_a($success, 'PEAR_Error')) {
             return $success;
         }
 
-        /* Load preferences after the configuration has been loaded to
-         * make sure the prefs file has all the information it needs. */
+        /* Load preferences after the configuration has been loaded to make
+         * sure the prefs file has all the information it needs. */
         $this->loadPrefs($app);
 
-        /* Reset the language in case there is a different one
-         * selected in the preferences. */
+        /* Reset the language in case there is a different one selected in the
+         * preferences. */
         $language = '';
-        if (isset($this->_prefsCache[$app]) &&
-            isset($this->_prefsCache[$app]->_prefs['language'])) {
-            $language = $this->_prefsCache[$app]->getValue('language');
+        if (isset($GLOBALS['prefs'])) {
+            $language = $GLOBALS['prefs']->getValue('language');
+            if ($language != $GLOBALS['language']) {
+                NLS::setLanguageEnvironment($language, $app);
+            }
         }
-        NLS::setLang($language);
-        NLS::setTextdomain($app, $this->applications[$app]['fileroot'] . '/locale', NLS::getCharset());
-        String::setDefaultCharset(NLS::getCharset());
 
-        /* Once we know everything succeeded and is in a consistent
-         * state again, push the new application onto the stack. */
-        $this->_appStack[] = $app;
-        $this->_currentApp = $app;
+        /* Once we know everything succeeded and is in a consistent state
+         * again, push the new application onto the stack. */
+        $this->_appStack[] = $this->_currentApp = $app;
+
+        /* Call post-push hook. */
+        Horde::callHook('_horde_hook_post_pushapp', array($app), 'horde', null);
 
         return true;
     }
@@ -818,11 +872,7 @@ class Registry {
             $this->importConfig($this->_currentApp);
             $this->loadPrefs($this->_currentApp);
             $language = $GLOBALS['prefs']->getValue('language');
-            if (isset($language)) {
-                NLS::setLang($language);
-            }
-            NLS::setTextdomain($this->_currentApp, $this->applications[$this->_currentApp]['fileroot'] . '/locale', NLS::getCharset());
-            String::setDefaultCharset(NLS::getCharset());
+            NLS::setLanguageEnvironment($language, $this->_currentApp);
         }
 
         return $previous;
@@ -862,35 +912,27 @@ class Registry {
      */
     function importConfig($app)
     {
-        /* Don't make config files global $registry themselves. */
-        global $registry;
-
         /* Cache config values so that we don't re-read files on every
          * popApp() call. */
         if (!isset($this->_confCache[$app])) {
             if (!isset($this->_confCache['horde'])) {
-                $conf = array();
-                ob_start();
-                $success = include HORDE_BASE . '/config/conf.php';
-                $errors = ob_get_contents();
-                ob_end_clean();
-                if (!empty($errors)) {
-                    return PEAR::raiseError('Failed to import Horde configuration: ' . strip_tags($errors));
-                }
-                if (!$success) {
-                    return PEAR::raiseError('Failed to import Horde configuration.');
+                $success = Horde::loadConfiguration('conf.php', 'conf', 'horde');
+                if (is_a($success, 'PEAR_Error')) {
+                    return $success;
                 }
+                $conf = $success;
 
                 /* Initial Horde-wide settings. */
 
+                /* Set the maximum execution time in accordance with
+                 * the config settings. */
+                error_reporting(0);
+                set_time_limit($conf['max_exec_time']);
+
                 /* Set the error reporting level in accordance with
                  * the config settings. */
                 error_reporting($conf['debug_level']);
 
-                /* Set the maximum execution time in accordance with
-                 * the config settings. */
-                @set_time_limit($conf['max_exec_time']);
-
                 /* Set the umask according to config settings. */
                 if (isset($conf['umask'])) {
                     umask($conf['umask']);
@@ -900,16 +942,12 @@ class Registry {
             }
 
             if ($app !== 'horde') {
-                ob_start();
-                $success = include $this->applications[$app]['fileroot'] . '/config/conf.php';
-                $errors = ob_get_contents();
-                ob_end_clean();
-                if (!empty($errors)) {
-                    return PEAR::raiseError('Failed to import application configuration for ' . $app . ': ' . strip_tags($errors));
-                }
-                if (!$success) {
-                    return PEAR::raiseError('Failed to import application configuration for ' . $app);
+                $success = Horde::loadConfiguration('conf.php', 'conf', $app);
+                if (is_a($success, 'PEAR_Error')) {
+                    return $success;
                 }
+                require_once 'Horde/Array.php';
+                $conf = Horde_Array::array_merge_recursive_overwrite($conf, $success);
             }
 
             $this->_cacheVars(array('_confCache'));
@@ -929,36 +967,24 @@ class Registry {
      */
     function loadPrefs($app = null)
     {
-        static $prefs_default = false;
-
         require_once 'Horde/Prefs.php';
 
-        if ($app === null) {
+        if (is_null($app)) {
             $app = $this->_currentApp;
         }
 
         /* If there is no logged in user, return an empty Prefs::
          * object with just default preferences. */
         if (!Auth::getAuth()) {
-            $prefs = &Prefs::factory('session', $app, '', '', null, false);
-            $prefs->retrieve();
-            $this->_prefsCache[$app] = &$prefs;
-            $GLOBALS['prefs'] = &$this->_prefsCache[$app];
-            $prefs_default = true;
-            return;
+            $GLOBALS['prefs'] = &Prefs::factory('session', $app, '', '', null, false);
+        } else {
+            if (!isset($GLOBALS['prefs']) || $GLOBALS['prefs']->getUser() != Auth::getAuth()) {
+                $GLOBALS['prefs'] = &Prefs::factory($GLOBALS['conf']['prefs']['driver'], $app,
+                                                    Auth::getAuth(), Auth::getCredential('password'));
+            } else {
+                $GLOBALS['prefs']->retrieve($app);
+            }
         }
-
-        /* Cache prefs objects so that we don't re-load them on every
-         * popApp() call. */
-        if (!isset($this->_prefsCache[$app]) ||
-            !empty($prefs_default)) {
-            $prefs = &Prefs::factory($GLOBALS['conf']['prefs']['driver'], $app,
-                                     Auth::getAuth(), Auth::getCredential('password'));
-            $prefs->retrieve();
-            $this->_prefsCache[$app] = &$prefs;
-        }
-
-        $GLOBALS['prefs'] = &$this->_prefsCache[$app];
     }
 
     /**
@@ -974,14 +1000,6 @@ class Registry {
      */
     function unloadPrefs($app = null)
     {
-        if ($app === null) {
-            $this->_prefsCache = array();
-        } elseif (isset($this->_prefsCache[$app])) {
-            unset($this->_prefsCache[$app]);
-        } else {
-            return;
-        }
-
         if ($this->_currentApp) {
             $this->loadPrefs();
         }
@@ -1038,29 +1056,32 @@ class Registry {
         if (empty($app)) {
             $app = $this->_currentApp;
         }
+        if ($this->get('status', $app) == 'heading') {
+            $app = 'horde';
+        }
 
-        static $img_dir = array();
-        if (isset($img_dir[$app])) {
-            return $img_dir[$app];
+        if (isset($this->_imgDir[$app])) {
+            return $this->_imgDir[$app];
         }
 
         /* This is the default location for the graphics. */
-        $img_dir[$app] = $this->get('themesuri', $app) . '/graphics';
-
-        static $theme_icons;
+        $this->_imgDir[$app] = $this->get('themesuri', $app) . '/graphics';
 
         /* Figure out if this is going to be overridden by any theme
          * settings. */
         if (isset($GLOBALS['prefs']) &&
-            ($theme = $GLOBALS['prefs']->getValue('theme')) &&
-            (isset($theme_icons) ||
-             ((@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
-              isset($theme_icons))) &&
-            in_array($app, $theme_icons)) {
-            $img_dir[$app] = $this->get('themesuri', $app) . '/' . $theme . '/graphics';
+            ($theme = $GLOBALS['prefs']->getValue('theme'))) {
+            if (!isset($this->_themeCache[$theme][$app])) {
+                $this->_themeCache[$theme][$app] = file_exists($this->get('themesfs', $app) . '/' . $theme . '/themed_graphics');
+                $this->_cacheVars(array('_themeCache'));
+            }
+
+            if ($this->_themeCache[$theme][$app]) {
+                $this->_imgDir[$app] = $this->get('themesuri', $app) . '/' . $theme . '/graphics';
+            }
         }
 
-        return $img_dir[$app];
+        return $this->_imgDir[$app];
     }
 
     /**
