@@ -3,12 +3,13 @@
  * SessionHandler implementation for LDAP directories.
  *
  * Required parameters:<pre>
- *   'foo'       The foo.
+ *   'hostspec' - (string) The hostname of the ldap server.
+ *   'port'     - (integer) The port number of the ldap server.
+ *   'dn'       - (string) The bind DN.
+ *   'password' - (string) The bind password.
+ * </pre>
  *
- * Optional parameters:<pre>
- *   'hostspec'  The hostname of the ldap server.
- *
- * $Horde: framework/SessionHandler/SessionHandler/ldap.php,v 1.2.2.2 2005/10/18 11:01:27 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/ldap.php,v 1.2.2.3 2007-12-20 13:49:39 jan Exp $
  *
  * This code is adapted from the comments at
  * http://www.php.net/session-set-save-handler.
@@ -31,23 +32,38 @@ class SessionHandler_ldap extends SessionHandler {
     /**
      * Open the SessionHandler backend.
      *
+     * @access private
+     *
      * @param string $save_path     The path to the session object.
      * @param string $session_name  The name of the session.
      *
      * @return boolean  True on success, false otherwise.
      */
-    function open($save_path, $session_name)
+    function _open($save_path = null, $session_name = null)
     {
         $this->_conn = @ldap_connect($this->_params['hostspec'], $this->_params['port']);
+
+        // Set protocol version if necessary.
+        if (isset($this->_params['version'])) {
+            if (!@ldap_set_option($this->_ds, LDAP_OPT_PROTOCOL_VERSION, $this->_params['version'])) {
+                return PEAR::raiseError(sprintf('Set LDAP protocol version to %d failed: [%d] %s',
+                                        $this->_params['version'],
+                                        ldap_errno($conn),
+                                        ldap_error($conn)));
+            }
+        }
+
         return @ldap_bind($this->_conn, $this->_params['dn'], $this->_params['password']);
     }
 
     /**
      * Close the SessionHandler backend.
      *
+     * @access private
+     *
      * @return boolean  True on success, false otherwise.
      */
-    function close()
+    function _close()
     {
         return @ldap_close($this->_conn);
     }
@@ -56,30 +72,30 @@ class SessionHandler_ldap extends SessionHandler {
      * Read the data for a particular session identifier from the
      * SessionHandler backend.
      *
+     * @access private
+     *
      * @param string $id  The session identifier.
      *
      * @return string  The session data.
      */
-    function read($id)
+    function _read($id)
     {
         $sr = @ldap_search($this->_conn, $this->_params['dn'], "(cn=$id)");
         $info = @ldap_get_entries($this->_conn, $sr);
-        if ($info['count'] > 0) {
-            return $info[0]['session'][0];
-        } else {
-            return '';
-        }
+        return ($info['count'] > 0) ? $info[0]['session'][0] : '';
     }
 
     /**
      * Write session data to the SessionHandler backend.
      *
+     * @access private
+     *
      * @param string $id            The session identifier.
      * @param string $session_data  The session data.
      *
      * @return boolean  True on success, false otherwise.
      */
-    function write($id, $session_data)
+    function _write($id, $session_data)
     {
         $update = array('objectClass' => array('phpsession', 'top'),
                         'session' => $session_data);
