@@ -13,28 +13,28 @@ require_once dirname(__FILE__) . '/sql.php';
  * (using MSSQL-2000).
  *
  * Required parameters:<pre>
- *   'hostspec'  The hostname of the database server.
- *   'protocol'  The communication protocol ('tcp', 'unix', etc.).
- *   'username'  The username with which to connect to the database.
- *   'password'  The password associated with 'username'.
- *   'database'  The name of the database.</pre>
+ *   'hostspec' - (string) The hostname of the database server.
+ *   'username' - (string) The username with which to connect to the database.
+ *   'password' - (string) The password associated with 'username'.
+ *   'database' - (string) The name of the database.
+ * </pre>
  *
  * Optional parameters:<pre>
- *   'table'     The name of the sessiondata table in 'database'.  Default is
- *               'horde_sessionhandler'.</pre>
+ *   'table' - (string) The name of the sessiondata table in 'database'.
+ *             DEFAULT: 'horde_sessionhandler'
+ * </pre>
  *
  * The table structure for the SessionHandler can be found in
  * horde/scripts/sql/horde_sessionhandler.sapdb.sql.
  *
- * $Horde: framework/SessionHandler/SessionHandler/sapdb.php,v 1.13.12.9 2007/01/02 13:54:38 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/sapdb.php,v 1.13.12.12 2009-01-06 15:23:35 jan Exp $
  *
- * Copyright 2002-2007 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @since   Horde 3.0
  * @package Horde_SessionHandler
  */
 class SessionHandler_sapdb extends SessionHandler_sql {
@@ -54,15 +54,14 @@ class SessionHandler_sapdb extends SessionHandler_sql {
      * Read the data for a particular session identifier from the
      * SessionHandler backend.
      *
+     * @access private
+     *
      * @param string $id  The session identifier.
      *
      * @return string  The session data.
      */
-    function read($id)
+    function _read($id)
     {
-        /* Make sure we have a valid database connection. */
-        $this->_connect();
-
         /* Begin a transaction. */
         $result = $this->_db->autocommit(false);
         if (is_a($result, 'PEAR_Error')) {
@@ -76,7 +75,7 @@ class SessionHandler_sapdb extends SessionHandler_sql {
                          $this->_db->quote($id));
 
         /* Log the query at a DEBUG log level. */
-        Horde::logMessage(sprintf('SQL Query by SessionHandler_sql::read(): query = "%s"', $query),
+        Horde::logMessage(sprintf('SQL Query by SessionHandler_sapdb::_read(): query = "%s"', $query),
                           __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
         /* Execute the query */
