@@ -3,7 +3,7 @@
  * Horde_Share_sql:: provides the sql backend for the horde share
  * driver.
  *
- * $Horde: framework/Share/Share/sql.php,v 1.1.2.57 2009/08/12 13:52:00 jan Exp $
+ * $Horde: framework/Share/Share/sql.php,v 1.1.2.61 2010-07-28 15:28:15 mrubinsk Exp $
  *
  * Copyright 2008-2009 The Horde Project (http://www.horde.org/)
  *
@@ -465,6 +465,9 @@ class Horde_Share_sql extends Horde_Share {
             @sqlite_query('PRAGMA short_column_names=1', $connection);
         }
 
+        // Log query at debug level
+        Horde::logMessage(sprintf('SQL query by Horde_Share_sql::listShares: %s', $query), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
         $result = $this->_db->query($query);
         if (is_a($result, 'PEAR_Error')) {
             Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
@@ -675,7 +678,7 @@ class Horde_Share_sql extends Horde_Share {
             $where .= ' OR (' . Horde_SQL::buildClause($this->_db, 's.perm_default',  '&', $perm) . ')';
 
             // (name == perm_users and key == $userid and val & $perm)
-            $query .= ' LEFT JOIN ' . $this->_table . '_users AS u ON u.share_id = s.share_id';
+            $query .= ' LEFT JOIN ' . $this->_table . '_users u ON u.share_id = s.share_id';
             $where .= ' OR ( u.user_uid = ' .  $this->_write_db->quote($userid)
                 . ' AND (' . Horde_SQL::buildClause($this->_db, 'u.perm', '&', $perm) . '))';
 
@@ -688,9 +691,9 @@ class Horde_Share_sql extends Horde_Share {
                 $ids = array_keys($groups);
                 $group_ids = array();
                 foreach ($ids as $id) {
-                    $group_ids[] = $this->_db->quote($id);
+                    $group_ids[] = $this->_db->quote((string)$id);
                 }
-                $query .= ' LEFT JOIN ' . $this->_table . '_groups AS g ON g.share_id = s.share_id';
+                $query .= ' LEFT JOIN ' . $this->_table . '_groups g ON g.share_id = s.share_id';
                 $where .= ' OR (g.group_uid IN (' . implode(',', $group_ids) . ')'
                     . ' AND (' . Horde_SQL::buildClause($this->_db, 'g.perm', '&', $perm) . '))';
             } elseif (is_a($groups, 'PEAR_Error')) {
@@ -768,15 +771,20 @@ class Horde_Share_sql extends Horde_Share {
             $this->_write_db->setOption('portability', MDB2_PORTABILITY_FIX_CASE | MDB2_PORTABILITY_ERRORS | MDB2_PORTABILITY_RTRIM | MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES);
             break;
 
-        case 'pgsql':
-            /* The debug handler breaks PostgreSQL. In most cases it shouldn't
-             * be necessary, but this may mean we simply can't support use of
-             * multiple Postgres databases right now. See
-             * http://bugs.horde.org/ticket/7825 */
-            $this->_write_db->setOption('debug', false);
-            // Fall through
-
         default:
+            switch ($this->_write_db->phptype) {
+            case 'oci8':
+                $this->_write_db->setOption('emulate_database', false);
+                break;
+
+            case 'pgsql':
+                /* The debug handler breaks PostgreSQL. In most cases it
+                 * shouldn't be necessary, but this may mean we simply can't
+                 * support use of multiple Postgres databases right now. See
+                 * http://bugs.horde.org/ticket/7825 */
+                $this->_write_db->setOption('debug', false);
+                break;
+            }
             $this->_write_db->setOption('field_case', CASE_LOWER);
             $this->_write_db->setOption('portability', MDB2_PORTABILITY_FIX_CASE | MDB2_PORTABILITY_ERRORS | MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES);
         }
@@ -798,15 +806,20 @@ class Horde_Share_sql extends Horde_Share {
                 $this->_db->setOption('portability', MDB2_PORTABILITY_FIX_CASE | MDB2_PORTABILITY_ERRORS | MDB2_PORTABILITY_RTRIM | MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES);
                 break;
 
-            case 'pgsql':
-                /* The debug handler breaks PostgreSQL. In most cases it shouldn't
-                 * be necessary, but this may mean we simply can't support use of
-                 * multiple Postgres databases right now. See
-                 * http://bugs.horde.org/ticket/7825 */
-                $this->_write_db->setOption('debug', false);
-                // Fall through
-
             default:
+                switch ($this->_db->phptype) {
+                case 'oci8':
+                    $this->_db->setOption('emulate_database', false);
+                    break;
+
+                case 'pgsql':
+                    /* The debug handler breaks PostgreSQL. In most cases it
+                     * shouldn't be necessary, but this may mean we simply
+                     * can't support use of multiple Postgres databases right
+                     * now. See http://bugs.horde.org/ticket/7825 */
+                    $this->_write_db->setOption('debug', false);
+                    break;
+                }
                 $this->_db->setOption('field_case', CASE_LOWER);
                 $this->_db->setOption('portability', MDB2_PORTABILITY_FIX_CASE | MDB2_PORTABILITY_ERRORS | MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES);
             }
