@@ -3,7 +3,7 @@
  * Implementation of Horde_Share class for shared objects that are hierarchical
  * in nature.
  *
- * $Horde: framework/Share/Share/sql_hierarchical.php,v 1.17.2.27 2009/03/24 17:47:15 mrubinsk Exp $
+ * $Horde: framework/Share/Share/sql_hierarchical.php,v 1.17.2.29 2010-07-27 23:12:03 mrubinsk Exp $
  *
  * @author  Duck <duck@obala.net>
  * @author  Michael J. Rubinsky <mrubinsk@horde.org>
@@ -214,7 +214,7 @@ class Horde_Share_sql_hierarchical extends Horde_Share_sql {
             $where .= ' OR (' . Horde_SQL::buildClause($this->_db, 's.perm_default',  '&', $perm) . ')';
 
             // (name == perm_users and key == $userid and val & $perm)
-            $query .= ' LEFT JOIN ' . $this->_table . '_users AS u ON u.share_id = s.share_id';
+            $query .= ' LEFT JOIN ' . $this->_table . '_users u ON u.share_id = s.share_id';
             $where .= ' OR ( u.user_uid = ' .  $this->_write_db->quote($userid)
             . ' AND (' . Horde_SQL::buildClause($this->_db, 'u.perm', '&', $perm) . '))';
 
@@ -227,9 +227,9 @@ class Horde_Share_sql_hierarchical extends Horde_Share_sql {
                 $ids = array_keys($groups);
                 $group_ids = array();
                 foreach ($ids as $id) {
-                    $group_ids[] = $this->_db->quote($id);
+                    $group_ids[] = $this->_db->quote((string)$id);
                 }
-                $query .= ' LEFT JOIN ' . $this->_table . '_groups AS g ON g.share_id = s.share_id';
+                $query .= ' LEFT JOIN ' . $this->_table . '_groups g ON g.share_id = s.share_id';
                 $where .= ' OR (g.group_uid IN (' . implode(',', $group_ids) . ')'
                     . ' AND (' . Horde_SQL::buildClause($this->_db, 'g.perm', '&', $perm) . '))';
             }
