@@ -3,22 +3,29 @@
  * Token tracking implementation for PHP's PEAR database abstraction layer.
  *
  * Required parameters:<pre>
- *   'phptype'   The database type (ie. 'pgsql', 'mysql', etc.).</pre>
+ *   'phptype'      The database type (ie. 'pgsql', 'mysql', etc.).</pre>
  *
  * Required by some database implementations:<pre>
- *   'database'  The name of the database.
- *   'hostspec'  The hostname of the database server.
- *   'username'  The username with which to connect to the database.
- *   'password'  The password associated with 'username'.
- *   'options'   Additional options to pass to the database.
- *   'tty'       The TTY on which to connect to the database.
- *   'port'      The port on which to connect to the database.</pre>
+ *   'database'     The name of the database.
+ *   'hostspec'     The hostname of the database server.
+ *   'username'     The username with which to connect to the database.
+ *   'password'     The password associated with 'username'.
+ *   'options'      Additional options to pass to the database.
+ *   'tty'          The TTY on which to connect to the database.
+ *   'port'         The port on which to connect to the database.</pre>
  *
  * Optional parameters:<pre>
- *   'table'     The name of the tokens table in 'database'.
- *               Defaults to 'horde_tokens'.
- *   'timeout'   The period (in seconds) after which an id is purged.
- *               Defaults to 86400 (i.e. 24 hours).</pre>
+ *   'table'        The name of the tokens table in 'database'.
+ *                  Defaults to 'horde_tokens'.
+ *   'timeout'      The period (in seconds) after which an id is purged.
+ *                  Defaults to 86400 (i.e. 24 hours).</pre>
+ *
+ * Optional values when using separate reading and writing servers, for example
+ * in replication settings:<pre>
+ *   'splitread'   Boolean, whether to implement the separation or not.
+ *   'read'        Array containing the parameters which are different for
+ *                 the read database connection, currently supported
+ *                 only 'hostspec' and 'port' parameters.</pre>
  *
  * The table structure for the tokens is as follows:
  *
@@ -32,9 +39,9 @@
  * );
  * </pre>
  *
- * $Horde: framework/Token/Token/sql.php,v 1.23.6.13 2007/01/02 13:54:45 jan Exp $
+ * $Horde: framework/Token/Token/sql.php,v 1.23.6.17 2009-02-13 05:45:19 chuck Exp $
  *
- * Copyright 1999-2007 Max Kalika <max@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -52,6 +59,14 @@ class Horde_Token_sql extends Horde_Token {
      */
     var $_db = '';
 
+    /**
+     * Handle for the current database connection, used for writing. Defaults
+     * to the same handle as $_db if a separate write database is not required.
+     *
+     * @var DB
+     */
+    var $_write_db;
+
     /**
      * Boolean indicating whether or not we're connected to the SQL
      * server.
@@ -87,15 +102,15 @@ class Horde_Token_sql extends Horde_Token {
         }
 
         /* Build SQL query. */
-        $query = 'DELETE FROM ' . $this->_params['table'] . ' WHERE ';
-        $query .= 'token_timestamp < ?';
+        $query = 'DELETE FROM ' . $this->_params['table']
+            . ' WHERE token_timestamp < ?';
 
         $values = array(time() - $this->_params['timeout']);
 
-        $result = $this->_db->query($query, $values);
-
-        /* Return an error if the update fails, too. */
+        /* Return an error if the update fails. */
+        $result = $this->_write_db->query($query, $values);
         if (is_a($result, 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
             return $result;
         }
 
@@ -109,14 +124,14 @@ class Horde_Token_sql extends Horde_Token {
         }
 
         /* Build SQL query. */
-        $query  = 'SELECT token_id FROM ' . $this->_params['table'];
-        $query .= ' WHERE token_address = ?';
-        $query .= ' AND token_id = ?';
+        $query = 'SELECT token_id FROM ' . $this->_params['table']
+            . ' WHERE token_address = ? AND token_id = ?';
 
         $values = array($this->encodeRemoteAddress(), $tokenID);
 
         $result = $this->_db->getOne($query, $values);
         if (is_a($result, 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         } else {
             return !empty($result);
@@ -130,13 +145,15 @@ class Horde_Token_sql extends Horde_Token {
         }
 
         /* Build SQL query. */
-        $query  = 'INSERT INTO ' . $this->_params['table'] . ' (token_address, token_id, token_timestamp) ';
-        $query .= 'VALUES (?, ?, ?)';
+        $query = 'INSERT INTO ' . $this->_params['table']
+            . ' (token_address, token_id, token_timestamp)'
+            . ' VALUES (?, ?, ?)';
 
         $values = array($this->encodeRemoteAddress(), $tokenID, time());
 
-        $result = $this->_db->query($query, $values);
+        $result = $this->_write_db->query($query, $values);
         if (is_a($result, 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
             return $result;
         }
 
@@ -178,38 +195,48 @@ class Horde_Token_sql extends Horde_Token {
 
         /* Connect to the SQL server using the supplied parameters. */
         require_once 'DB.php';
-        $this->_db = &DB::connect($this->_params,
-                                  array('persistent' => !empty($this->_params['persistent'])));
-        if (is_a($this->_db, 'PEAR_Error')) {
-            return $this->_db;
+        $this->_write_db = &DB::connect($this->_params,
+                                  array('persistent' => !empty($this->_params['persistent']),
+                                        'ssl' => !empty($this->_params['ssl'])));
+        if (is_a($this->_write_db, 'PEAR_Error')) {
+            return $this->_write_db;
         }
 
         // Set DB portability options.
-        switch ($this->_db->phptype) {
+        switch ($this->_write_db->phptype) {
         case 'mssql':
-            $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
+            $this->_write_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
             break;
         default:
-            $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
+            $this->_write_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
+        }
+
+        /* Check if we need to set up the read DB connection
+         * seperately. */
+        if (!empty($this->_params['splitread'])) {
+            $params = array_merge($this->_params, $this->_params['read']);
+            $this->_db = &DB::connect($params,
+                                      array('persistent' => !empty($params['persistent']),
+                                            'ssl' => !empty($this->_params['ssl'])));
+            if (is_a($this->_db, 'PEAR_Error')) {
+                return $this->_db;
+            }
+
+            // Set DB portability options.
+            switch ($this->_db->phptype) {
+            case 'mssql':
+                $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
+                break;
+            default:
+                $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
+            }
+
+        } else {
+            /* Default to the same DB handle for read. */
+            $this->_db = $this->_write_db;
         }
 
         $this->_connected = true;
-
-        return true;
-    }
-
-    /**
-     * Disconnect from the SQL server and clean up the connection.
-     *
-     * @return boolean  True on success, a PEAR_Error object on failure.
-     */
-    function _disconnect()
-    {
-        if ($this->_connected) {
-            $this->_connected = false;
-            return $this->_db->disconnect();
-        }
-
         return true;
     }
 
