@@ -3,12 +3,12 @@
  * The Horde_Tree_html:: class extends the Horde_Tree class to provide
  * HTML specific rendering functions.
  *
- * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Tree/Tree/html.php,v 1.51.2.9 2005/07/03 05:22:36 selsky Exp $
+ * $Horde: framework/Tree/Tree/html.php,v 1.51.2.16 2009-01-06 15:23:44 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @package Horde_Tree
@@ -28,56 +28,56 @@ class Horde_Tree_html extends Horde_Tree {
      *
      * @var string
      */
-    var $_img_line         = 'line.png';
+    var $_img_line = 'line.png';
 
     /**
      * Default tree graphic for a blank.
      *
      * @var string
      */
-    var $_img_blank        = 'blank.png';
+    var $_img_blank = 'blank.png';
 
     /**
      * Default tree graphic for a join.
      *
      * @var string
      */
-    var $_img_join         = 'join.png';
+    var $_img_join = 'join.png';
 
     /**
      * Default tree graphic for a bottom join.
      *
      * @var string
      */
-    var $_img_join_bottom  = 'joinbottom.png';
+    var $_img_join_bottom = 'joinbottom.png';
 
     /**
      * Default tree graphic for a plus.
      *
      * @var string
      */
-    var $_img_plus         = 'plus.png';
+    var $_img_plus = 'plus.png';
 
     /**
      * Default tree graphic for a bottom plus.
      *
      * @var string
      */
-    var $_img_plus_bottom  = 'plusbottom.png';
+    var $_img_plus_bottom = 'plusbottom.png';
 
     /**
      * Default tree graphic for a plus only.
      *
      * @var string
      */
-    var $_img_plus_only    = 'plusonly.png';
+    var $_img_plus_only = 'plusonly.png';
 
     /**
      * Default tree graphic for a minus.
      *
      * @var string
      */
-    var $_img_minus        = 'minus.png';
+    var $_img_minus = 'minus.png';
 
     /**
      * Default tree graphic for a bottom minus.
@@ -91,35 +91,35 @@ class Horde_Tree_html extends Horde_Tree {
      *
      * @var string
      */
-    var $_img_minus_only   = 'minusonly.png';
+    var $_img_minus_only = 'minusonly.png';
 
     /**
      * Default tree graphic for a null only.
      *
      * @var string
      */
-    var $_img_null_only    = 'nullonly.png';
+    var $_img_null_only = 'nullonly.png';
 
     /**
      * Default tree graphic for a folder.
      *
      * @var string
      */
-    var $_img_folder       = 'folder.png';
+    var $_img_folder = 'folder.png';
 
     /**
      * Default tree graphic for an open folder.
      *
      * @var string
      */
-    var $_img_folder_open  = 'folderopen.png';
+    var $_img_folder_open = 'folderopen.png';
 
     /**
      * Default tree graphic for a leaf.
      *
      * @var string
      */
-    var $_img_leaf         = 'leaf.png';
+    var $_img_leaf = 'leaf.png';
 
     /**
      * TODO
@@ -157,6 +157,20 @@ class Horde_Tree_html extends Horde_Tree {
         parent::Horde_Tree($tree_name, $params);
 
         $this->_img_dir = $GLOBALS['registry']->getImageDir('horde') . '/tree';
+
+        if (!empty($GLOBALS['nls']['rtl'][$GLOBALS['language']])) {
+            $this->_img_line = 'rev-line.png';
+            $this->_img_join = 'rev-join.png';
+            $this->_img_join_bottom = 'rev-joinbottom.png';
+            $this->_img_plus = 'rev-plus.png';
+            $this->_img_plus_bottom = 'rev-plusbottom.png';
+            $this->_img_plus_only = 'rev-plusonly.png';
+            $this->_img_minus = 'rev-minus.png';
+            $this->_img_minus_bottom = 'rev-minusbottom.png';
+            $this->_img_minus_only = 'rev-minusonly.png';
+            $this->_img_null_only = 'rev-nullonly.png';
+            $this->_img_leaf = 'rev-leaf.png';
+        }
     }
 
     /**
@@ -225,20 +239,22 @@ class Horde_Tree_html extends Horde_Tree {
         $html .= '>';
 
         foreach ($this->_header as $header) {
-            $html .= '<div';
+            $html .= '<div class="leftFloat';
             if (!empty($header['class'])) {
-                $html .= ' class="' . $header['class'] . '"';
+                $html .= ' ' . $header['class'];
             }
+            $html .= '"';
 
-            $style = 'float:left;';
+            $style = '';
             if (!empty($header['width'])) {
                 $style .= 'width:' . $header['width'] . ';';
             }
             if (!empty($header['align'])) {
                 $style .= 'text-align:' . $header['align'] . ';';
             }
-
-            $html .= ' style="' . $style . '"';
+            if (!empty($style)) {
+                $html .= ' style="' . $style . '"';
+            }
             $html .= '>';
             $html .= empty($header['html']) ? '&nbsp;' : $header['html'];
             $html .= '</div>';
@@ -307,22 +323,30 @@ class Horde_Tree_html extends Horde_Tree {
             $extra = $this->_nodes[$node_id]['extra'][HORDE_TREE_EXTRA_LEFT];
             $cMax = count($extra);
             for ($c = 0; $c < $cMax; $c++) {
-                $style = 'float:left;';
+                $style = '';
                 if (isset($this->_header[$column]['width'])) {
                     $style .= 'width:' . $this->_header[$column]['width'] . ';';
                 }
 
-                $line .= '<div style="' . $style . '">' . $extra[$c] . '</div>';
+                $line .= '<div class="leftFloat"';
+                if (!empty($style)) {
+                    $line .= ' style="' . $style . '"';
+                }
+                $line .= '>' . $extra[$c] . '</div>';
 
                 $column++;
             }
         }
 
-        $style = 'float:left;';
+        $style = '';
         if (isset($this->_header[$column]['width'])) {
             $style .= 'width:' . $this->_header[$column]['width'] . ';';
         }
-        $line .= '<div style="' . $style . '">';
+        $line .= '<div class="leftFloat"';
+        if (!empty($style)) {
+            $line .= ' style="' . $style . '"';
+        }
+        $line .= '>';
 
         if ($this->getOption('multiline')) {
             $line .= '<table cellspacing="0"><tr><td>';
@@ -356,12 +380,16 @@ class Horde_Tree_html extends Horde_Tree {
             $extra = $this->_nodes[$node_id]['extra'][HORDE_TREE_EXTRA_RIGHT];
             $cMax = count($extra);
             for ($c = 0; $c < $cMax; $c++) {
-                $style = 'float:left;';
+                $style = '';
                 if (isset($this->_header[$column]['width'])) {
                     $style .= 'width:' . $this->_header[$column]['width'] . ';';
                 }
 
-                $line .= '<div style="' . $style . '">' . $extra[$c] . '</div>';
+                $line .= '<div class="leftFloat"';
+                if (!empty($style)) {
+                    $line .= ' style="' . $style . '"';
+                }
+                $line .= '>' . $extra[$c] . '</div>';
 
                 $column++;
             }
@@ -564,14 +592,14 @@ class Horde_Tree_html extends Horde_Tree {
             }
         }
 
-        $imgtxt = '<img src="' . $img_dir . $img . '" style="vertical-align:middle" ';
+        $imgtxt = '<img src="' . $img_dir . $img . '"';
 
         /* Does the node have user defined alt text? */
         if (isset($this->_nodes[$node_id]['iconalt'])) {
-            $imgtxt .= 'alt="' . $this->_nodes[$node_id]['iconalt'] . '" ';
+            $imgtxt .= ' alt="' . htmlspecialchars($this->_nodes[$node_id]['iconalt']) . '"';
         }
 
-        return $imgtxt . '/>';
+        return $imgtxt . ' />';
     }
 
 }
