@@ -5,13 +5,15 @@ require_once dirname(__FILE__) . '/Widget.php';
 /**
  * The Horde_UI_Tabs:: class manages and renders a tab-like interface.
  *
- * $Horde: framework/UI/UI/Tabs.php,v 1.27.6.7 2005/07/03 05:05:55 selsky Exp $
+ * $Horde: framework/UI/UI/Tabs.php,v 1.27.6.14 2009-01-06 15:23:45 jan Exp $
  *
  * Copyright 2001-2003 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file LICENSE for license information (LGPL).
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
+ * @author  Jason M. Felice <jason.m.felice@gmail.com>
  * @since   Horde_UI 0.0.1
  * @package Horde_UI
  */
@@ -25,13 +27,13 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
     var $_tabs = array();
 
     /**
-     * Add a tab to the interface.
+     * Adds a tab to the interface.
      *
-     * @param string $title    The text which appears on the tab.
-     * @param string $link     The target page.
-     * @param mixed  $params   Either a string value to set the tab variable to,
-     *                         or a hash of parameters. If an array, the tab variable
-     *                         can be set by the 'tabname' key.
+     * @param string $title  The text which appears on the tab.
+     * @param string $link   The target page.
+     * @param mixed $params  Either a string value to set the tab variable to,
+     *                       or a hash of parameters. If an array, the tab
+     *                       variable can be set by the 'tabname' key.
      */
     function addTab($title, $link, $params = array())
     {
@@ -45,7 +47,7 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
     }
 
     /**
-     * Retrieve the title of the tab with the specified name.
+     * Returns the title of the tab with the specified name.
      *
      * @param string $tabname  The name of the tab.
      *
@@ -71,7 +73,7 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
      */
     function render($active_tab = null)
     {
-        $html = "<ul class=\"tabset\">\n";
+        $html = "<div class=\"tabset\"><ul>\n";
 
         $first = true;
         $active = $_SERVER['PHP_SELF'] . $this->_vars->get($this->_name);
@@ -83,10 +85,15 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
                                            $tab['tabname']);
             }
 
-            $class = null;
+            $class = '';
             if ((!is_null($active_tab) && $active_tab == $tab['tabname']) ||
                 ($active == $tab['link'] . $tab['tabname'])) {
-                $class = 'activeTab';
+                $class = ' class="activeTab"';
+            }
+
+            $id = '';
+            if (!empty($tab['id'])) {
+                $id = ' id="' . htmlspecialchars($tab['id']) . '"';
             }
 
             if (!isset($tab['target'])) {
@@ -99,13 +106,13 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
 
             $accesskey = Horde::getAccessKey($tab['title']);
 
-            $html .= '<li>' .
-                Horde::link($link, $tab['title'], $class, $tab['target'], $tab['onclick'], null, $accesskey) .
-                str_replace(' ', '&nbsp;', Horde::highlightAccessKey($tab['title'], $accesskey)) .
+            $html .= '<li' . $class . $id . '>' .
+                Horde::link($link, '', '', $tab['target'], $tab['onclick'], null, $accesskey) .
+                Horde::highlightAccessKey(str_replace(' ', '&nbsp;', $tab['title']), $accesskey) .
                 "</a> </li>\n";
         }
 
-        return $html . "</ul>\n";
+        return $html . "</ul></div><br class=\"clear\" />\n";
     }
 
 }
