@@ -12,7 +12,7 @@ include_once 'Horde/NLS.php';
 /**
  * Class representing iCalendar files.
  *
- * $Horde: framework/iCalendar/iCalendar.php,v 1.57.4.76 2009/05/14 10:47:29 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar.php,v 1.57.4.81 2010-11-10 14:34:25 jan Exp $
  *
  * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
@@ -537,42 +537,10 @@ class Horde_iCalendar {
         }
         $vCal = trim($vCal);
 
-        // All subcomponents.
-        $matches = null;
-        if (preg_match_all('/^BEGIN:(.*)(\r\n|\r|\n)(.*)^END:\1/Uims', $vCal, $matches)) {
-            // vTimezone components are processed first. They are
-            // needed to process vEvents that may use a TZID.
-            foreach ($matches[0] as $key => $data) {
-                $type = trim($matches[1][$key]);
-                if ($type != 'VTIMEZONE') {
-                    continue;
-                }
-                $component = &Horde_iCalendar::newComponent($type, $this);
-                if ($component === false) {
-                    return PEAR::raiseError("Unable to create object for type $type");
-                }
-                $component->parsevCalendar($data, $type, $charset);
-
-                $this->addComponent($component);
-
-                // Remove from the vCalendar data.
-                $vCal = str_replace($data, '', $vCal);
-            }
-
-            // Now process the non-vTimezone components.
-            foreach ($matches[0] as $key => $data) {
-                $type = trim($matches[1][$key]);
-                if ($type == 'VTIMEZONE') {
-                    continue;
-                }
-                $component = &Horde_iCalendar::newComponent($type, $this);
-                if ($component === false) {
-                    return PEAR::raiseError("Unable to create object for type $type");
-                }
-                $component->parsevCalendar($data, $type, $charset);
-
-                $this->addComponent($component);
-
+        // Extract all subcomponents.
+        $matches = $components = null;
+        if (preg_match_all('/^BEGIN:(.*)(\r\n|\r|\n)(.*)^END:\1/Uims', $vCal, $components)) {
+            foreach ($components[0] as $key => $data) {
                 // Remove from the vCalendar data.
                 $vCal = str_replace($data, '', $vCal);
             }
@@ -618,8 +586,16 @@ class Horde_iCalendar {
                                 $paramValue = $paramValue[0];
                             }
                         }
-                        if (preg_match('/"([^"]*)"/', $paramValue, $parts)) {
-                            $paramValue = $parts[1];
+                        if (is_string($paramValue)) {
+                            if (preg_match('/"([^"]*)"/', $paramValue, $parts)) {
+                                $paramValue = $parts[1];
+                            }
+                        } else {
+                            foreach ($paramValue as $k => $tmp) {
+                                if (preg_match('/"([^"]*)"/', $tmp, $parts)) {
+                                    $paramValue[$k] = $parts[1];
+                                }
+                            }
                         }
                         $params[$paramName] = $paramValue;
                     }
@@ -659,6 +635,7 @@ class Horde_iCalendar {
 
                 case 'BDAY':
                 case 'X-SYNCJE-ANNIVERSARY':
+                case 'X-ANNIVERSARY':
                     $this->setAttribute($tag, $this->_parseDate($value), $params);
                     break;
 
@@ -690,8 +667,12 @@ class Horde_iCalendar {
                 // Comma seperated dates.
                 case 'EXDATE':
                 case 'RDATE':
+                    if (!strlen($value)) {
+                        break;
+                    }
                     $dates = array();
-                    preg_match_all('/,([^,]*)/', ',' . $value, $values);
+                    $separator = $this->isOldFormat() ? ';' : ',';
+                    preg_match_all('/' . $separator . '([^' . $separator . ']*)/', $separator . $value, $values);
 
                     foreach ($values[1] as $value) {
                         $dates[] = $this->_parseDate($value);
@@ -800,6 +781,40 @@ class Horde_iCalendar {
             }
         }
 
+        // Process all components.
+        if ($components) {
+            // vTimezone components are processed first. They are
+            // needed to process vEvents that may use a TZID.
+            foreach ($components[0] as $key => $data) {
+                $type = trim($components[1][$key]);
+                if ($type != 'VTIMEZONE') {
+                    continue;
+                }
+                $component = &Horde_iCalendar::newComponent($type, $this);
+                if ($component === false) {
+                    return PEAR::raiseError("Unable to create object for type $type");
+                }
+                $component->parsevCalendar($data, $type, $charset);
+
+                $this->addComponent($component);
+            }
+
+            // Now process the non-vTimezone components.
+            foreach ($components[0] as $key => $data) {
+                $type = trim($components[1][$key]);
+                if ($type == 'VTIMEZONE') {
+                    continue;
+                }
+                $component = &Horde_iCalendar::newComponent($type, $this);
+                if ($component === false) {
+                    return PEAR::raiseError("Unable to create object for type $type");
+                }
+                $component->parsevCalendar($data, $type, $charset);
+
+                $this->addComponent($component);
+            }
+        }
+
         return true;
     }
 
@@ -929,7 +944,7 @@ class Horde_iCalendar {
                         $dates[] = $this->_exportDateTime($date);
                     }
                 }
-                $value = implode(',', $dates);
+                $value = implode($this->isOldFormat() ? ';' : ',', $dates);
                 break;
 
             case 'TRIGGER':
@@ -1237,16 +1252,11 @@ class Horde_iCalendar {
         $temp = array();
         if (!is_object($value) && !is_array($value)) {
             $tz = date('O', $value);
-            $TZOffset = (3600 * substr($tz, 0, 3)) + (60 * substr(date('O', $value), 3, 2));
+            $TZOffset = (3600 * substr($tz, 0, 3)) + (60 * substr($tz, 3, 2));
             $value -= $TZOffset;
 
             $temp['zone']   = 'UTC';
-            $temp['year']   = date('Y', $value);
-            $temp['month']  = date('n', $value);
-            $temp['mday']   = date('j', $value);
-            $temp['hour']   = date('G', $value);
-            $temp['minute'] = date('i', $value);
-            $temp['second'] = date('s', $value);
+            list($temp['year'], $temp['month'], $temp['mday'], $temp['hour'], $temp['minute'], $temp['second']) = explode('-', date('Y-n-j-G-i-s', $value));
         } else {
             $dateOb = new Horde_Date($value);
             return Horde_iCalendar::_exportDateTime($dateOb->timestamp());
