@@ -10,9 +10,9 @@ require_once 'SyncML/Command.php';
  * The Final command is an indicator that the SyncML message is the last
  * message in the current SyncML package.
  *
- * $Horde: framework/SyncML/SyncML/Command/Final.php,v 1.10.10.9 2008/09/22 04:16:29 chuck Exp $
+ * $Horde: framework/SyncML/SyncML/Command/Final.php,v 1.10.10.11 2009-04-05 20:24:43 jan Exp $
  *
- * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -34,7 +34,7 @@ class SyncML_Command_Final extends SyncML_Command {
     /**
      * Implements the actual business logic of the Alert command.
      */
-    function handleCommand()
+    function handleCommand($debug = false)
     {
         $state = &$_SESSION['SyncML.state'];
 
@@ -49,7 +49,7 @@ class SyncML_Command_Final extends SyncML_Command {
         $GLOBALS['backend']->logMessage('Received <Final> from client.',
                                         __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
-        $state->handleFinal($this->_outputHandler);
+        $state->handleFinal($this->_outputHandler, $debug);
     }
 
 }
