@@ -4,8 +4,21 @@
  *
  * This class renders the diff in classic "unified diff" format.
  *
- * $Horde: framework/Text_Diff/Diff/Renderer/unified.php,v 1.3.10.1 2005/03/22 09:54:05 jan Exp $
+ * $Horde: framework/Text_Diff/Diff/Renderer/unified.php,v 1.3.10.7 2009-01-06 15:23:42 jan Exp $
  *
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://opensource.org/licenses/lgpl-license.php.
+ *
+ * @author  Ciprian Popovici
+ * @package Text_Diff
+ */
+
+/** Text_Diff_Renderer */
+require_once 'Text/Diff/Renderer.php';
+
+/**
  * @package Text_Diff
  */
 class Text_Diff_Renderer_unified extends Text_Diff_Renderer {
@@ -31,6 +44,11 @@ class Text_Diff_Renderer_unified extends Text_Diff_Renderer {
         return "@@ -$xbeg +$ybeg @@";
     }
 
+    function _context($lines)
+    {
+        return $this->_lines($lines, ' ');
+    }
+
     function _added($lines)
     {
         return $this->_lines($lines, '+');
