@@ -3,19 +3,19 @@
  * The Text_Flowed:: class provides common methods for manipulating text
  * using the encoding described in RFC 3676 ('flowed' text).
  *
- * $Horde: framework/Text_Flowed/Flowed.php,v 1.14.10.18 2007/01/02 13:54:44 jan Exp $
+ * $Horde: framework/Text_Flowed/Flowed.php,v 1.14.10.21 2009-01-06 15:23:43 jan Exp $
  *
  * This class is based on the Text::Flowed perl module (Version 0.14) found
  * in the CPAN perl repository.  This module is released under the Perl
  * license, which is compatible with the LGPL.
  *
- * Copyright 2002-2007 Philip Mak
- * Copyright 2004-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2003 Philip Mak
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @since   Horde 3.0
  * @package Horde_Text
  */
@@ -50,7 +50,14 @@ class Text_Flowed {
      *
      * @var array
      */
-    var $_output = null;
+    var $_output = array();
+
+    /**
+     * The format of the data in $_output.
+     *
+     * @var string
+     */
+    var $_formattype = null;
 
     /**
      * The character set of the text.
@@ -123,10 +130,12 @@ class Text_Flowed {
         $txt = '';
 
         $this->_reformat(false, $quote);
-        foreach ($this->_output as $val) {
-            $txt .= $val['text'] . "\n";
+        reset($this->_output);
+        $lines = count($this->_output) - 1;
+        while (list($no, $line) = each($this->_output)) {
+            $txt .= $line['text'] . (($lines == $no) ? '' : "\n");
         }
-        return rtrim($txt);
+        return $txt;
     }
 
     /**
@@ -160,8 +169,9 @@ class Text_Flowed {
         $txt = '';
 
         $this->_reformat(true, $quote);
-        foreach ($this->_output as $val) {
-            $txt .= $val['text'] . "\n";
+        reset($this->_output);
+        while (list(,$line) = each($this->_output)) {
+            $txt .= $line['text'] . "\n";
         }
         return $txt;
     }
@@ -174,25 +184,32 @@ class Text_Flowed {
      *
      * @param boolean $toflowed  Convert to flowed?
      * @param boolean $quote     Add level of quoting to each line?
-     *
-     * @return array  A list of arrays.
      */
     function _reformat($toflowed, $quote)
     {
-        if (!is_null($this->_output)) {
+        $format_type = implode('|', array($toflowed, $quote));
+        if ($format_type == $this->_formattype) {
             return;
         }
 
         $this->_output = array();
-        $text = explode("\n", $this->_text);
+        $this->_formattype = $format_type;
 
         /* Set variables used in regexps. */
         $delsp = ($toflowed && $this->_delsp) ? 1 : 0;
         $opt = $this->_optlength - 1 - $delsp;
 
         /* Process message line by line. */
-        do {
-            $line = array_shift($text);
+        $text = explode("\n", $this->_text);
+        $text_count = count($text) - 1;
+        $skip = 0;
+        reset($text);
+
+        while (list($no, $line) = each($text)) {
+            if ($skip) {
+                --$skip;
+                continue;
+            }
 
             /* Per RFC 2646 [4.3], the 'Usenet Signature Convention' line
              * (DASH DASH SP) is not considered flowed.  Watch for this when
@@ -215,17 +232,19 @@ class Text_Flowed {
                  * at the end of the line), and there is a next line, and the
                  * next line has the same quote depth, add to the current
                  * line. A line is not flowed if it is a signature line. */
-                while (!empty($line) &&
-                       ($line != '-- ') &&
-                       ($line{strlen($line)-1} == ' ') &&
-                       !empty($text) &&
-                       ($this->_numquotes($text[0]) == $num_quotes)) {
-                    /* If DelSp is yes and this is flowed input, we need to
-                     * remove the trailing space. */
-                    if (!$toflowed && $this->_delsp) {
-                        $line = substr($line, 0, -1);
+                if ($line != '-- ') {
+                    while (!empty($line) && 
+                           ($line[strlen($line) - 1] == ' ') &&
+                           ($text_count != $no) &&
+                           ($this->_numquotes($text[$no + 1]) == $num_quotes)) {
+                        /* If DelSp is yes and this is flowed input, we need to
+                         * remove the trailing space. */
+                        if (!$toflowed && $this->_delsp) {
+                            $line = substr($line, 0, -1);
+                        }
+                        $line .= $this->_unstuff(substr($text[++$no], $num_quotes));
+                        ++$skip;
                     }
-                    $line .= $this->_unstuff(substr(array_shift($text), $num_quotes));
                 }
             }
 
@@ -284,7 +303,7 @@ class Text_Flowed {
                         /* One excessively long word left on line.  Be
                          * absolutely sure it does not exceed 998 characters
                          * in length or else we must truncate. */
-                        if ($line_length > 998) { 
+                        if ($line_length > 998) {
                             $this->_output[] = array('text' => String::substr($line, 0, 998, $this->_charset), 'level' => $num_quotes);
                             $line = String::substr($line, 998, null, $this->_charset);
                         } else {
@@ -294,7 +313,7 @@ class Text_Flowed {
                     }
                 }
             }
-        } while (!empty($text));
+        }
     }
 
     /**
@@ -345,7 +364,7 @@ class Text_Flowed {
      */
     function _unstuff($text)
     {
-        if (!empty($text) && ($text{0} == ' ')) {
+        if (!empty($text) && ($text[0] == ' ')) {
             $text = substr($text, 1);
         }
         return $text;
