@@ -9,7 +9,7 @@
  * 'apache', or 'www-data') MUST have read/write permission to the
  * directory you specify as the 'vfsroot'.
  *
- * $Horde: framework/VFS/lib/VFS/file.php,v 1.1.2.5 2009/01/06 15:23:47 jan Exp $
+ * $Horde: framework/VFS/lib/VFS/file.php,v 1.1.2.7 2010-06-29 04:51:13 slusarz Exp $
  *
  * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
@@ -289,6 +289,11 @@ class VFS_file extends VFS {
             }
         }
 
+        $res = $this->_checkQuotaWrite('file', $orig);
+        if (is_a($res, 'PEAR_Error')) {
+            return $res;
+        }
+
         if (!@copy($orig, $this->_getNativePath($dest, $name))) {
             return PEAR::raiseError(_("Unable to copy VFS file."));
         }
@@ -718,7 +723,9 @@ class VFS_file extends VFS {
     {
         $name = basename($name);
         if (strlen($name)) {
-            $name = str_replace('..', '', $name);
+            if ($name == '..') {
+                $name = '';
+            }
             if (substr($name, 0, 1) != '/') {
                 $name = '/' . $name;
             }
