@@ -21,7 +21,7 @@
  *   - changePermissions(): The SMB permission style does not fit with the
  *                          module.
  *
- * $Horde: framework/VFS/VFS/smb.php,v 1.11.2.8 2006/05/31 04:50:02 slusarz Exp $
+ * $Horde: framework/VFS/lib/VFS/smb.php,v 1.1.2.5 2009-02-06 18:24:20 slusarz Exp $
  *
  * Codebase copyright 2002 Paul Gareau <paul@xhawk.net>.  Adapted with
  * permission by Patrice Levesque <wayne@ptaff.ca> from phpsmb-0.8 code, and
@@ -82,29 +82,71 @@ class VFS_smb extends VFS {
      */
     function read($path, $name)
     {
-        list($path, $name) = $this->_escapeShellCommand($path, $name);
-        $temp = $this->_getTempFile();
-        $cmd = array('get \"' . $name . '\" ' . $temp);
-        $err = $this->_command($path, $cmd);
-        if (is_a($err, 'PEAR_Error')) {
-            return $err;
-        }
-        if (!file_exists($temp)) {
-            return PEAR::raiseError(sprintf(_("Unable to open VFS file \"%s\"."), $this->_getPath($path, $name)));
-        }
-        if (function_exists('file_get_contents')) {
-            $file = file_get_contents($temp);
-        } else {
-            $fp = fopen($temp, 'r');
-            $file = fread($fp, filesize($temp));
-            fclose($fp);
-        }
-        unlink($temp);
-        if ($file) {
+        $file = $this->readFile($path, $name);
+        if (is_a($file, 'PEAR_Error')) {
             return $file;
-        } else {
+        }
+
+        $size = filesize($file);
+        if ($size === 0) {
+            return '';
+        }
+
+        return file_get_contents($file);
+    }
+
+    /**
+     * Retrieves a file from the VFS as an on-disk local file.
+     *
+     * This function provides a file on local disk with the data of a VFS file
+     * in it. This file <em>cannot</em> be modified! The behavior if you do
+     * modify it is undefined. It will be removed at the end of the request.
+     *
+     * @param string $path  The pathname to the file.
+     * @param string $name  The filename to retrieve.
+     *
+     * @return string A local filename.
+     */
+    function readFile($path, $name)
+    {
+        // Create a temporary file and register it for deletion at the
+        // end of this request.
+        $localFile = $this->_getTempFile();
+        if (!$localFile) {
+            return PEAR::raiseError(_("Unable to create temporary file."));
+        }
+        register_shutdown_function(create_function('', 'unlink(\'' . addslashes($localFile) . '\');'));
+
+        list($path, $name) = $this->_escapeShellCommand($path, $name);
+        $cmd = array('get \"' . $name . '\" ' . $localFile);
+        $result = $this->_command($path, $cmd);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+        if (!file_exists($localFile)) {
             return PEAR::raiseError(sprintf(_("Unable to open VFS file \"%s\"."), $this->_getPath($path, $name)));
         }
+
+        return $localFile;
+    }
+
+    /**
+     * Open a stream to a file in the VFS.
+     *
+     * @param string $path  The pathname to the file.
+     * @param string $name  The filename to retrieve.
+     *
+     * @return resource  The stream.
+     */
+    function readStream($path, $name)
+    {
+        $file = $this->readFile($path, $name);
+        if (is_a($file, 'PEAR_Error')) {
+            return $file;
+        }
+
+        $mode = OS_WINDOWS ? 'rb' : 'r';
+        return fopen($file, $mode);
     }
 
     /**
@@ -170,6 +212,12 @@ class VFS_smb extends VFS {
      */
     function deleteFile($path, $name)
     {
+        // In some samba versions after samba-3.0.25-pre2, $path must
+        // end in a trailing slash.
+        if (substr($path, -1) != '/') {
+            $path .= '/';
+        }
+
         list($path, $name) = $this->_escapeShellCommand($path, $name);
         $cmd = array('del \"' . $name . '\"');
         $err = $this->_command($path, $cmd);
@@ -209,16 +257,13 @@ class VFS_smb extends VFS {
      */
     function deleteFolder($path, $name, $recursive = false)
     {
-        $isDir = false;
-        $dirCheck = $this->listFolder($path);
-        foreach ($dirCheck as $file) {
-            if ($file['name'] == $name && $file['type'] == '**dir') {
-                $isDir = true;
-                break;
-            }
+        // In some samba versions after samba-3.0.25-pre2, $path must
+        // end in a trailing slash.
+        if (substr($path, -1) != '/') {
+            $path .= '/';
         }
 
-        if (!$isDir) {
+        if (!$this->isFolder($path, $name)) {
             return PEAR::raiseError(sprintf(_("\"%s\" is not a directory."), $path . '/' . $name));
         }
 
@@ -270,12 +315,27 @@ class VFS_smb extends VFS {
             return $result;
         }
 
-        // Double quotes not allowed in SMB filename.
-        $newname = str_replace('"', "'", $newname);
+        // Double quotes not allowed in SMB filename. The '/' character should
+        // also be removed from the beginning/end of the names.
+        $oldname = str_replace('"', "'", trim($oldname, '/'));
+        $newname = str_replace('"', "'", trim($newname, '/'));
+
+        if (empty($oldname)) {
+            return PEAR::raiseError(_("Unable to rename VFS file to same name."));
+        }
+
+        /* If the path was not empty (i.e. the path is not the root path),
+         * then add the trailing '/' character to path. */
+        if (!empty($oldpath)) {
+            $oldpath .= '/';
+        }
+        if (!empty($newpath)) {
+            $newpath .= '/';
+        }
 
         list($file, $name) = $this->_escapeShellCommand($oldname, $newname);
-        $cmd = array('rename \"' .  str_replace('/', '\\\\', $oldpath) . '\\' . $file . '\" \"' .
-                                    str_replace('/', '\\\\', $newpath) . '\\' . $name . '\"');
+        $cmd = array('rename \"' .  str_replace('/', '\\\\', $oldpath) . $file . '\" \"' .
+                                    str_replace('/', '\\\\', $newpath) . $name . '\"');
         if (is_a($err = $this->_command('', $cmd), 'PEAR_Error')) {
             return PEAR::raiseError(sprintf(_("Unable to rename VFS file \"%s\"."), $this->_getPath($path, $name)));
         }
@@ -293,6 +353,12 @@ class VFS_smb extends VFS {
      */
     function createFolder($path, $name)
     {
+        // In some samba versions after samba-3.0.25-pre2, $path must
+        // end in a trailing slash.
+        if (substr($path, -1) != '/') {
+            $path .= '/';
+        }
+
         // Double quotes not allowed in SMB filename.
         $name = str_replace('"', "'", $name);
 
@@ -431,20 +497,31 @@ class VFS_smb extends VFS {
     /**
      * Copies a file through the backend.
      *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $dest         The destination of the file.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return boolean|PEAR_Error  True on success or a PEAR_Error on failure.
      */
-    function copy($path, $name, $dest)
+    function copy($path, $name, $dest, $autocreate = false)
     {
         $orig = $this->_getPath($path, $name);
         if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
             return PEAR::raiseError(_("Cannot copy file(s) - source and destination are the same."));
         }
 
+        if ($autocreate) {
+            $result = $this->autocreatePath($dest);
+            if (is_a($result, 'PEAR_Error')) {
+                return $result;
+            }
+        }
+
         $fileCheck = $this->listFolder($dest, null, true);
+        if (is_a($fileCheck, 'PEAR_Error')) {
+            return $fileCheck;
+        }
         foreach ($fileCheck as $file) {
             if ($file['name'] == $name) {
                 return PEAR::raiseError(sprintf(_("%s already exists."),
@@ -452,40 +529,18 @@ class VFS_smb extends VFS {
             }
         }
 
-        $isDir = false;
-        $dirCheck = $this->listFolder($path, null, false);
-        foreach ($dirCheck as $file) {
-            if ($file['name'] == $name && $file['type'] == '**dir') {
-                $isDir = true;
-                break;
-            }
-        }
-
-        if ($isDir) {
-            $result = $this->createFolder($dest, $name);
-
-            if (is_a($result, 'PEAR_Error')) {
+        if ($this->isFolder($path, $name)) {
+            if (is_a($result = $this->_copyRecursive($path, $name, $dest), 'PEAR_Error')) {
                 return $result;
             }
-
-            $file_list = $this->listFolder($orig);
-            foreach ($file_list as $file) {
-                $result = $this->copy($orig,
-                                      $file['name'],
-                                      $this->_getPath($dest, $name));
-                if (is_a($result, 'PEAR_Error')) {
-                    return $result;
-                }
-            }
         } else {
-            $tmpFile = $this->_createTempFile($path, $name);
+            $tmpFile = $this->readFile($path, $name);
             if (is_a($tmpFile, 'PEAR_Error')) {
                 return PEAR::raiseError(sprintf(_("Failed to retrieve: %s"), $orig));
             }
 
-            $res = $this->write($dest, $name, $tmpFile);
-            unlink($tmpFile);
-            if (is_a($res, 'PEAR_Error')) {
+            $result = $this->write($dest, $name, $tmpFile);
+            if (is_a($result, 'PEAR_Error')) {
                 return PEAR::raiseError(sprintf(_("Copy failed: %s"),
                                                 $this->_getPath($dest, $name)));
             }
@@ -497,20 +552,31 @@ class VFS_smb extends VFS {
     /**
      * Moves a file through the backend.
      *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $dest         The destination of the file.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return boolean|PEAR_Error  True on success or a PEAR_Error on failure.
      */
-    function move($path, $name, $dest)
+    function move($path, $name, $dest, $autocreate = false)
     {
         $orig = $this->_getPath($path, $name);
         if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
             return PEAR::raiseError(_("Cannot move file(s) - destination is within source."));
         }
 
+        if ($autocreate) {
+            $result = $this->autocreatePath($dest);
+            if (is_a($result, 'PEAR_Error')) {
+                return $result;
+            }
+        }
+
         $fileCheck = $this->listFolder($dest, null, true);
+        if (is_a($fileCheck, 'PEAR_Error')) {
+            return $fileCheck;
+        }
         foreach ($fileCheck as $file) {
             if ($file['name'] == $name) {
                 return PEAR::raiseError(sprintf(_("%s already exists."),
@@ -526,22 +592,6 @@ class VFS_smb extends VFS {
         return true;
     }
 
-    /**
-     * Returns the full path of an item.
-     *
-     * @param string $path  The path of directory of the item.
-     * @param string $name  The name of the item.
-     *
-     * @return mixed  Full path when $path isset and just $name when not set.
-     */
-    function _getPath($path, $name)
-    {
-        if ($path !== '') {
-             return ($path . '/' . $name);
-        }
-        return $name;
-    }
-
     /**
      * Replacement for escapeshellcmd(), variable length args, as we only want
      * certain characters escaped.
@@ -651,29 +701,4 @@ class VFS_smb extends VFS {
         return $this->_execute($fullcmd);
     }
 
-    /**
-     * Retrieves a file from the VFS and stores it to a temporary file.
-     *
-     * @access private
-     *
-     * @param string $path  The pathname to the file.
-     * @param string $name  The filename to retrieve.
-     *
-     * @return mixed  The temporary filename or a PEAR_Error on failure.
-     */
-    function _createTempFile($path, $name)
-    {
-        list($path, $name) = $this->_escapeShellCommand($path, $name);
-        $temp = $this->_getTempFile();
-        $cmd = array('get \"' . $name . '\" ' . $temp);
-        $err = $this->_command($path, $cmd);
-        if (is_a($err, 'PEAR_Error')) {
-            return $err;
-        }
-        if (!file_exists($temp)) {
-            return PEAR::raiseError(sprintf(_("Unable to open VFS file \"%s\"."), $this->_getPath($path, $name)));
-        }
-        return $temp;
-    }
-
 }
