@@ -14,24 +14,30 @@ define('VFS_FOLDER', 2);
  * VFS implementation for PHP's PEAR database abstraction layer.
  *
  * Required values for $params:<pre>
- *      'phptype'       The database type (ie. 'pgsql', 'mysql', etc.).</pre>
+ *   'phptype'      The database type (ie. 'pgsql', 'mysql', etc.).</pre>
  *
  * Optional values:<pre>
- *      'table'         The name of the vfs table in 'database'. Defaults to
- *                      'horde_vfs'.</pre>
+ *   'table'          The name of the vfs table in 'database'. Defaults to
+ *                    'horde_vfs'.</pre>
  *
  * Required by some database implementations:<pre>
- *      'hostspec'      The hostname of the database server.
- *      'protocol'      The communication protocol ('tcp', 'unix', etc.).
- *      'database'      The name of the database.
- *      'username'      The username with which to connect to the database.
- *      'password'      The password associated with 'username'.
- *      'options'       Additional options to pass to the database.
- *      'tty'           The TTY on which to connect to the database.
- *      'port'          The port on which to connect to the database.</pre>
+ *   'hostspec'     The hostname of the database server.
+ *   'protocol'     The communication protocol ('tcp', 'unix', etc.).
+ *   'database'     The name of the database.
+ *   'username'     The username with which to connect to the database.
+ *   'password'     The password associated with 'username'.
+ *   'options'      Additional options to pass to the database.
+ *   'tty'          The TTY on which to connect to the database.
+ *   'port'         The port on which to connect to the database.</pre>
  *
- * The table structure for the VFS can be found in
- * data/vfs.sql.
+ * Optional values when using separate reading and writing servers, for example
+ * in replication settings:<pre>
+ *   'splitread'   Boolean, whether to implement the separation or not.
+ *   'read'        Array containing the parameters which are different for
+ *                 the read database connection, currently supported
+ *                 only 'hostspec' and 'port' parameters.</pre>
+ *
+ * The table structure for the VFS can be found in data/vfs.sql.
  *
  * Database specific notes:
  *
@@ -46,9 +52,9 @@ define('VFS_FOLDER', 2);
  *    mssql.textsize = 0 ; zero to pass through
  * </pre>
  *
- * $Horde: framework/VFS/VFS/sql.php,v 1.85.4.30 2007/06/05 23:37:48 slusarz Exp $
+ * $Horde: framework/VFS/lib/VFS/sql.php,v 1.1.2.6 2009-02-13 05:45:19 chuck Exp $
  *
- * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -65,6 +71,22 @@ class VFS_sql extends VFS {
      */
     var $_db = false;
 
+    /**
+     * Handle for the current database connection, used for writing. Defaults
+     * to the same handle as $_db if a separate write database is not required.
+     *
+     * @var DB
+     */
+    var $_write_db;
+
+    /**
+     * Boolean indicating whether or not we're connected to the SQL
+     * server.
+     *
+     * @var boolean
+     */
+    var $_connected = false;
+
     /**
      * Retrieves the filesize from the VFS.
      *
@@ -75,9 +97,9 @@ class VFS_sql extends VFS {
      */
     function size($path, $name)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $length_op = $this->_getFileSizeOp();
@@ -110,9 +132,9 @@ class VFS_sql extends VFS {
      */
     function getFolderSize($path = null, $name = null)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $where = (is_null($path)) ? null : sprintf('WHERE vfs_path LIKE %s', ((!strlen($path)) ? '""' : $this->_db->quote($this->_convertPath($path) . '%')));
@@ -139,9 +161,9 @@ class VFS_sql extends VFS {
      */
     function read($path, $name)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         return $this->_readBlob($this->_params['table'], 'vfs_data',
@@ -167,11 +189,11 @@ class VFS_sql extends VFS {
      *
      * @return string The file data.
      */
-    function readPart($path, $name, &$offset, $length = -1, &$remaining)
+    function readByteRange($path, $name, &$offset, $length = -1, &$remaining)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $data = $this->_readBlob($this->_params['table'], 'vfs_data',
@@ -210,23 +232,10 @@ class VFS_sql extends VFS {
     {
         /* Don't need to check quota here since it will be checked when
          * writeData() is called. */
-        if (function_exists('file_get_contents')) {
-            $data = file_get_contents($tmpFile);
-        } else {
-            $size = filesize($tmpFile);
-            if ($size === 0) {
-                $data = '';
-                } else {
-                $dataFP = @fopen($tmpFile, 'rb');
-                if (!$dataFP) {
-                    return PEAR::raiseError(sprintf(_("The temporary file \"%s\" does not exist."), $tmpFile));
-                }
-                $data = @fread($dataFP, $size);
-                @fclose($dataFP);
-            }
-        }
-
-        return $this->writeData($path, $name, $data, $autocreate);
+        return $this->writeData($path,
+                                $name,
+                                file_get_contents($tmpFile),
+                                $autocreate);
     }
 
     /**
@@ -241,14 +250,14 @@ class VFS_sql extends VFS {
      */
     function writeData($path, $name, $data, $autocreate = false)
     {
-        $res = $this->_checkQuotaWrite('string', $data);
-        if (is_a($res, 'PEAR_Error')) {
-            return $res;
+        $result = $this->_checkQuotaWrite('string', $data);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $path = $this->_convertPath($path);
@@ -256,7 +265,7 @@ class VFS_sql extends VFS {
         /* Check to see if the data already exists. */
         $sql = sprintf('SELECT vfs_id FROM %s WHERE vfs_path %s AND vfs_name = ?',
                        $this->_params['table'],
-                       (empty($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($path));
+                       (!strlen($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($path));
         $values = array($name);
         $this->log($sql, PEAR_LOG_DEBUG);
         $id = $this->_db->getOne($sql, $values);
@@ -277,7 +286,7 @@ class VFS_sql extends VFS {
             $parent = implode('/', $dirs);
             if (!$this->isFolder($parent, $path_name)) {
                 if (!$autocreate) {
-                    return PEAR::raiseError(sprintf(_("Folder %s does not exist"), $path), 'horde.error');
+                    return PEAR::raiseError(sprintf(_("Folder \"%s\" does not exist"), $path), 'horde.error');
                 } else {
                     $result = $this->autocreatePath($path);
                     if (is_a($result, 'PEAR_Error')) {
@@ -286,11 +295,12 @@ class VFS_sql extends VFS {
                 }
             }
 
-            $id = $this->_db->nextId($this->_params['table']);
+            $id = $this->_write_db->nextId($this->_params['table']);
             if (is_a($id, 'PEAR_Error')) {
                 $this->log($id, PEAR_LOG_ERR);
                 return $id;
             }
+
             return $this->_insertBlob($this->_params['table'], 'vfs_data',
                                       $data, array('vfs_id' => $id,
                                                    'vfs_type' => VFS_FILE,
@@ -311,21 +321,21 @@ class VFS_sql extends VFS {
      */
     function deleteFile($path, $name)
     {
-        $res = $this->_checkQuotaDelete($path, $name);
-        if (is_a($res, 'PEAR_Error')) {
-            return $res;
+        $result = $this->_checkQuotaDelete($path, $name);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $path = $this->_convertPath($path);
 
         $sql = sprintf('DELETE FROM %s WHERE vfs_type = ? AND vfs_path %s AND vfs_name = ?',
                        $this->_params['table'],
-                       (empty($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($path));
+                       (!strlen($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($path));
         $values = array(VFS_FILE, $name);
         $this->log($sql, PEAR_LOG_DEBUG);
         $result = $this->_db->query($sql, $values);
@@ -349,9 +359,9 @@ class VFS_sql extends VFS {
      */
     function rename($oldpath, $oldname, $newpath, $newname)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         if (strpos($newpath, '/') === false) {
@@ -375,9 +385,9 @@ class VFS_sql extends VFS {
 
         $values = array($newpath, $newname, time(), $oldpath, $oldname);
 
-        $result = $this->_db->query($sql, $values);
+        $result = $this->_write_db->query($sql, $values);
 
-        if ($this->_db->affectedRows() == 0) {
+        if ($this->_write_db->affectedRows() == 0) {
             return PEAR::raiseError(_("Unable to rename VFS file."));
         }
 
@@ -400,12 +410,12 @@ class VFS_sql extends VFS {
      */
     function createFolder($path, $name)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
-        $id = $this->_db->nextId($this->_params['table']);
+        $id = $this->_write_db->nextId($this->_params['table']);
         if (is_a($id, 'PEAR_Error')) {
             $this->log($id, PEAR_LOG_ERR);
             return $id;
@@ -431,9 +441,9 @@ class VFS_sql extends VFS {
      */
     function deleteFolder($path, $name, $recursive = false)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $path = $this->_convertPath($path);
@@ -456,9 +466,9 @@ class VFS_sql extends VFS {
          * get no orphans */
         $sql = sprintf('DELETE FROM %s WHERE vfs_path %s',
                        $this->_params['table'],
-                       (empty($folderPath) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' LIKE ' . $this->_db->quote($this->_getNativePath($folderPath, '%')));
+                       (!strlen($folderPath) && $this->_write_db->dbsyntax == 'oci8') ? ' IS NULL' : ' LIKE ' . $this->_write_db->quote($this->_getNativePath($folderPath, '%')));
         $this->log($sql, PEAR_LOG_DEBUG);
-        $deleteContents = $this->_db->query($sql);
+        $deleteContents = $this->_write_db->query($sql);
         if (is_a($deleteContents, 'PEAR_Error')) {
             $this->log($deleteContents, PEAR_LOG_ERR);
             return PEAR::raiseError(sprintf(_("Unable to delete VFS recursively: %s."), $deleteContents->getMessage()));
@@ -467,9 +477,9 @@ class VFS_sql extends VFS {
         /* Now delete everything inside the folder. */
         $sql = sprintf('DELETE FROM %s WHERE vfs_path %s',
                        $this->_params['table'],
-                       (empty($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($folderPath));
+                       (!strlen($path) && $this->_write_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_write_db->quote($folderPath));
         $this->log($sql, PEAR_LOG_DEBUG);
-        $delete = $this->_db->query($sql);
+        $delete = $this->_write_db->query($sql);
         if (is_a($delete, 'PEAR_Error')) {
             $this->log($delete, PEAR_LOG_ERR);
             return PEAR::raiseError(sprintf(_("Unable to delete VFS directory: %s."), $delete->getMessage()));
@@ -478,10 +488,10 @@ class VFS_sql extends VFS {
         /* All ok now delete the actual folder */
         $sql = sprintf('DELETE FROM %s WHERE vfs_path %s AND vfs_name = ?',
                        $this->_params['table'],
-                       (empty($path) && $this->_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_db->quote($path));
+                       (!strlen($path) && $this->_write_db->dbsyntax == 'oci8') ? ' IS NULL' : ' = ' . $this->_write_db->quote($path));
         $values = array($name);
         $this->log($sql, PEAR_LOG_DEBUG);
-        $delete = $this->_db->query($sql, $values);
+        $delete = $this->_write_db->query($sql, $values);
         if (is_a($delete, 'PEAR_Error')) {
             $this->log($delete, PEAR_LOG_ERR);
             return PEAR::raiseError(sprintf(_("Unable to delete VFS directory: %s."), $delete->getMessage()));
@@ -504,15 +514,15 @@ class VFS_sql extends VFS {
     function _listFolder($path, $filter = null, $dotfiles = true,
                          $dironly = false)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $path = $this->_convertPath($path);
 
         // Fix for Oracle not differentiating between '' and NULL.
-        if (empty($path) && $this->_db->dbsyntax == 'oci8') {
+        if (!strlen($path) && $this->_db->dbsyntax == 'oci8') {
             $where = 'vfs_path IS NULL';
         } else {
             $where = 'vfs_path = ' . $this->_db->quote($path);
@@ -588,9 +598,9 @@ class VFS_sql extends VFS {
      */
     function listFolders($path = '', $filter = array(), $dotfolders = true)
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
         }
 
         $path = $this->_convertPath($path);
@@ -672,7 +682,7 @@ class VFS_sql extends VFS {
                         $this->_convertPath($path),
                         $this->_convertPath($path) . '/%');
 
-        return $this->_db->query($sql, $values);
+        return $this->_write_db->query($sql, $values);
     }
 
     /**
@@ -707,9 +717,7 @@ class VFS_sql extends VFS {
 
         $values = array($this->_getNativePath($newpath, $newname), $this->_getNativePath($oldpath, $oldname));
 
-        $result = $this->_db->query($sql, $values);
-
-        return $result;
+        return $this->_write_db->query($sql, $values);
     }
 
     /**
@@ -725,15 +733,13 @@ class VFS_sql extends VFS {
      */
     function _getNativePath($path, $name)
     {
-        if (empty($path)) {
+        if (!strlen($path)) {
             return $name;
         }
 
-        if (!empty($path)) {
-            if (isset($this->_params['home']) &&
-                preg_match('|^~/?(.*)$|', $path, $matches)) {
-                $path = $this->_params['home'] . '/' . $matches[1];
-            }
+        if (isset($this->_params['home']) &&
+            preg_match('|^~/?(.*)$|', $path, $matches)) {
+            $path = $this->_params['home'] . '/' . $matches[1];
         }
 
         return $path . '/' . $name;
@@ -748,43 +754,66 @@ class VFS_sql extends VFS {
      */
     function _connect()
     {
-        if ($this->_db === false) {
-            if (!is_array($this->_params)) {
-                return PEAR::raiseError(_("No configuration information specified for SQL VFS."));
-            }
+        if ($this->_connected) {
+            return true;
+        }
 
-            $required = array('phptype');
-            foreach ($required as $val) {
-                if (!isset($this->_params[$val])) {
-                    return PEAR::raiseError(sprintf(_("Required \"%s\" not specified in VFS configuration."), $val));
-                }
-            }
+        if (!is_array($this->_params)) {
+            return PEAR::raiseError(_("No configuration information specified for SQL VFS."));
+        }
 
-            if (!isset($this->_params['database'])) {
-                $this->_params['database'] = '';
-            }
-            if (!isset($this->_params['username'])) {
-                $this->_params['username'] = '';
-            }
-            if (!isset($this->_params['hostspec'])) {
-                $this->_params['hostspec'] = '';
-            }
-            if (!isset($this->_params['table'])) {
-                $this->_params['table'] = 'horde_vfs';
+        $required = array('phptype');
+        foreach ($required as $val) {
+            if (!isset($this->_params[$val])) {
+                return PEAR::raiseError(sprintf(_("Required \"%s\" not specified in VFS configuration."), $val));
             }
+        }
 
-            /* Connect to the SQL server using the supplied parameters. */
-            require_once 'DB.php';
-            $this->_db = &DB::connect($this->_params,
-                                      array('persistent' => !empty($this->_params['persistent'])));
+        if (!isset($this->_params['database'])) {
+            $this->_params['database'] = '';
+        }
+        if (!isset($this->_params['username'])) {
+            $this->_params['username'] = '';
+        }
+        if (!isset($this->_params['hostspec'])) {
+            $this->_params['hostspec'] = '';
+        }
+        if (!isset($this->_params['table'])) {
+            $this->_params['table'] = 'horde_vfs';
+        }
+
+        /* Connect to the SQL server using the supplied parameters. */
+        require_once 'DB.php';
+        $this->_write_db = &DB::connect($this->_params,
+                                        array('persistent' => !empty($this->_params['persistent']),
+                                              'ssl' => !empty($this->_params['ssl'])));
+        if (is_a($this->_write_db, 'PEAR_Error')) {
+            $this->log($this->_write_db, PEAR_LOG_ERR);
+            $error = $this->_write_db;
+            $this->_write_db = false;
+            return $error;
+        }
+
+        // Set DB portability options.
+        switch ($this->_write_db->phptype) {
+        case 'mssql':
+            $this->_write_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
+            break;
+        default:
+            $this->_write_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
+        }
+
+        /* Check if we need to set up the read DB connection
+         * seperately. */
+        if (!empty($this->_params['splitread'])) {
+            $params = array_merge($this->_params, $this->_params['read']);
+            $this->_db = &DB::connect($params,
+                                      array('persistent' => !empty($params['persistent']),
+                                            'ssl' => !empty($params['ssl'])));
             if (is_a($this->_db, 'PEAR_Error')) {
-                $this->log($this->_db, PEAR_LOG_ERR);
-                $error = $this->_db;
-                $this->_db = false;
-                return $error;
+                return $this->_db;
             }
 
-
             // Set DB portability options.
             switch ($this->_db->phptype) {
             case 'mssql':
@@ -794,32 +823,23 @@ class VFS_sql extends VFS {
                 $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
             }
 
+        } else {
+            /* Default to the same DB handle for reads. */
+            $this->_db =& $this->_write_db;
         }
 
+        $this->_connected = true;
         return true;
     }
 
     /**
-     * Disconnect from the SQL server and clean up the connection.
-     *
-     * @access private
-     */
-    function _disconnect()
-    {
-        if ($this->_db) {
-            $this->_db->disconnect();
-            $this->_db = false;
-        }
-    }
-
-    /**
-     * TODO
+     * Read file data from the SQL VFS backend.
      *
      * @access private
      *
-     * @param string $table     TODO
-     * @param string $field     TODO
-     * @param string $criteria  TODO
+     * @param string $table    The VFS table name.
+     * @param string $field    TODO
+     * @param array $criteria  TODO
      *
      * @return mixed  TODO
      */
@@ -837,7 +857,7 @@ class VFS_sql extends VFS {
                 if (!empty($where)) {
                     $where .= ' AND ';
                 }
-                if (empty($value)) {
+                if (!strlen($value)) {
                     $where .= $key . ' IS NULL';
                 } else {
                     $where .= $key . ' = ' . $this->_db->quote($value);
@@ -903,14 +923,14 @@ class VFS_sql extends VFS {
         $fields = array();
         $values = array();
 
-        switch ($this->_db->dbsyntax) {
+        switch ($this->_write_db->dbsyntax) {
         case 'oci8':
             foreach ($attributes as $key => $value) {
                 $fields[] = $key;
-                $values[] = $this->_db->quoteSmart($value);
+                $values[] = $this->_write_db->quoteSmart($value);
             }
 
-            $statement = OCIParse($this->_db->connection,
+            $statement = OCIParse($this->_write_db->connection,
                                   sprintf('INSERT INTO %s (%s, %s)' .
                                           ' VALUES (%s, EMPTY_BLOB()) RETURNING %s INTO :blob',
                                           $table,
@@ -919,11 +939,11 @@ class VFS_sql extends VFS {
                                           implode(', ', $values),
                                           $field));
 
-            $lob = OCINewDescriptor($this->_db->connection);
+            $lob = OCINewDescriptor($this->_write_db->connection);
             OCIBindByName($statement, ':blob', $lob, -1, SQLT_BLOB);
             OCIExecute($statement, OCI_DEFAULT);
             $lob->save($data);
-            $result = OCICommit($this->_db->connection);
+            $result = OCICommit($this->_write_db->connection);
             $lob->free();
             OCIFreeStatement($statement);
             return $result ? true : PEAR::raiseError('Unknown Error');
@@ -942,7 +962,7 @@ class VFS_sql extends VFS {
             break;
         }
 
-        switch ($this->_db->dbsyntax) {
+        switch ($this->_write_db->dbsyntax) {
         case 'mssql':
         case 'pgsql':
             $values[] = bin2hex($data);
@@ -954,7 +974,7 @@ class VFS_sql extends VFS {
 
         /* Execute the query. */
         $this->log($query, PEAR_LOG_DEBUG);
-        return $this->_db->query($query, $values);
+        return $this->_write_db->query($query, $values);
     }
 
     /**
@@ -975,17 +995,17 @@ class VFS_sql extends VFS {
         $fields = array();
         $values = array();
 
-        switch ($this->_db->dbsyntax) {
+        switch ($this->_write_db->dbsyntax) {
         case 'oci8':
             $wherestring = '';
             foreach ($where as $key => $value) {
                 if (!empty($wherestring)) {
                     $wherestring .= ' AND ';
                 }
-                $wherestring .= $key . ' = ' . $this->_db->quote($value);
+                $wherestring .= $key . ' = ' . $this->_write_db->quote($value);
             }
 
-            $statement = OCIParse($this->_db->connection,
+            $statement = OCIParse($this->_write_db->connection,
                                   sprintf('SELECT %s FROM %s WHERE %s FOR UPDATE',
                                           $field,
                                           $table,
@@ -994,7 +1014,7 @@ class VFS_sql extends VFS {
             OCIExecute($statement, OCI_DEFAULT);
             OCIFetchInto($statement, $lob);
             $lob[0]->save($data);
-            $result = OCICommit($this->_db->connection);
+            $result = OCICommit($this->_write_db->connection);
             $lob[0]->free();
             OCIFreeStatement($statement);
             return $result ? true : PEAR::raiseError('Unknown Error');
@@ -1007,7 +1027,7 @@ class VFS_sql extends VFS {
                 $values[] = $value;
             }
             $updatestring .= $field . ' = ?';
-            switch ($this->_db->dbsyntax) {
+            switch ($this->_write_db->dbsyntax) {
             case 'mssql':
             case 'pgsql':
                 $values[] = bin2hex($data);
@@ -1035,30 +1055,30 @@ class VFS_sql extends VFS {
 
         /* Execute the query. */
         $this->log($query, PEAR_LOG_DEBUG);
-        return $this->_db->query($query, $values);
+        return $this->_write_db->query($query, $values);
     }
 
     /**
-     * Convert the pathname from regular filesystem form to the internal
+     * Converts the path name from regular filesystem form to the internal
      * format needed to access the file in the database.
+     *
      * Namely, we will treat '/' as a base directory as this is pretty much
      * the standard way to access base directories over most filesystems.
-}    *
+     *
      * @access private
      *
      * @param string $path  A VFS path.
      *
-     * @return string  The path with any beginning slash stripped off.
+     * @return string  The path with any surrouding slashes stripped off.
      */
     function _convertPath($path)
     {
-        if (!empty($path) && (strpos($path, '/') === 0)) {
-            $path = strval(substr($path, 1));
-        }
-
-        return $path;
+        return trim($path, '/');
     }
 
+    /**
+     * TODO
+     */
     function _getFileSizeOp()
     {
         switch ($this->_db->dbsyntax) {
