@@ -12,7 +12,7 @@
  *      'port'           The port used to connect to the ssh2 server if other
  *                       than 22.</pre>
  *
- * $Horde: framework/VFS/lib/VFS/ssh2.php,v 1.1.2.13 2009/06/15 14:22:32 chuck Exp $
+ * $Horde: framework/VFS/lib/VFS/ssh2.php,v 1.1.2.16 2009-11-01 02:29:08 chuck Exp $
  *
  * Copyright 2006-2009 The Horde Project (http://www.horde.org/)
  *
@@ -118,6 +118,7 @@ class VFS_ssh2 extends VFS {
             return $file;
         }
 
+        clearstatcache();
         $size = filesize($file);
         if ($size === 0) {
             return '';
@@ -764,6 +765,11 @@ class VFS_ssh2 extends VFS {
                 return PEAR::raiseError(sprintf(_("Failed to copy from \"%s\"."), $orig));
             }
 
+            $res = $this->_checkQuotaWrite('file', $tmpFile);
+            if (is_a($res, 'PEAR_Error')) {
+                return $res;
+            }
+
             if (!$this->_send($tmpFile, $this->_getPath($dest, $name))) {
                 unlink($tmpFile);
                 return PEAR::raiseError(sprintf(_("Failed to copy to \"%s\"."), $this->_getPath($dest, $name)));
@@ -963,7 +969,7 @@ class VFS_ssh2 extends VFS {
      */
     function _send($local, $remote)
     {
-        return copy($local, $this->_wrap($remote));
+        return @copy($local, $this->_wrap($remote));
     }
 
     /**
@@ -979,7 +985,7 @@ class VFS_ssh2 extends VFS {
      */
     function _recv($remote, $local)
     {
-        return copy($this->_wrap($remote), $local);
+        return @copy($this->_wrap($remote), $local);
     }
 
     /**
