@@ -3,16 +3,17 @@
 include_once 'XML/WBXML/DTD.php';
 
 /**
- * $Horde: framework/XML_WBXML/WBXML/DTD/SyncML.php,v 1.6.12.6 2007/01/02 13:54:51 jan Exp $
- *
  * From Binary XML Content Format Specification Version 1.3, 25 July 2001
  * found at http://www.wapforum.org
  *
- * Copyright 2003-2007 Anthony Mills <amills@pyramid6.com>
+ * $Horde: framework/XML_WBXML/WBXML/DTD/SyncML.php,v 1.6.12.9 2009-01-06 15:23:50 jan Exp $
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
+ * @author  Anthony Mills <amills@pyramid6.com>
  * @package XML_WBXML
  */
 class XML_WBXML_DTD_SyncML extends XML_WBXML_DTD {
@@ -72,17 +73,29 @@ class XML_WBXML_DTD_SyncML extends XML_WBXML_DTD {
         $this->setTag(0x30, "Reserved for future use"); // 0x00
         $this->setTag(0x31, "VerDTD"); // 0x00
         $this->setTag(0x32, "VerProto"); // 0x00
-        $this->setTag(0x33, "NumberOfChanged"); // 0x00
+        $this->setTag(0x33, "NumberOfChanges"); // 0x00
         $this->setTag(0x34, "MoreData"); // 0x00
+        $this->setTag(0x35, "Field"); // 0x00
+        $this->setTag(0x36, "Filter"); // 0x00
+        $this->setTag(0x37, "Record"); // 0x00
+        $this->setTag(0x38, "FilterType"); // 0x00
+        $this->setTag(0x39, "SourceParent"); // 0x00
+        $this->setTag(0x3a, "TargetParent"); // 0x00
+        $this->setTag(0x3b, "Move"); // 0x00
+        $this->setTag(0x3c, "Correlator"); // 0x00
 
-        if ($this->version == 0) {
-            $this->setCodePage(0, '-//SYNCML//DTD SyncML 1.0//EN', 'syncml:syncml1.0');
-            $this->setCodePage(1, '-//SYNCML//DTD MetInf 1.0//EN', 'syncml:metinf1.0');
-            $this->setURI('syncml:syncml1.0');
-        } else {
-            $this->setCodePage(0, '-//SYNCML//DTD SyncML 1.1//EN', 'syncml:syncml1.1');
-            $this->setCodePage(1, '-//SYNCML//DTD MetInf 1.1//EN', 'syncml:metinf1.1');
+        if ($this->version == 1) {
+            $this->setCodePage(0, DPI_DTD_SYNCML_1_1, 'syncml:syncml1.1');
+            $this->setCodePage(1, DPI_DTD_METINF_1_1, 'syncml:metinf1.1');
             $this->setURI('syncml:syncml1.1');
+        } elseif ($this->version == 2) {
+            $this->setCodePage(0, DPI_DTD_SYNCML_1_2, 'syncml:syncml1.2');
+            $this->setCodePage(1, DPI_DTD_METINF_1_2, 'syncml:metinf1.2');
+            $this->setURI('syncml:syncml1.2');
+        } else {
+            $this->setCodePage(0, DPI_DTD_SYNCML_1_0, 'syncml:syncml1.0');
+            $this->setCodePage(1, DPI_DTD_METINF_1_0, 'syncml:metinf1.0');
+            $this->setURI('syncml:syncml1.0');
         }
     }
 
