@@ -5,16 +5,17 @@ include_once 'XML/WBXML/DTD/SyncMLMetInf.php';
 include_once 'XML/WBXML/DTD/SyncMLDevInf.php';
 
 /**
- * $Horde: framework/XML_WBXML/WBXML/DTDManager.php,v 1.3.12.12 2007/01/02 13:54:50 jan Exp $
+ * From Binary XML Content Format Specification Version 1.3, 25 July 2001
+ * found at http://www.wapforum.org
  *
- * Copyright 2003-2007 Anthony Mills <amills@pyramid6.com>
+ * $Horde: framework/XML_WBXML/WBXML/DTDManager.php,v 1.3.12.15 2009-01-06 15:23:50 jan Exp $
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * From Binary XML Content Format Specification Version 1.3, 25 July
- * 2001 found at http://www.wapforum.org
- *
+ * @author  Anthony Mills <amills@pyramid6.com>
  * @package XML_WBXML
  */
 class XML_WBXML_DTDManager {
@@ -33,14 +34,17 @@ class XML_WBXML_DTDManager {
      */
     function XML_WBXML_DTDManager()
     {
-        $this->registerDTD('-//SYNCML//DTD SyncML 1.0//EN', 'syncml:syncml1.0', new XML_WBXML_DTD_SyncML(0));
-        $this->registerDTD('-//SYNCML//DTD SyncML 1.1//EN', 'syncml:syncml1.1', new XML_WBXML_DTD_SyncML(1));
+        $this->registerDTD(DPI_DTD_SYNCML_1_0, 'syncml:syncml1.0', new XML_WBXML_DTD_SyncML(0));
+        $this->registerDTD(DPI_DTD_SYNCML_1_1, 'syncml:syncml1.1', new XML_WBXML_DTD_SyncML(1));
+        $this->registerDTD(DPI_DTD_SYNCML_1_2, 'syncml:syncml1.2', new XML_WBXML_DTD_SyncML(2));
 
-        $this->registerDTD('-//SYNCML//DTD MetInf 1.0//EN', 'syncml:metinf1.0', new XML_WBXML_DTD_SyncMLMetInf(0));
-        $this->registerDTD('-//SYNCML//DTD MetInf 1.1//EN', 'syncml:metinf1.1', new XML_WBXML_DTD_SyncMLMetInf(1));
+        $this->registerDTD(DPI_DTD_METINF_1_0, 'syncml:metinf1.0', new XML_WBXML_DTD_SyncMLMetInf(0));
+        $this->registerDTD(DPI_DTD_METINF_1_1, 'syncml:metinf1.1', new XML_WBXML_DTD_SyncMLMetInf(1));
+        $this->registerDTD(DPI_DTD_METINF_1_2, 'syncml:metinf1.2', new XML_WBXML_DTD_SyncMLMetInf(2));
 
-        $this->registerDTD('-//SYNCML//DTD DevInf 1.0//EN', 'syncml:devinf1.0', new XML_WBXML_DTD_SyncMLDevInf(0));
-        $this->registerDTD('-//SYNCML//DTD DevInf 1.1//EN', 'syncml:devinf1.1', new XML_WBXML_DTD_SyncMLDevInf(1));
+        $this->registerDTD(DPI_DTD_DEVINF_1_0, 'syncml:devinf1.0', new XML_WBXML_DTD_SyncMLDevInf(0));
+        $this->registerDTD(DPI_DTD_DEVINF_1_1, 'syncml:devinf1.1', new XML_WBXML_DTD_SyncMLDevInf(1));
+        $this->registerDTD(DPI_DTD_DEVINF_1_2, 'syncml:devinf1.2', new XML_WBXML_DTD_SyncMLDevInf(2));
     }
 
     /**
@@ -85,9 +89,10 @@ class XML_WBXML_DTDManager {
      */
     function registerDTD($publicIdentifier, $uri, &$dtd)
     {
-        $publicIdentifier = strtolower($publicIdentifier);
         $dtd->setDPI($publicIdentifier);
 
+        $publicIdentifier = strtolower($publicIdentifier);
+
         $this->_strDTD[$publicIdentifier] = $dtd;
         $this->_strDTDURI[strtolower($uri)] = $dtd;
     }
