@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/sql/create.mysql.sql,v 1.4.6.22 2008/08/13 20:18:03 chuck Exp $
+-- $Horde: horde/scripts/sql/create.mysql.sql,v 1.4.6.25 2009-07-07 03:01:40 mrubinsk Exp $
 --
 -- If you are installing Horde for the first time, you can simply
 -- direct this file to mysql as STDIN:
@@ -62,10 +62,8 @@ CREATE TABLE horde_signups (
     user_name VARCHAR(255) NOT NULL,
     signup_date VARCHAR(255) NOT NULL,
     signup_host VARCHAR(255) NOT NULL,
-    signup_email VARCHAR(255) NOT NULL,
     signup_data TEXT NOT NULL,
-    UNIQUE KEY user_name (user_name),
-    UNIQUE KEY signup_email (signup_email)
+    PRIMARY KEY user_name (user_name)
 );
 
 CREATE TABLE horde_groups (
@@ -184,6 +182,9 @@ CREATE TABLE horde_sessionhandler (
     PRIMARY KEY (session_id)
 ) ENGINE = InnoDB;
 
+CREATE INDEX session_lastmodified_idx ON horde_sessionhandler (session_lastmodified);
+
+
 CREATE TABLE horde_syncml_map (
     syncml_syncpartner VARCHAR(255) NOT NULL,
     syncml_db          VARCHAR(255) NOT NULL,
