@@ -1,13 +1,13 @@
--- $Horde: horde/scripts/sql/horde_muvfs.sql,v 1.1 2004/09/18 17:20:59 chuck Exp $
+-- $Horde: horde/scripts/sql/horde_muvfs.sql,v 1.1.10.1 2008-07-20 14:25:23 chuck Exp $
 
 CREATE TABLE horde_muvfs (
-    vfs_id        BIGINT NOT NULL,
-    vfs_type      SMALLINT NOT NULL,
+    vfs_id        INT UNSIGNED NOT NULL,
+    vfs_type      SMALLINT UNSIGNED NOT NULL,
     vfs_path      VARCHAR(255) NOT NULL,
     vfs_name      VARCHAR(255) NOT NULL,
     vfs_modified  BIGINT NOT NULL,
     vfs_owner     VARCHAR(255) NOT NULL,
-    vfs_perms     SMALLINT NOT NULL,
+    vfs_perms     SMALLINT UNSIGNED NOT NULL,
     vfs_data      LONGBLOB,
 -- Or, on some DBMS systems:
 --  vfs_data      IMAGE,
