@@ -1,8 +1,8 @@
--- $Horde: horde/scripts/sql/horde_prefs.mssql.sql,v 1.1.2.2 2006/06/29 16:29:03 jan Exp $
+-- $Horde: horde/scripts/sql/horde_prefs.mssql.sql,v 1.1.2.3 2007-12-20 15:03:03 jan Exp $
 
 CREATE TABLE horde_prefs (
     pref_uid        VARCHAR(255) NOT NULL,
-    pref_scope      VARCHAR(16) NOT NULL DEFAULT '',
+    pref_scope      VARCHAR(16) DEFAULT '' NOT NULL,
     pref_name       VARCHAR(32) NOT NULL,
     pref_value      VARCHAR(MAX),
 --
@@ -11,5 +11,3 @@ CREATE TABLE horde_prefs (
 
 CREATE INDEX pref_uid_idx ON horde_prefs (pref_uid);
 CREATE INDEX pref_scope_idx ON horde_prefs (pref_scope);
-
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_prefs TO horde;
