@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/sql/horde_sessionhandler.mysql.sql,v 1.1.2.1 2006/03/22 18:30:23 jan Exp $
+-- $Horde: horde/scripts/sql/horde_sessionhandler.mysql.sql,v 1.1.2.3 2009-02-14 04:43:47 chuck Exp $
 
 CREATE TABLE horde_sessionhandler (
     session_id             VARCHAR(32) NOT NULL,
@@ -8,4 +8,4 @@ CREATE TABLE horde_sessionhandler (
     PRIMARY KEY (session_id)
 ) ENGINE = InnoDB;
 
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_sessionhandler TO horde@localhost;
+CREATE INDEX session_lastmodified_idx ON horde_sessionhandler (session_lastmodified);
