@@ -1,8 +1,8 @@
--- $Horde: horde/scripts/sql/horde_vfs.mssql.sql,v 1.1.2.1 2006/01/18 19:59:16 ben Exp $
+-- $Horde: horde/scripts/sql/horde_vfs.mssql.sql,v 1.1.2.3 2008-07-20 14:25:23 chuck Exp $
 
 CREATE TABLE horde_vfs (
-    vfs_id        BIGINT NOT NULL,
-    vfs_type      SMALLINT NOT NULL,
+    vfs_id        INT UNSIGNED NOT NULL,
+    vfs_type      SMALLINT UNSIGNED NOT NULL,
     vfs_path      VARCHAR(255) NOT NULL,
     vfs_name      VARCHAR(255) NOT NULL,
     vfs_modified  BIGINT NOT NULL,
@@ -13,5 +13,3 @@ CREATE TABLE horde_vfs (
 
 CREATE INDEX vfs_path_idx ON horde_vfs (vfs_path);
 CREATE INDEX vfs_name_idx ON horde_vfs (vfs_name);
-
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_vfs TO horde;
