@@ -1,8 +1,8 @@
--- $Horde: horde/scripts/sql/horde_vfs.sql,v 1.1.10.2 2005/10/18 11:34:00 jan Exp $
+-- $Horde: horde/scripts/sql/horde_vfs.sql,v 1.1.10.4 2008-07-20 14:25:23 chuck Exp $
 
 CREATE TABLE horde_vfs (
-    vfs_id        BIGINT NOT NULL,
-    vfs_type      SMALLINT NOT NULL,
+    vfs_id        INT UNSIGNED NOT NULL,
+    vfs_type      SMALLINT UNSIGNED NOT NULL,
     vfs_path      VARCHAR(255) NOT NULL,
     vfs_name      VARCHAR(255) NOT NULL,
     vfs_modified  BIGINT NOT NULL,
@@ -15,5 +15,3 @@ CREATE TABLE horde_vfs (
 
 CREATE INDEX vfs_path_idx ON horde_vfs (vfs_path);
 CREATE INDEX vfs_name_idx ON horde_vfs (vfs_name);
-
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_vfs TO horde;
