@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: horde/services/javascript.php,v 1.37.10.2 2005/01/20 15:09:52 chuck Exp $
+ * $Horde: horde/services/javascript.php,v 1.37.10.8 2009-01-06 15:26:20 jan Exp $
  *
- * Copyright 2000-2005 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('HORDE_BASE', dirname(__FILE__) . '/..');
@@ -20,7 +22,7 @@ $app = Util::getFormData('app', Util::nonInputVar('app'));
 $file = Util::getFormData('file', Util::nonInputVar('file'));
 if (!empty($app) && !empty($file) && strpos($file, '..') === false) {
     $script_file = $registry->get('templates', $app) . '/javascript/' . $file;
-    if (@file_exists($script_file)) {
+    if (file_exists($script_file)) {
         $registry->pushApp($app, false);
         $script = Util::bufferOutput('require', $script_file);
 
