@@ -1,13 +1,14 @@
 <?php
 /**
- * $Horde: horde/services/maintenance.php,v 1.31.2.4 2007/01/02 13:55:15 jan Exp $
+ * $Horde: horde/services/maintenance.php,v 1.31.2.7 2009-01-06 15:26:20 jan Exp $
  *
- * Copyright 2001-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
- * Copyright 2001-2007 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 2001-2007 Jon Parise <jon@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
+ * @author Michael Slusarz <slusarz@horde.org>
  */
 
 @define('HORDE_BASE', dirname(__FILE__) . '/..');
@@ -32,7 +33,7 @@ if (!($maint = &Maintenance::factory($module))) {
 }
 
 /* Create the Horde_Template item. */
-$template = &new Horde_Template();
+$template = new Horde_Template();
 $template->set('javascript', $browser->hasFeature('javascript'), true);
 
 /* Have the maintenance module do all necessary processing. */
@@ -78,10 +79,11 @@ foreach ($tasklist as $pref) {
 
 $template->setOption('gettext', true);
 $template->set('tasks', $tasks);
-$template->set('maint_url', $maint->getMaintenanceFormURL());
+$template->set('maint_url', htmlspecialchars($maint->getMaintenanceFormURL()));
 $template->set('maint_postdata', $maint->getPostData());
 $template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
 
+$bodyId = 'services_maintenance';
 require HORDE_TEMPLATES . '/common-header.inc';
 echo $template->fetch(HORDE_TEMPLATES . '/maintenance/maintenance.html');
 require HORDE_TEMPLATES . '/common-footer.inc';
