@@ -1,25 +1,26 @@
 <?php
 /**
- * $Horde: horde/services/portal/sidebar.php,v 1.4.2.8 2005/07/02 00:05:08 chuck Exp $
+ * $Horde: horde/services/portal/sidebar.php,v 1.4.2.20 2009-01-06 15:27:33 jan Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
- * Copyright 2003-2005 Michael Pawlowsky <mjpawlowsky@yahoo.com>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @author Michael Pawlowsky <mikep@clearskymedia.ca>
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 /**
  * Determine if the current user can see an application.
  *
- * @param string  $app          The application name.
- * @param array   $params       The application's parameters.
- * @param array  &$hasChildren  Reference to an array to set children flags in.
+ * @param string $app         The application name.
+ * @param array $params       The application's parameters.
+ * @param array $hasChildren  Reference to an array to set children flags in.
  */
 function canSee($app, $params, &$hasChildren)
 {
-    global $perms, $registry;
+    global $registry;
 
     static $cache = array();
     static $isAdmin;
@@ -37,23 +38,27 @@ function canSee($app, $params, &$hasChildren)
         $user = Auth::getAuth();
     }
 
-    // Check if the current user has permisson to see this
-    // application, and if the application is active. Headings are
-    // visible to everyone (but get filtered out later if they have no
-    // children). Administrators always see all applications except
-    // those marked 'inactive'. Anyone with SHOW permissions can see
-    // an application, but READ is needed to actually use the
-    // application. You can use this distinction to show applications
-    // to guests that they need to log in to use. If you don't want
-    // them to see apps they can't use, then don't give guests SHOW
-    // permissions to anything.
-    if (// Don't show applications that aren't installed, even if
-        // they're configured.
+    // Check if the current user has permisson to see this application, and if
+    // the application is active. Headings are visible to everyone (but get
+    // filtered out later if they have no children). Administrators always see
+    // all applications except those marked 'inactive'. Anyone with SHOW
+    // permissions can see an application, but READ is needed to actually use
+    // the application. You can use this distinction to show applications to
+    // guests that they need to log in to use. If you don't want them to see
+    // apps they can't use, then don't give guests SHOW permissions to
+    // anything.
+    if (// Don't show applications that aren't installed, even if they're
+        // configured.
         (isset($params['fileroot']) && !is_dir($params['fileroot'])) ||
 
-        // Filter out entries that are disabled, hidden or shouldn't
-        // show up in the menu.
-        $params['status'] == 'notoolbar' || $params['status'] == 'hidden' || $params['status'] == 'inactive') {
+        // Don't show blocks of applications that aren't installed.
+        ($params['status'] == 'block' &&
+         !is_dir($registry->get('fileroot', $params['app']))) ||
+
+        // Filter out entries that are disabled, hidden or shouldn't show up
+        // in the menu.
+        $params['status'] == 'notoolbar' || $params['status'] == 'hidden' ||
+        $params['status'] == 'inactive') {
 
         $cache[$app] = false;
 
@@ -63,8 +68,8 @@ function canSee($app, $params, &$hasChildren)
               // Admins see everything that makes it to this point.
               ($isAdmin ||
 
-               // Users who have SHOW permissions to active or block
-               // entries see them.
+               // Users who have SHOW permissions to active or block entries
+               // see them.
                ($registry->hasPermission($app, PERMS_SHOW) &&
                 ($params['status'] == 'active' ||
                  $params['status'] == 'block')))) {
@@ -88,7 +93,7 @@ function canSee($app, $params, &$hasChildren)
  */
 function buildMenu()
 {
-    global $conf, $perms, $registry;
+    global $conf, $registry;
 
     $apps = array();
     $children = array();
@@ -114,33 +119,18 @@ function buildMenu()
                                         'icon' => $registry->getImageDir() . '/administration.png',
                                         'status' => 'heading');
 
-        foreach ($registry->listApps() as $app) {
-            if (!$registry->hasMethod('admin_list', $app)) {
-                continue;
-            }
-
-            $list = $registry->callByPackage($app, 'admin_list');
-            if (is_a($list, 'PEAR_Error')) {
-                continue;
-            }
-
+        $list = $registry->callByPackage('horde', 'admin_list');
+        if (!is_a($list, 'PEAR_Error')) {
             foreach ($list as $method => $vals) {
-                if ($app != 'horde') {
-                    $name = $registry->get('name', $app);
-                    if (!empty($vals['name'])) {
-                        $name .= ' ' . $vals['name'];
-                    }
-                } else {
-                    $name = Horde::stripAccessKey($vals['name']);
-                }
-                $icon = isset($vals['icon']) ? $registry->getImageDir($app) . '/' . $vals['icon'] : $registry->get('icon', $app);
+                $name = Horde::stripAccessKey($vals['name']);
+                $icon = isset($vals['icon']) ? $registry->getImageDir() . '/' . $vals['icon'] : $registry->get('icon');
 
-                $menu['administration_' . $app . '_' . $method] = array(
+                $menu['administration_' . $method] = array(
                     'name' => $name,
                     'icon' => $icon,
                     'status' => 'active',
                     'menu_parent' => 'administration',
-                    'url' => Horde::url($registry->applicationWebPath($vals['link'], $app)),
+                    'url' => Horde::url($registry->applicationWebPath($vals['link'])),
                     );
             }
         }
@@ -150,8 +140,44 @@ function buildMenu()
         $conf['prefs']['driver'] != '' && $conf['prefs']['driver'] != 'none') {
         $menu['options'] = array('name' => _("Options"),
                                  'status' => 'active',
-                                 'icon' => $registry->getImageDir() . '/prefs.png',
-                                 'url' => Horde::applicationUrl('services/prefs.php'));
+                                 'icon' => $registry->getImageDir() . '/prefs.png');
+
+        /* Get a list of configurable applications. */
+        $prefs_apps = array();
+        foreach ($registry->applications as $application => $params) {
+            if ($params['status'] == 'heading' ||
+                $params['status'] == 'block' ||
+                !file_exists($registry->get('fileroot', $application) . '/config/prefs.php')) {
+                continue;
+            }
+
+            /* Check if the current user has permission to see this
+             * application, and if the application is active.
+             * Administrators always see all applications. */
+            if ((Auth::isAdmin() && $params['status'] != 'inactive') ||
+                ($registry->hasPermission($application) &&
+                 ($params['status'] == 'active'))) {
+                $prefs_apps[$application] = _($params['name']);
+            }
+        }
+
+        if (!empty($prefs_apps['horde'])) {
+            $menu['options_' . 'horde'] = array('name' => _("Global Options"),
+                                                'status' => 'active',
+                                                'menu_parent' => 'options',
+                                                'icon' => $registry->get('icon', 'horde'),
+                                                'url' => Horde::applicationUrl('services/prefs.php?app=horde'));
+            unset($prefs_apps['horde']);
+        }
+
+        asort($prefs_apps);
+        foreach ($prefs_apps as $app => $name) {
+            $menu['options_' . $app] = array('name' => $name,
+                                             'status' => 'active',
+                                             'menu_parent' => 'options',
+                                             'icon' => $registry->get('icon', $app),
+                                             'url' => Horde::applicationUrl('services/prefs.php?app=' . $app));
+        }
     }
 
     if (Auth::isAuthenticated()) {
@@ -190,14 +216,16 @@ $tree->setOption(array('target' => $is_mozbar ? '_content' : 'horde_main'));
 $menu = buildMenu();
 foreach ($menu as $app => $params) {
     if ($params['status'] == 'block') {
-        if (isset($menu[$params['app']])) {
-            $block = &Horde_Block_Collection::getBlock($params['app'], $params['blockname']);
-            if (is_a($block, 'PEAR_Error')) {
-                Horde::fatal($block, __FILE__, __LINE__);
-            }
-            $block->buildTree($tree, 0,
-                              isset($params['menu_parent']) ? $params['menu_parent'] : null);
+        if ($registry->get('status', $params['app']) == 'inactive') {
+            continue;
         }
+        $block = &Horde_Block_Collection::getBlock($params['app'], $params['blockname']);
+        if (is_a($block, 'PEAR_Error')) {
+            Horde::logMessage($block, __FILE__, __LINE__, PEAR_LOG_ERR);
+            continue;
+        }
+        $block->buildTree($tree, 0,
+                          isset($params['menu_parent']) ? $params['menu_parent'] : null);
     } else {
         // Need to run the name through gettext since the user's
         // locale may not have been loaded when registry.php was
@@ -227,17 +255,17 @@ foreach ($menu as $app => $params) {
 // updated node javascript.
 if (Util::getFormData('httpclient')) {
     header('Content-Type: text/javascript; charset=' . NLS::getCharset());
-    Horde::inlineScriptFiles();
     echo $tree->renderNodeDefinitions();
     exit;
 }
 
 $rtl = isset($nls['rtl'][$language]);
+$htmlId = 'sidebar-frame';
 $bodyClass = 'sidebar';
 if ($browser->hasQuirk('scrollbar_in_way')) {
     $bodyClass .= ' scrollbar-quirk';
 }
-Horde::addScriptFile('httpclient.js', 'horde', true);
-Horde::addScriptFile('hideable.js', 'horde', true);
+Horde::addScriptFile('prototype.js', 'horde', true);
+Horde::addScriptFile('sidebar.js', 'horde', true);
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/portal/sidebar.inc';
