@@ -1,12 +1,13 @@
 <?php
 /**
- * $Horde: horde/services/problem.php,v 2.114.8.9 2007/01/02 13:55:15 jan Exp $
+ * $Horde: horde/services/problem.php,v 2.114.8.13 2009-01-06 15:26:20 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Jon Parise <jon@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 /* Send the browser back to the correct page. */
@@ -20,7 +21,6 @@ function _returnToPage()
 @define('AUTH_HANDLER', true);
 @define('HORDE_BASE', dirname(__FILE__) . '/..');
 require_once HORDE_BASE . '/lib/base.php';
-require_once HORDE_BASE . '/lib/version.php';
 require_once 'Horde/Identity.php';
 
 if (!Horde::showService('problem')) {
@@ -40,7 +40,7 @@ $actionID = Util::getFormData('actionID');
 switch ($actionID) {
 case 'send_problem_report':
     if ($subject && $message) {
-        // This is not a gettext string on purpose.
+        /* This is not a gettext string on purpose. */
         $remote = (!empty($_SERVER['REMOTE_HOST'])) ? $_SERVER['REMOTE_HOST'] : $_SERVER['REMOTE_ADDR'];
         $user_agent = $_SERVER['HTTP_USER_AGENT'];
         $body = "This problem report was received from $remote. " .
@@ -49,11 +49,25 @@ case 'send_problem_report':
             "\nand is using the following browser:\n$user_agent\n\n" .
             str_replace("\r\n", "\n", $message);
 
-        // Default to a relatively reasonable email address.
+        /* Default to a relatively reasonable email address. */
         if (!$email) {
             $email = 'horde-problem@' . $conf['problems']['maildomain'];
         }
 
+        /* Check for attachments. */
+        $attachment = null;
+        if (!empty($conf['problems']['attachments'])) {
+            $result = Browser::wasFileUploaded('attachment', _("attachment"));
+            if (is_a($result, 'PEAR_Error')) {
+                if ($result->getCode() != UPLOAD_ERR_NO_FILE) {
+                    $notification->push($result, 'horde.error');
+                    break;
+                }
+            } else {
+                $attachment = $_FILES['attachment'];
+            }
+        }
+
         if (!empty($conf['problems']['tickets']) &&
             $registry->hasMethod('tickets/addTicket')) {
             $info = array_merge($conf['problems']['ticket_params'],
@@ -64,14 +78,23 @@ case 'send_problem_report':
             if (is_a($result, 'PEAR_Error')) {
                 $notification->push($result);
             } else {
+                if ($attachment &&
+                    $registry->hasMethod('tickets/addAttachment')) {
+                    $result = $registry->call(
+                        'tickets/addAttachment',
+                        array('ticket_id' => $result,
+                              'name' => $attachment['name'],
+                              'data' => file_get_contents($attachment['tmp_name'])));
+                    if (is_a($result, 'PEAR_Error')) {
+                        $notification->push($result);
+                    }
+                }
                 _returnToPage();
             }
         } else {
-            require_once 'Horde/MIME.php';
-            require_once 'Horde/MIME/Headers.php';
-            require_once 'Horde/MIME/Message.php';
+            require_once 'Horde/MIME/Mail.php';
 
-            // Add user's name to the email address if provided.
+            /* Add user's name to the email address if provided. */
             if ($name) {
                 @list($mailbox, $host) = @explode('@', $email, 2);
                 if (empty($host)) {
@@ -80,21 +103,17 @@ case 'send_problem_report':
                 $email = MIME::rfc822WriteAddress($mailbox, $host, $name);
             }
 
-            $msg_headers = &new MIME_Headers();
-            $msg_headers->addReceivedHeader();
-            $msg_headers->addMessageIdHeader();
-            $msg_headers->addAgentHeader();
-            $msg_headers->addHeader('Date', date('r'));
-            $msg_headers->addHeader('To', $conf['problems']['email']);
-            $msg_headers->addHeader('Subject', _("[Problem Report]") . ' ' . $subject);
-            $msg_headers->addHeader('From', $email);
-            $msg_headers->addHeader('Sender', 'horde-problem@' . $conf['problems']['maildomain']);
+            $mail = new MIME_Mail(_("[Problem Report]") . ' ' . $subject,
+                                  $body, $conf['problems']['email'], $email,
+                                  NLS::getCharset());
+            $mail->addHeader('Sender', 'horde-problem@' . $conf['problems']['maildomain']);
 
-            $mime = &new MIME_Message();
-            $mime->addPart(new MIME_Part('text/plain',
-                                         String::wrap($body, 80, "\n"),
-                                         NLS::getCharset()));
-            $msg_headers->addMIMEHeaders($mime);
+            /* Add attachment. */
+            if ($attachment) {
+                $mail->addAttachment($attachment['tmp_name'],
+                                     $attachment['name'],
+                                     $attachment['type']);
+            }
 
             $mail_driver = $conf['mailer']['type'];
             $mail_params = $conf['mailer']['params'];
@@ -110,11 +129,20 @@ case 'send_problem_report':
                 }
             }
 
-            if (!is_a($sent = $mime->send($conf['problems']['email'], $msg_headers, $mail_driver, $mail_params), 'PEAR_Error')) {
-                /* We succeeded. Return to previous page and exit this script. */
-                _returnToPage();
-            } else {
+            if (is_a($sent = $mail->send($mail_driver, $mail_params),
+                     'PEAR_Error')) {
                 $notification->push($sent);
+            } else {
+                /* We succeeded. */
+                Horde::logMessage(
+                    sprintf("%s Message sent to %s from %s",
+                            $_SERVER['REMOTE_ADDR'],
+                            preg_replace('/^.*<([^>]+)>.*$/', '$1', $conf['problems']['email']),
+                            preg_replace('/^.*<([^>]+)>.*$/', '$1', $email)),
+                    __FILE__, __LINE__, PEAR_LOG_INFO);
+
+                /* Return to previous page and exit this script. */
+                _returnToPage();
             }
         }
     }
@@ -125,7 +153,6 @@ case 'cancel_problem_report':
 }
 
 $title = _("Problem Description");
-$menu = &new Menu(HORDE_MENU_MASK_ALL & ~HORDE_MENU_MASK_PREFS);
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/menu/menu.inc';
 $notification->notify(array('listeners' => 'status'));
