@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/test.php,v 1.122.6.27 2008/11/26 22:55:50 chuck Exp $
+ * $Horde: horde/test.php,v 1.122.6.31 2009-05-05 15:27:28 selsky Exp $
  *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -76,6 +76,11 @@ $module_list = array(
     'imap' => array(
         'descrip' => 'IMAP Support',
         'error' => 'The IMAP extension is required if you want to authenticate against an IMAP server.'),
+    'imagick' => array(
+        'descrip' => 'Imagick Library',
+        'required' => false,
+        'error' => 'Horde can make use of the Imagick Library, if it is installed on your system.  It is highly recommended to use either ImageMagick\'s convert utility or the Imagick php library for faster results.'
+    ),
     'json' => array(
         'descrip' => 'JSON Support',
         'error' => 'Horde can optionally use the JSON extension to provide faster Javascript generation for rich GUI applications.'),
@@ -101,7 +106,7 @@ $module_list = array(
         'error' => 'Mcrypt is a general-purpose cryptography library which is broader and significantly more efficient (FASTER!) than PHP\'s own cryptographic code and will provider faster logins.'),
     'memcache' => array(
         'descrip' => 'memcached Support (memcache)',
-        'error' => 'The memcache PECL module is needed only if you are using the memcached SessionHandler. See horde/docs/INSTALL for information on how to install PECL/PHP extensions.'),
+        'error' => 'The memcache PECL module is only needed if you are using a memcached server for caching or sessions. See horde/docs/INSTALL for information on how to install PECL/PHP extensions.'),
     'fileinfo' => array(
         'descrip' => 'MIME Magic Support (fileinfo)',
         'error' => 'The fileinfo PECL module or the mime_magic PHP extension (see below) will most likely provide faster MIME Magic lookups than the built-in Horde PHP magic code. See horde/docs/INSTALL for information on how to install PECL/PHP extensions.'),
@@ -242,6 +247,10 @@ $pear_list = array(
     'XML_Serializer' => array(
         'path' => 'XML/Serializer.php',
         'error' => 'XML_Serializer is used by the Services_Weather module on the weather applet/block on the portal page.'
+    ),
+    'Net_DNS' => array(
+        'path' => 'Net/DNS.php',
+        'error' => 'Net_DNS can speed up hostname lookups against broken DNS servers.'
     )
 );
 
